Class: Appwrite::Messaging
- Defined in:
- lib/appwrite/services/messaging.rb
Instance Method Summary collapse
-
#create_apns_provider(provider_id:, name:, auth_key: nil, auth_key_id: nil, team_id: nil, bundle_id: nil, sandbox: nil, enabled: nil) ⇒ Provider
Create a new Apple Push Notification service provider.
-
#create_email(message_id:, subject:, content:, topics: nil, users: nil, targets: nil, cc: nil, bcc: nil, attachments: nil, draft: nil, html: nil, scheduled_at: nil) ⇒ Message
Create a new email message.
-
#create_fcm_provider(provider_id:, name:, service_account_json: nil, enabled: nil) ⇒ Provider
Create a new Firebase Cloud Messaging provider.
-
#create_mailgun_provider(provider_id:, name:, api_key: nil, domain: nil, is_eu_region: nil, from_name: nil, from_email: nil, reply_to_name: nil, reply_to_email: nil, enabled: nil) ⇒ Provider
Create a new Mailgun provider.
-
#create_msg91_provider(provider_id:, name:, template_id: nil, sender_id: nil, auth_key: nil, enabled: nil) ⇒ Provider
Create a new MSG91 provider.
-
#create_push(message_id:, title: nil, body: nil, topics: nil, users: nil, targets: nil, data: nil, action: nil, image: nil, icon: nil, sound: nil, color: nil, tag: nil, badge: nil, draft: nil, scheduled_at: nil, content_available: nil, critical: nil, priority: nil) ⇒ Message
Create a new push notification.
-
#create_resend_provider(provider_id:, name:, api_key: nil, from_name: nil, from_email: nil, reply_to_name: nil, reply_to_email: nil, enabled: nil) ⇒ Provider
Create a new Resend provider.
-
#create_sendgrid_provider(provider_id:, name:, api_key: nil, from_name: nil, from_email: nil, reply_to_name: nil, reply_to_email: nil, enabled: nil) ⇒ Provider
Create a new Sendgrid provider.
-
#create_ses_provider(provider_id:, name:, access_key: nil, secret_key: nil, region: nil, from_name: nil, from_email: nil, reply_to_name: nil, reply_to_email: nil, enabled: nil) ⇒ Provider
Create a new Amazon SES provider.
-
#create_sms(message_id:, content:, topics: nil, users: nil, targets: nil, draft: nil, scheduled_at: nil) ⇒ Message
Create a new SMS message.
-
#create_smtp_provider(provider_id:, name:, host:, port: nil, username: nil, password: nil, encryption: nil, auto_tls: nil, mailer: nil, from_name: nil, from_email: nil, reply_to_name: nil, reply_to_email: nil, enabled: nil) ⇒ Provider
Create a new SMTP provider.
-
#create_subscriber(topic_id:, subscriber_id:, target_id:) ⇒ Subscriber
Create a new subscriber.
-
#create_telesign_provider(provider_id:, name:, from: nil, customer_id: nil, api_key: nil, enabled: nil) ⇒ Provider
Create a new Telesign provider.
-
#create_textmagic_provider(provider_id:, name:, from: nil, username: nil, api_key: nil, enabled: nil) ⇒ Provider
Create a new Textmagic provider.
-
#create_topic(topic_id:, name:, subscribe: nil) ⇒ Topic
Create a new topic.
-
#create_twilio_provider(provider_id:, name:, from: nil, account_sid: nil, auth_token: nil, enabled: nil) ⇒ Provider
Create a new Twilio provider.
-
#create_vonage_provider(provider_id:, name:, from: nil, api_key: nil, api_secret: nil, enabled: nil) ⇒ Provider
Create a new Vonage provider.
-
#delete(message_id:) ⇒ Object
Delete a message.
-
#delete_provider(provider_id:) ⇒ Object
Delete a provider by its unique ID.
-
#delete_subscriber(topic_id:, subscriber_id:) ⇒ Object
Delete a subscriber by its unique ID.
-
#delete_topic(topic_id:) ⇒ Object
Delete a topic by its unique ID.
-
#get_message(message_id:) ⇒ Message
Get a message by its unique ID.
-
#get_provider(provider_id:) ⇒ Provider
Get a provider by its unique ID.
-
#get_subscriber(topic_id:, subscriber_id:) ⇒ Subscriber
Get a subscriber by its unique ID.
-
#get_topic(topic_id:) ⇒ Topic
Get a topic by its unique ID.
-
#initialize(client) ⇒ Messaging
constructor
A new instance of Messaging.
-
#list_messages(queries: nil, search: nil, total: nil) ⇒ MessageList
Get a list of all messages from the current Appwrite project.
-
#list_providers(queries: nil, search: nil, total: nil) ⇒ ProviderList
Get a list of all providers from the current Appwrite project.
-
#list_subscribers(topic_id:, queries: nil, search: nil, total: nil) ⇒ SubscriberList
Get a list of all subscribers from the current Appwrite project.
-
#list_targets(message_id:, queries: nil, total: nil) ⇒ TargetList
Get a list of the targets associated with a message.
-
#list_topics(queries: nil, search: nil, total: nil) ⇒ TopicList
Get a list of all topics from the current Appwrite project.
-
#update_apns_provider(provider_id:, name: nil, enabled: nil, auth_key: nil, auth_key_id: nil, team_id: nil, bundle_id: nil, sandbox: nil) ⇒ Provider
Update a Apple Push Notification service provider by its unique ID.
-
#update_email(message_id:, topics: nil, users: nil, targets: nil, subject: nil, content: nil, draft: nil, html: nil, cc: nil, bcc: nil, scheduled_at: nil, attachments: nil) ⇒ Message
Update an email message by its unique ID.
-
#update_fcm_provider(provider_id:, name: nil, enabled: nil, service_account_json: nil) ⇒ Provider
Update a Firebase Cloud Messaging provider by its unique ID.
-
#update_mailgun_provider(provider_id:, name: nil, api_key: nil, domain: nil, is_eu_region: nil, enabled: nil, from_name: nil, from_email: nil, reply_to_name: nil, reply_to_email: nil) ⇒ Provider
Update a Mailgun provider by its unique ID.
-
#update_msg91_provider(provider_id:, name: nil, enabled: nil, template_id: nil, sender_id: nil, auth_key: nil) ⇒ Provider
Update a MSG91 provider by its unique ID.
-
#update_push(message_id:, topics: nil, users: nil, targets: nil, title: nil, body: nil, data: nil, action: nil, image: nil, icon: nil, sound: nil, color: nil, tag: nil, badge: nil, draft: nil, scheduled_at: nil, content_available: nil, critical: nil, priority: nil) ⇒ Message
Update a push notification by its unique ID.
-
#update_resend_provider(provider_id:, name: nil, enabled: nil, api_key: nil, from_name: nil, from_email: nil, reply_to_name: nil, reply_to_email: nil) ⇒ Provider
Update a Resend provider by its unique ID.
-
#update_sendgrid_provider(provider_id:, name: nil, enabled: nil, api_key: nil, from_name: nil, from_email: nil, reply_to_name: nil, reply_to_email: nil) ⇒ Provider
Update a Sendgrid provider by its unique ID.
-
#update_ses_provider(provider_id:, name: nil, enabled: nil, access_key: nil, secret_key: nil, region: nil, from_name: nil, from_email: nil, reply_to_name: nil, reply_to_email: nil) ⇒ Provider
Update an Amazon SES provider by its unique ID.
-
#update_sms(message_id:, topics: nil, users: nil, targets: nil, content: nil, draft: nil, scheduled_at: nil) ⇒ Message
Update an SMS message by its unique ID.
-
#update_smtp_provider(provider_id:, name: nil, host: nil, port: nil, username: nil, password: nil, encryption: nil, auto_tls: nil, mailer: nil, from_name: nil, from_email: nil, reply_to_name: nil, reply_to_email: nil, enabled: nil) ⇒ Provider
Update a SMTP provider by its unique ID.
-
#update_telesign_provider(provider_id:, name: nil, enabled: nil, customer_id: nil, api_key: nil, from: nil) ⇒ Provider
Update a Telesign provider by its unique ID.
-
#update_textmagic_provider(provider_id:, name: nil, enabled: nil, username: nil, api_key: nil, from: nil) ⇒ Provider
Update a Textmagic provider by its unique ID.
-
#update_topic(topic_id:, name: nil, subscribe: nil) ⇒ Topic
Update a topic by its unique ID.
-
#update_twilio_provider(provider_id:, name: nil, enabled: nil, account_sid: nil, auth_token: nil, from: nil) ⇒ Provider
Update a Twilio provider by its unique ID.
-
#update_vonage_provider(provider_id:, name: nil, enabled: nil, api_key: nil, api_secret: nil, from: nil) ⇒ Provider
Update a Vonage provider by its unique ID.
Constructor Details
#initialize(client) ⇒ Messaging
Returns a new instance of Messaging.
6 7 8 |
# File 'lib/appwrite/services/messaging.rb', line 6 def initialize(client) @client = client end |
Instance Method Details
#create_apns_provider(provider_id:, name:, auth_key: nil, auth_key_id: nil, team_id: nil, bundle_id: nil, sandbox: nil, enabled: nil) ⇒ Provider
Create a new Apple Push Notification service provider.
535 536 537 538 539 540 541 542 543 544 545 546 547 548 549 550 551 552 553 554 555 556 557 558 559 560 561 562 563 564 565 566 567 568 569 570 571 |
# File 'lib/appwrite/services/messaging.rb', line 535 def create_apns_provider(provider_id:, name:, auth_key: nil, auth_key_id: nil, team_id: nil, bundle_id: nil, sandbox: nil, enabled: nil) api_path = '/messaging/providers/apns' if provider_id.nil? raise Appwrite::Exception.new('Missing required parameter: "providerId"') end if name.nil? raise Appwrite::Exception.new('Missing required parameter: "name"') end api_params = { providerId: provider_id, name: name, authKey: auth_key, authKeyId: auth_key_id, teamId: team_id, bundleId: bundle_id, sandbox: sandbox, enabled: enabled, } api_headers = { "X-Appwrite-Project": @client.get_config('project'), "content-type": 'application/json', "accept": 'application/json', } @client.call( method: 'POST', path: api_path, headers: api_headers, params: api_params, response_type: Models::Provider ) end |
#create_email(message_id:, subject:, content:, topics: nil, users: nil, targets: nil, cc: nil, bcc: nil, attachments: nil, draft: nil, html: nil, scheduled_at: nil) ⇒ Message
Create a new email message.
57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 |
# File 'lib/appwrite/services/messaging.rb', line 57 def create_email(message_id:, subject:, content:, topics: nil, users: nil, targets: nil, cc: nil, bcc: nil, attachments: nil, draft: nil, html: nil, scheduled_at: nil) api_path = '/messaging/messages/email' if .nil? raise Appwrite::Exception.new('Missing required parameter: "messageId"') end if subject.nil? raise Appwrite::Exception.new('Missing required parameter: "subject"') end if content.nil? raise Appwrite::Exception.new('Missing required parameter: "content"') end api_params = { messageId: , subject: subject, content: content, topics: topics, users: users, targets: targets, cc: cc, bcc: bcc, attachments: , draft: draft, html: html, scheduledAt: scheduled_at, } api_headers = { "X-Appwrite-Project": @client.get_config('project'), "content-type": 'application/json', "accept": 'application/json', } @client.call( method: 'POST', path: api_path, headers: api_headers, params: api_params, response_type: Models::Message ) end |
#create_fcm_provider(provider_id:, name:, service_account_json: nil, enabled: nil) ⇒ Provider
Create a new Firebase Cloud Messaging provider.
627 628 629 630 631 632 633 634 635 636 637 638 639 640 641 642 643 644 645 646 647 648 649 650 651 652 653 654 655 656 657 658 659 |
# File 'lib/appwrite/services/messaging.rb', line 627 def create_fcm_provider(provider_id:, name:, service_account_json: nil, enabled: nil) api_path = '/messaging/providers/fcm' if provider_id.nil? raise Appwrite::Exception.new('Missing required parameter: "providerId"') end if name.nil? raise Appwrite::Exception.new('Missing required parameter: "name"') end api_params = { providerId: provider_id, name: name, serviceAccountJSON: service_account_json, enabled: enabled, } api_headers = { "X-Appwrite-Project": @client.get_config('project'), "content-type": 'application/json', "accept": 'application/json', } @client.call( method: 'POST', path: api_path, headers: api_headers, params: api_params, response_type: Models::Provider ) end |
#create_mailgun_provider(provider_id:, name:, api_key: nil, domain: nil, is_eu_region: nil, from_name: nil, from_email: nil, reply_to_name: nil, reply_to_email: nil, enabled: nil) ⇒ Provider
Create a new Mailgun provider.
713 714 715 716 717 718 719 720 721 722 723 724 725 726 727 728 729 730 731 732 733 734 735 736 737 738 739 740 741 742 743 744 745 746 747 748 749 750 751 |
# File 'lib/appwrite/services/messaging.rb', line 713 def create_mailgun_provider(provider_id:, name:, api_key: nil, domain: nil, is_eu_region: nil, from_name: nil, from_email: nil, reply_to_name: nil, reply_to_email: nil, enabled: nil) api_path = '/messaging/providers/mailgun' if provider_id.nil? raise Appwrite::Exception.new('Missing required parameter: "providerId"') end if name.nil? raise Appwrite::Exception.new('Missing required parameter: "name"') end api_params = { providerId: provider_id, name: name, apiKey: api_key, domain: domain, isEuRegion: is_eu_region, fromName: from_name, fromEmail: from_email, replyToName: reply_to_name, replyToEmail: reply_to_email, enabled: enabled, } api_headers = { "X-Appwrite-Project": @client.get_config('project'), "content-type": 'application/json', "accept": 'application/json', } @client.call( method: 'POST', path: api_path, headers: api_headers, params: api_params, response_type: Models::Provider ) end |
#create_msg91_provider(provider_id:, name:, template_id: nil, sender_id: nil, auth_key: nil, enabled: nil) ⇒ Provider
Create a new MSG91 provider.
813 814 815 816 817 818 819 820 821 822 823 824 825 826 827 828 829 830 831 832 833 834 835 836 837 838 839 840 841 842 843 844 845 846 847 |
# File 'lib/appwrite/services/messaging.rb', line 813 def create_msg91_provider(provider_id:, name:, template_id: nil, sender_id: nil, auth_key: nil, enabled: nil) api_path = '/messaging/providers/msg91' if provider_id.nil? raise Appwrite::Exception.new('Missing required parameter: "providerId"') end if name.nil? raise Appwrite::Exception.new('Missing required parameter: "name"') end api_params = { providerId: provider_id, name: name, templateId: template_id, senderId: sender_id, authKey: auth_key, enabled: enabled, } api_headers = { "X-Appwrite-Project": @client.get_config('project'), "content-type": 'application/json', "accept": 'application/json', } @client.call( method: 'POST', path: api_path, headers: api_headers, params: api_params, response_type: Models::Provider ) end |
#create_push(message_id:, title: nil, body: nil, topics: nil, users: nil, targets: nil, data: nil, action: nil, image: nil, icon: nil, sound: nil, color: nil, tag: nil, badge: nil, draft: nil, scheduled_at: nil, content_available: nil, critical: nil, priority: nil) ⇒ Message
Create a new push notification.
183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 |
# File 'lib/appwrite/services/messaging.rb', line 183 def create_push(message_id:, title: nil, body: nil, topics: nil, users: nil, targets: nil, data: nil, action: nil, image: nil, icon: nil, sound: nil, color: nil, tag: nil, badge: nil, draft: nil, scheduled_at: nil, content_available: nil, critical: nil, priority: nil) api_path = '/messaging/messages/push' if .nil? raise Appwrite::Exception.new('Missing required parameter: "messageId"') end api_params = { messageId: , title: title, body: body, topics: topics, users: users, targets: targets, data: data, action: action, image: image, icon: icon, sound: sound, color: color, tag: tag, badge: badge, draft: draft, scheduledAt: scheduled_at, contentAvailable: content_available, critical: critical, priority: priority, } api_headers = { "X-Appwrite-Project": @client.get_config('project'), "content-type": 'application/json', "accept": 'application/json', } @client.call( method: 'POST', path: api_path, headers: api_headers, params: api_params, response_type: Models::Message ) end |
#create_resend_provider(provider_id:, name:, api_key: nil, from_name: nil, from_email: nil, reply_to_name: nil, reply_to_email: nil, enabled: nil) ⇒ Provider
Create a new Resend provider.
903 904 905 906 907 908 909 910 911 912 913 914 915 916 917 918 919 920 921 922 923 924 925 926 927 928 929 930 931 932 933 934 935 936 937 938 939 |
# File 'lib/appwrite/services/messaging.rb', line 903 def create_resend_provider(provider_id:, name:, api_key: nil, from_name: nil, from_email: nil, reply_to_name: nil, reply_to_email: nil, enabled: nil) api_path = '/messaging/providers/resend' if provider_id.nil? raise Appwrite::Exception.new('Missing required parameter: "providerId"') end if name.nil? raise Appwrite::Exception.new('Missing required parameter: "name"') end api_params = { providerId: provider_id, name: name, apiKey: api_key, fromName: from_name, fromEmail: from_email, replyToName: reply_to_name, replyToEmail: reply_to_email, enabled: enabled, } api_headers = { "X-Appwrite-Project": @client.get_config('project'), "content-type": 'application/json', "accept": 'application/json', } @client.call( method: 'POST', path: api_path, headers: api_headers, params: api_params, response_type: Models::Provider ) end |
#create_sendgrid_provider(provider_id:, name:, api_key: nil, from_name: nil, from_email: nil, reply_to_name: nil, reply_to_email: nil, enabled: nil) ⇒ Provider
Create a new Sendgrid provider.
999 1000 1001 1002 1003 1004 1005 1006 1007 1008 1009 1010 1011 1012 1013 1014 1015 1016 1017 1018 1019 1020 1021 1022 1023 1024 1025 1026 1027 1028 1029 1030 1031 1032 1033 1034 1035 |
# File 'lib/appwrite/services/messaging.rb', line 999 def create_sendgrid_provider(provider_id:, name:, api_key: nil, from_name: nil, from_email: nil, reply_to_name: nil, reply_to_email: nil, enabled: nil) api_path = '/messaging/providers/sendgrid' if provider_id.nil? raise Appwrite::Exception.new('Missing required parameter: "providerId"') end if name.nil? raise Appwrite::Exception.new('Missing required parameter: "name"') end api_params = { providerId: provider_id, name: name, apiKey: api_key, fromName: from_name, fromEmail: from_email, replyToName: reply_to_name, replyToEmail: reply_to_email, enabled: enabled, } api_headers = { "X-Appwrite-Project": @client.get_config('project'), "content-type": 'application/json', "accept": 'application/json', } @client.call( method: 'POST', path: api_path, headers: api_headers, params: api_params, response_type: Models::Provider ) end |
#create_ses_provider(provider_id:, name:, access_key: nil, secret_key: nil, region: nil, from_name: nil, from_email: nil, reply_to_name: nil, reply_to_email: nil, enabled: nil) ⇒ Provider
Create a new Amazon SES provider.
1097 1098 1099 1100 1101 1102 1103 1104 1105 1106 1107 1108 1109 1110 1111 1112 1113 1114 1115 1116 1117 1118 1119 1120 1121 1122 1123 1124 1125 1126 1127 1128 1129 1130 1131 1132 1133 1134 1135 |
# File 'lib/appwrite/services/messaging.rb', line 1097 def create_ses_provider(provider_id:, name:, access_key: nil, secret_key: nil, region: nil, from_name: nil, from_email: nil, reply_to_name: nil, reply_to_email: nil, enabled: nil) api_path = '/messaging/providers/ses' if provider_id.nil? raise Appwrite::Exception.new('Missing required parameter: "providerId"') end if name.nil? raise Appwrite::Exception.new('Missing required parameter: "name"') end api_params = { providerId: provider_id, name: name, accessKey: access_key, secretKey: secret_key, region: region, fromName: from_name, fromEmail: from_email, replyToName: reply_to_name, replyToEmail: reply_to_email, enabled: enabled, } api_headers = { "X-Appwrite-Project": @client.get_config('project'), "content-type": 'application/json', "accept": 'application/json', } @client.call( method: 'POST', path: api_path, headers: api_headers, params: api_params, response_type: Models::Provider ) end |
#create_sms(message_id:, content:, topics: nil, users: nil, targets: nil, draft: nil, scheduled_at: nil) ⇒ Message
Create a new SMS message.
310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 |
# File 'lib/appwrite/services/messaging.rb', line 310 def create_sms(message_id:, content:, topics: nil, users: nil, targets: nil, draft: nil, scheduled_at: nil) api_path = '/messaging/messages/sms' if .nil? raise Appwrite::Exception.new('Missing required parameter: "messageId"') end if content.nil? raise Appwrite::Exception.new('Missing required parameter: "content"') end api_params = { messageId: , content: content, topics: topics, users: users, targets: targets, draft: draft, scheduledAt: scheduled_at, } api_headers = { "X-Appwrite-Project": @client.get_config('project'), "content-type": 'application/json', "accept": 'application/json', } @client.call( method: 'POST', path: api_path, headers: api_headers, params: api_params, response_type: Models::Message ) end |
#create_smtp_provider(provider_id:, name:, host:, port: nil, username: nil, password: nil, encryption: nil, auto_tls: nil, mailer: nil, from_name: nil, from_email: nil, reply_to_name: nil, reply_to_email: nil, enabled: nil) ⇒ Provider
Create a new SMTP provider.
1205 1206 1207 1208 1209 1210 1211 1212 1213 1214 1215 1216 1217 1218 1219 1220 1221 1222 1223 1224 1225 1226 1227 1228 1229 1230 1231 1232 1233 1234 1235 1236 1237 1238 1239 1240 1241 1242 1243 1244 1245 1246 1247 1248 1249 1250 1251 |
# File 'lib/appwrite/services/messaging.rb', line 1205 def create_smtp_provider(provider_id:, name:, host:, port: nil, username: nil, password: nil, encryption: nil, auto_tls: nil, mailer: nil, from_name: nil, from_email: nil, reply_to_name: nil, reply_to_email: nil, enabled: nil) api_path = '/messaging/providers/smtp' if provider_id.nil? raise Appwrite::Exception.new('Missing required parameter: "providerId"') end if name.nil? raise Appwrite::Exception.new('Missing required parameter: "name"') end if host.nil? raise Appwrite::Exception.new('Missing required parameter: "host"') end api_params = { providerId: provider_id, name: name, host: host, port: port, username: username, password: password, encryption: encryption, autoTLS: auto_tls, mailer: mailer, fromName: from_name, fromEmail: from_email, replyToName: reply_to_name, replyToEmail: reply_to_email, enabled: enabled, } api_headers = { "X-Appwrite-Project": @client.get_config('project'), "content-type": 'application/json', "accept": 'application/json', } @client.call( method: 'POST', path: api_path, headers: api_headers, params: api_params, response_type: Models::Provider ) end |
#create_subscriber(topic_id:, subscriber_id:, target_id:) ⇒ Subscriber
Create a new subscriber.
1939 1940 1941 1942 1943 1944 1945 1946 1947 1948 1949 1950 1951 1952 1953 1954 1955 1956 1957 1958 1959 1960 1961 1962 1963 1964 1965 1966 1967 1968 1969 1970 1971 1972 1973 1974 |
# File 'lib/appwrite/services/messaging.rb', line 1939 def create_subscriber(topic_id:, subscriber_id:, target_id:) api_path = '/messaging/topics/{topicId}/subscribers' .gsub('{topicId}', topic_id) if topic_id.nil? raise Appwrite::Exception.new('Missing required parameter: "topicId"') end if subscriber_id.nil? raise Appwrite::Exception.new('Missing required parameter: "subscriberId"') end if target_id.nil? raise Appwrite::Exception.new('Missing required parameter: "targetId"') end api_params = { subscriberId: subscriber_id, targetId: target_id, } api_headers = { "X-Appwrite-Project": @client.get_config('project'), "content-type": 'application/json', "accept": 'application/json', } @client.call( method: 'POST', path: api_path, headers: api_headers, params: api_params, response_type: Models::Subscriber ) end |
#create_telesign_provider(provider_id:, name:, from: nil, customer_id: nil, api_key: nil, enabled: nil) ⇒ Provider
Create a new Telesign provider.
1321 1322 1323 1324 1325 1326 1327 1328 1329 1330 1331 1332 1333 1334 1335 1336 1337 1338 1339 1340 1341 1342 1343 1344 1345 1346 1347 1348 1349 1350 1351 1352 1353 1354 1355 |
# File 'lib/appwrite/services/messaging.rb', line 1321 def create_telesign_provider(provider_id:, name:, from: nil, customer_id: nil, api_key: nil, enabled: nil) api_path = '/messaging/providers/telesign' if provider_id.nil? raise Appwrite::Exception.new('Missing required parameter: "providerId"') end if name.nil? raise Appwrite::Exception.new('Missing required parameter: "name"') end api_params = { providerId: provider_id, name: name, from: from, customerId: customer_id, apiKey: api_key, enabled: enabled, } api_headers = { "X-Appwrite-Project": @client.get_config('project'), "content-type": 'application/json', "accept": 'application/json', } @client.call( method: 'POST', path: api_path, headers: api_headers, params: api_params, response_type: Models::Provider ) end |
#create_textmagic_provider(provider_id:, name:, from: nil, username: nil, api_key: nil, enabled: nil) ⇒ Provider
Create a new Textmagic provider.
1409 1410 1411 1412 1413 1414 1415 1416 1417 1418 1419 1420 1421 1422 1423 1424 1425 1426 1427 1428 1429 1430 1431 1432 1433 1434 1435 1436 1437 1438 1439 1440 1441 1442 1443 |
# File 'lib/appwrite/services/messaging.rb', line 1409 def create_textmagic_provider(provider_id:, name:, from: nil, username: nil, api_key: nil, enabled: nil) api_path = '/messaging/providers/textmagic' if provider_id.nil? raise Appwrite::Exception.new('Missing required parameter: "providerId"') end if name.nil? raise Appwrite::Exception.new('Missing required parameter: "name"') end api_params = { providerId: provider_id, name: name, from: from, username: username, apiKey: api_key, enabled: enabled, } api_headers = { "X-Appwrite-Project": @client.get_config('project'), "content-type": 'application/json', "accept": 'application/json', } @client.call( method: 'POST', path: api_path, headers: api_headers, params: api_params, response_type: Models::Provider ) end |
#create_topic(topic_id:, name:, subscribe: nil) ⇒ Topic
Create a new topic.
1763 1764 1765 1766 1767 1768 1769 1770 1771 1772 1773 1774 1775 1776 1777 1778 1779 1780 1781 1782 1783 1784 1785 1786 1787 1788 1789 1790 1791 1792 1793 1794 |
# File 'lib/appwrite/services/messaging.rb', line 1763 def create_topic(topic_id:, name:, subscribe: nil) api_path = '/messaging/topics' if topic_id.nil? raise Appwrite::Exception.new('Missing required parameter: "topicId"') end if name.nil? raise Appwrite::Exception.new('Missing required parameter: "name"') end api_params = { topicId: topic_id, name: name, subscribe: subscribe, } api_headers = { "X-Appwrite-Project": @client.get_config('project'), "content-type": 'application/json', "accept": 'application/json', } @client.call( method: 'POST', path: api_path, headers: api_headers, params: api_params, response_type: Models::Topic ) end |
#create_twilio_provider(provider_id:, name:, from: nil, account_sid: nil, auth_token: nil, enabled: nil) ⇒ Provider
Create a new Twilio provider.
1497 1498 1499 1500 1501 1502 1503 1504 1505 1506 1507 1508 1509 1510 1511 1512 1513 1514 1515 1516 1517 1518 1519 1520 1521 1522 1523 1524 1525 1526 1527 1528 1529 1530 1531 |
# File 'lib/appwrite/services/messaging.rb', line 1497 def create_twilio_provider(provider_id:, name:, from: nil, account_sid: nil, auth_token: nil, enabled: nil) api_path = '/messaging/providers/twilio' if provider_id.nil? raise Appwrite::Exception.new('Missing required parameter: "providerId"') end if name.nil? raise Appwrite::Exception.new('Missing required parameter: "name"') end api_params = { providerId: provider_id, name: name, from: from, accountSid: account_sid, authToken: auth_token, enabled: enabled, } api_headers = { "X-Appwrite-Project": @client.get_config('project'), "content-type": 'application/json', "accept": 'application/json', } @client.call( method: 'POST', path: api_path, headers: api_headers, params: api_params, response_type: Models::Provider ) end |
#create_vonage_provider(provider_id:, name:, from: nil, api_key: nil, api_secret: nil, enabled: nil) ⇒ Provider
Create a new Vonage provider.
1585 1586 1587 1588 1589 1590 1591 1592 1593 1594 1595 1596 1597 1598 1599 1600 1601 1602 1603 1604 1605 1606 1607 1608 1609 1610 1611 1612 1613 1614 1615 1616 1617 1618 1619 |
# File 'lib/appwrite/services/messaging.rb', line 1585 def create_vonage_provider(provider_id:, name:, from: nil, api_key: nil, api_secret: nil, enabled: nil) api_path = '/messaging/providers/vonage' if provider_id.nil? raise Appwrite::Exception.new('Missing required parameter: "providerId"') end if name.nil? raise Appwrite::Exception.new('Missing required parameter: "name"') end api_params = { providerId: provider_id, name: name, from: from, apiKey: api_key, apiSecret: api_secret, enabled: enabled, } api_headers = { "X-Appwrite-Project": @client.get_config('project'), "content-type": 'application/json', "accept": 'application/json', } @client.call( method: 'POST', path: api_path, headers: api_headers, params: api_params, response_type: Models::Provider ) end |
#delete(message_id:) ⇒ Object
Delete a message. If the message is not a draft or scheduled, but has been sent, this will not recall the message.
432 433 434 435 436 437 438 439 440 441 442 443 444 445 446 447 448 449 450 451 452 453 454 455 |
# File 'lib/appwrite/services/messaging.rb', line 432 def delete(message_id:) api_path = '/messaging/messages/{messageId}' .gsub('{messageId}', ) if .nil? raise Appwrite::Exception.new('Missing required parameter: "messageId"') end api_params = { } api_headers = { "X-Appwrite-Project": @client.get_config('project'), "content-type": 'application/json', } @client.call( method: 'DELETE', path: api_path, headers: api_headers, params: api_params, ) end |
#delete_provider(provider_id:) ⇒ Object
Delete a provider by its unique ID.
1700 1701 1702 1703 1704 1705 1706 1707 1708 1709 1710 1711 1712 1713 1714 1715 1716 1717 1718 1719 1720 1721 1722 1723 |
# File 'lib/appwrite/services/messaging.rb', line 1700 def delete_provider(provider_id:) api_path = '/messaging/providers/{providerId}' .gsub('{providerId}', provider_id) if provider_id.nil? raise Appwrite::Exception.new('Missing required parameter: "providerId"') end api_params = { } api_headers = { "X-Appwrite-Project": @client.get_config('project'), "content-type": 'application/json', } @client.call( method: 'DELETE', path: api_path, headers: api_headers, params: api_params, ) end |
#delete_subscriber(topic_id:, subscriber_id:) ⇒ Object
Delete a subscriber by its unique ID.
2020 2021 2022 2023 2024 2025 2026 2027 2028 2029 2030 2031 2032 2033 2034 2035 2036 2037 2038 2039 2040 2041 2042 2043 2044 2045 2046 2047 2048 |
# File 'lib/appwrite/services/messaging.rb', line 2020 def delete_subscriber(topic_id:, subscriber_id:) api_path = '/messaging/topics/{topicId}/subscribers/{subscriberId}' .gsub('{topicId}', topic_id) .gsub('{subscriberId}', subscriber_id) if topic_id.nil? raise Appwrite::Exception.new('Missing required parameter: "topicId"') end if subscriber_id.nil? raise Appwrite::Exception.new('Missing required parameter: "subscriberId"') end api_params = { } api_headers = { "X-Appwrite-Project": @client.get_config('project'), "content-type": 'application/json', } @client.call( method: 'DELETE', path: api_path, headers: api_headers, params: api_params, ) end |
#delete_topic(topic_id:) ⇒ Object
Delete a topic by its unique ID.
1870 1871 1872 1873 1874 1875 1876 1877 1878 1879 1880 1881 1882 1883 1884 1885 1886 1887 1888 1889 1890 1891 1892 1893 |
# File 'lib/appwrite/services/messaging.rb', line 1870 def delete_topic(topic_id:) api_path = '/messaging/topics/{topicId}' .gsub('{topicId}', topic_id) if topic_id.nil? raise Appwrite::Exception.new('Missing required parameter: "topicId"') end api_params = { } api_headers = { "X-Appwrite-Project": @client.get_config('project'), "content-type": 'application/json', } @client.call( method: 'DELETE', path: api_path, headers: api_headers, params: api_params, ) end |
#get_message(message_id:) ⇒ Message
Get a message by its unique ID.
400 401 402 403 404 405 406 407 408 409 410 411 412 413 414 415 416 417 418 419 420 421 422 423 424 |
# File 'lib/appwrite/services/messaging.rb', line 400 def (message_id:) api_path = '/messaging/messages/{messageId}' .gsub('{messageId}', ) if .nil? raise Appwrite::Exception.new('Missing required parameter: "messageId"') end api_params = { } api_headers = { "X-Appwrite-Project": @client.get_config('project'), "accept": 'application/json', } @client.call( method: 'GET', path: api_path, headers: api_headers, params: api_params, response_type: Models::Message ) end |
#get_provider(provider_id:) ⇒ Provider
Get a provider by its unique ID.
1669 1670 1671 1672 1673 1674 1675 1676 1677 1678 1679 1680 1681 1682 1683 1684 1685 1686 1687 1688 1689 1690 1691 1692 1693 |
# File 'lib/appwrite/services/messaging.rb', line 1669 def get_provider(provider_id:) api_path = '/messaging/providers/{providerId}' .gsub('{providerId}', provider_id) if provider_id.nil? raise Appwrite::Exception.new('Missing required parameter: "providerId"') end api_params = { } api_headers = { "X-Appwrite-Project": @client.get_config('project'), "accept": 'application/json', } @client.call( method: 'GET', path: api_path, headers: api_headers, params: api_params, response_type: Models::Provider ) end |
#get_subscriber(topic_id:, subscriber_id:) ⇒ Subscriber
Get a subscriber by its unique ID.
1983 1984 1985 1986 1987 1988 1989 1990 1991 1992 1993 1994 1995 1996 1997 1998 1999 2000 2001 2002 2003 2004 2005 2006 2007 2008 2009 2010 2011 2012 |
# File 'lib/appwrite/services/messaging.rb', line 1983 def get_subscriber(topic_id:, subscriber_id:) api_path = '/messaging/topics/{topicId}/subscribers/{subscriberId}' .gsub('{topicId}', topic_id) .gsub('{subscriberId}', subscriber_id) if topic_id.nil? raise Appwrite::Exception.new('Missing required parameter: "topicId"') end if subscriber_id.nil? raise Appwrite::Exception.new('Missing required parameter: "subscriberId"') end api_params = { } api_headers = { "X-Appwrite-Project": @client.get_config('project'), "accept": 'application/json', } @client.call( method: 'GET', path: api_path, headers: api_headers, params: api_params, response_type: Models::Subscriber ) end |
#get_topic(topic_id:) ⇒ Topic
Get a topic by its unique ID.
1802 1803 1804 1805 1806 1807 1808 1809 1810 1811 1812 1813 1814 1815 1816 1817 1818 1819 1820 1821 1822 1823 1824 1825 1826 |
# File 'lib/appwrite/services/messaging.rb', line 1802 def get_topic(topic_id:) api_path = '/messaging/topics/{topicId}' .gsub('{topicId}', topic_id) if topic_id.nil? raise Appwrite::Exception.new('Missing required parameter: "topicId"') end api_params = { } api_headers = { "X-Appwrite-Project": @client.get_config('project'), "accept": 'application/json', } @client.call( method: 'GET', path: api_path, headers: api_headers, params: api_params, response_type: Models::Topic ) end |
#list_messages(queries: nil, search: nil, total: nil) ⇒ MessageList
Get a list of all messages from the current Appwrite project.
17 18 19 20 21 22 23 24 25 26 27 28 29 30 31 32 33 34 35 36 37 38 39 |
# File 'lib/appwrite/services/messaging.rb', line 17 def (queries: nil, search: nil, total: nil) api_path = '/messaging/messages' api_params = { queries: queries, search: search, total: total, } api_headers = { "X-Appwrite-Project": @client.get_config('project'), "accept": 'application/json', } @client.call( method: 'GET', path: api_path, headers: api_headers, params: api_params, response_type: Models::MessageList ) end |
#list_providers(queries: nil, search: nil, total: nil) ⇒ ProviderList
Get a list of all providers from the current Appwrite project.
499 500 501 502 503 504 505 506 507 508 509 510 511 512 513 514 515 516 517 518 519 520 521 |
# File 'lib/appwrite/services/messaging.rb', line 499 def list_providers(queries: nil, search: nil, total: nil) api_path = '/messaging/providers' api_params = { queries: queries, search: search, total: total, } api_headers = { "X-Appwrite-Project": @client.get_config('project'), "accept": 'application/json', } @client.call( method: 'GET', path: api_path, headers: api_headers, params: api_params, response_type: Models::ProviderList ) end |
#list_subscribers(topic_id:, queries: nil, search: nil, total: nil) ⇒ SubscriberList
Get a list of all subscribers from the current Appwrite project.
1903 1904 1905 1906 1907 1908 1909 1910 1911 1912 1913 1914 1915 1916 1917 1918 1919 1920 1921 1922 1923 1924 1925 1926 1927 1928 1929 1930 |
# File 'lib/appwrite/services/messaging.rb', line 1903 def list_subscribers(topic_id:, queries: nil, search: nil, total: nil) api_path = '/messaging/topics/{topicId}/subscribers' .gsub('{topicId}', topic_id) if topic_id.nil? raise Appwrite::Exception.new('Missing required parameter: "topicId"') end api_params = { queries: queries, search: search, total: total, } api_headers = { "X-Appwrite-Project": @client.get_config('project'), "accept": 'application/json', } @client.call( method: 'GET', path: api_path, headers: api_headers, params: api_params, response_type: Models::SubscriberList ) end |
#list_targets(message_id:, queries: nil, total: nil) ⇒ TargetList
Get a list of the targets associated with a message.
464 465 466 467 468 469 470 471 472 473 474 475 476 477 478 479 480 481 482 483 484 485 486 487 488 489 490 |
# File 'lib/appwrite/services/messaging.rb', line 464 def list_targets(message_id:, queries: nil, total: nil) api_path = '/messaging/messages/{messageId}/targets' .gsub('{messageId}', ) if .nil? raise Appwrite::Exception.new('Missing required parameter: "messageId"') end api_params = { queries: queries, total: total, } api_headers = { "X-Appwrite-Project": @client.get_config('project'), "accept": 'application/json', } @client.call( method: 'GET', path: api_path, headers: api_headers, params: api_params, response_type: Models::TargetList ) end |
#list_topics(queries: nil, search: nil, total: nil) ⇒ TopicList
Get a list of all topics from the current Appwrite project.
1732 1733 1734 1735 1736 1737 1738 1739 1740 1741 1742 1743 1744 1745 1746 1747 1748 1749 1750 1751 1752 1753 1754 |
# File 'lib/appwrite/services/messaging.rb', line 1732 def list_topics(queries: nil, search: nil, total: nil) api_path = '/messaging/topics' api_params = { queries: queries, search: search, total: total, } api_headers = { "X-Appwrite-Project": @client.get_config('project'), "accept": 'application/json', } @client.call( method: 'GET', path: api_path, headers: api_headers, params: api_params, response_type: Models::TopicList ) end |
#update_apns_provider(provider_id:, name: nil, enabled: nil, auth_key: nil, auth_key_id: nil, team_id: nil, bundle_id: nil, sandbox: nil) ⇒ Provider
Update a Apple Push Notification service provider by its unique ID.
585 586 587 588 589 590 591 592 593 594 595 596 597 598 599 600 601 602 603 604 605 606 607 608 609 610 611 612 613 614 615 616 617 |
# File 'lib/appwrite/services/messaging.rb', line 585 def update_apns_provider(provider_id:, name: nil, enabled: nil, auth_key: nil, auth_key_id: nil, team_id: nil, bundle_id: nil, sandbox: nil) api_path = '/messaging/providers/apns/{providerId}' .gsub('{providerId}', provider_id) if provider_id.nil? raise Appwrite::Exception.new('Missing required parameter: "providerId"') end api_params = { name: name, enabled: enabled, authKey: auth_key, authKeyId: auth_key_id, teamId: team_id, bundleId: bundle_id, sandbox: sandbox, } api_headers = { "X-Appwrite-Project": @client.get_config('project'), "content-type": 'application/json', "accept": 'application/json', } @client.call( method: 'PATCH', path: api_path, headers: api_headers, params: api_params, response_type: Models::Provider ) end |
#update_email(message_id:, topics: nil, users: nil, targets: nil, subject: nil, content: nil, draft: nil, html: nil, cc: nil, bcc: nil, scheduled_at: nil, attachments: nil) ⇒ Message
Update an email message by its unique ID. This endpoint only works on messages that are in draft status. Messages that are already processing, sent, or failed cannot be updated.
122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 |
# File 'lib/appwrite/services/messaging.rb', line 122 def update_email(message_id:, topics: nil, users: nil, targets: nil, subject: nil, content: nil, draft: nil, html: nil, cc: nil, bcc: nil, scheduled_at: nil, attachments: nil) api_path = '/messaging/messages/email/{messageId}' .gsub('{messageId}', ) if .nil? raise Appwrite::Exception.new('Missing required parameter: "messageId"') end api_params = { topics: topics, users: users, targets: targets, subject: subject, content: content, draft: draft, html: html, cc: cc, bcc: bcc, scheduledAt: scheduled_at, attachments: , } api_headers = { "X-Appwrite-Project": @client.get_config('project'), "content-type": 'application/json', "accept": 'application/json', } @client.call( method: 'PATCH', path: api_path, headers: api_headers, params: api_params, response_type: Models::Message ) end |
#update_fcm_provider(provider_id:, name: nil, enabled: nil, service_account_json: nil) ⇒ Provider
Update a Firebase Cloud Messaging provider by its unique ID.
669 670 671 672 673 674 675 676 677 678 679 680 681 682 683 684 685 686 687 688 689 690 691 692 693 694 695 696 697 |
# File 'lib/appwrite/services/messaging.rb', line 669 def update_fcm_provider(provider_id:, name: nil, enabled: nil, service_account_json: nil) api_path = '/messaging/providers/fcm/{providerId}' .gsub('{providerId}', provider_id) if provider_id.nil? raise Appwrite::Exception.new('Missing required parameter: "providerId"') end api_params = { name: name, enabled: enabled, serviceAccountJSON: service_account_json, } api_headers = { "X-Appwrite-Project": @client.get_config('project'), "content-type": 'application/json', "accept": 'application/json', } @client.call( method: 'PATCH', path: api_path, headers: api_headers, params: api_params, response_type: Models::Provider ) end |
#update_mailgun_provider(provider_id:, name: nil, api_key: nil, domain: nil, is_eu_region: nil, enabled: nil, from_name: nil, from_email: nil, reply_to_name: nil, reply_to_email: nil) ⇒ Provider
Update a Mailgun provider by its unique ID.
767 768 769 770 771 772 773 774 775 776 777 778 779 780 781 782 783 784 785 786 787 788 789 790 791 792 793 794 795 796 797 798 799 800 801 |
# File 'lib/appwrite/services/messaging.rb', line 767 def update_mailgun_provider(provider_id:, name: nil, api_key: nil, domain: nil, is_eu_region: nil, enabled: nil, from_name: nil, from_email: nil, reply_to_name: nil, reply_to_email: nil) api_path = '/messaging/providers/mailgun/{providerId}' .gsub('{providerId}', provider_id) if provider_id.nil? raise Appwrite::Exception.new('Missing required parameter: "providerId"') end api_params = { name: name, apiKey: api_key, domain: domain, isEuRegion: is_eu_region, enabled: enabled, fromName: from_name, fromEmail: from_email, replyToName: reply_to_name, replyToEmail: reply_to_email, } api_headers = { "X-Appwrite-Project": @client.get_config('project'), "content-type": 'application/json', "accept": 'application/json', } @client.call( method: 'PATCH', path: api_path, headers: api_headers, params: api_params, response_type: Models::Provider ) end |
#update_msg91_provider(provider_id:, name: nil, enabled: nil, template_id: nil, sender_id: nil, auth_key: nil) ⇒ Provider
Update a MSG91 provider by its unique ID.
859 860 861 862 863 864 865 866 867 868 869 870 871 872 873 874 875 876 877 878 879 880 881 882 883 884 885 886 887 888 889 |
# File 'lib/appwrite/services/messaging.rb', line 859 def update_msg91_provider(provider_id:, name: nil, enabled: nil, template_id: nil, sender_id: nil, auth_key: nil) api_path = '/messaging/providers/msg91/{providerId}' .gsub('{providerId}', provider_id) if provider_id.nil? raise Appwrite::Exception.new('Missing required parameter: "providerId"') end api_params = { name: name, enabled: enabled, templateId: template_id, senderId: sender_id, authKey: auth_key, } api_headers = { "X-Appwrite-Project": @client.get_config('project'), "content-type": 'application/json', "accept": 'application/json', } @client.call( method: 'PATCH', path: api_path, headers: api_headers, params: api_params, response_type: Models::Provider ) end |
#update_push(message_id:, topics: nil, users: nil, targets: nil, title: nil, body: nil, data: nil, action: nil, image: nil, icon: nil, sound: nil, color: nil, tag: nil, badge: nil, draft: nil, scheduled_at: nil, content_available: nil, critical: nil, priority: nil) ⇒ Message
Update a push notification by its unique ID. This endpoint only works on messages that are in draft status. Messages that are already processing, sent, or failed cannot be updated.
254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 |
# File 'lib/appwrite/services/messaging.rb', line 254 def update_push(message_id:, topics: nil, users: nil, targets: nil, title: nil, body: nil, data: nil, action: nil, image: nil, icon: nil, sound: nil, color: nil, tag: nil, badge: nil, draft: nil, scheduled_at: nil, content_available: nil, critical: nil, priority: nil) api_path = '/messaging/messages/push/{messageId}' .gsub('{messageId}', ) if .nil? raise Appwrite::Exception.new('Missing required parameter: "messageId"') end api_params = { topics: topics, users: users, targets: targets, title: title, body: body, data: data, action: action, image: image, icon: icon, sound: sound, color: color, tag: tag, badge: badge, draft: draft, scheduledAt: scheduled_at, contentAvailable: content_available, critical: critical, priority: priority, } api_headers = { "X-Appwrite-Project": @client.get_config('project'), "content-type": 'application/json', "accept": 'application/json', } @client.call( method: 'PATCH', path: api_path, headers: api_headers, params: api_params, response_type: Models::Message ) end |
#update_resend_provider(provider_id:, name: nil, enabled: nil, api_key: nil, from_name: nil, from_email: nil, reply_to_name: nil, reply_to_email: nil) ⇒ Provider
Update a Resend provider by its unique ID.
953 954 955 956 957 958 959 960 961 962 963 964 965 966 967 968 969 970 971 972 973 974 975 976 977 978 979 980 981 982 983 984 985 |
# File 'lib/appwrite/services/messaging.rb', line 953 def update_resend_provider(provider_id:, name: nil, enabled: nil, api_key: nil, from_name: nil, from_email: nil, reply_to_name: nil, reply_to_email: nil) api_path = '/messaging/providers/resend/{providerId}' .gsub('{providerId}', provider_id) if provider_id.nil? raise Appwrite::Exception.new('Missing required parameter: "providerId"') end api_params = { name: name, enabled: enabled, apiKey: api_key, fromName: from_name, fromEmail: from_email, replyToName: reply_to_name, replyToEmail: reply_to_email, } api_headers = { "X-Appwrite-Project": @client.get_config('project'), "content-type": 'application/json', "accept": 'application/json', } @client.call( method: 'PATCH', path: api_path, headers: api_headers, params: api_params, response_type: Models::Provider ) end |
#update_sendgrid_provider(provider_id:, name: nil, enabled: nil, api_key: nil, from_name: nil, from_email: nil, reply_to_name: nil, reply_to_email: nil) ⇒ Provider
Update a Sendgrid provider by its unique ID.
1049 1050 1051 1052 1053 1054 1055 1056 1057 1058 1059 1060 1061 1062 1063 1064 1065 1066 1067 1068 1069 1070 1071 1072 1073 1074 1075 1076 1077 1078 1079 1080 1081 |
# File 'lib/appwrite/services/messaging.rb', line 1049 def update_sendgrid_provider(provider_id:, name: nil, enabled: nil, api_key: nil, from_name: nil, from_email: nil, reply_to_name: nil, reply_to_email: nil) api_path = '/messaging/providers/sendgrid/{providerId}' .gsub('{providerId}', provider_id) if provider_id.nil? raise Appwrite::Exception.new('Missing required parameter: "providerId"') end api_params = { name: name, enabled: enabled, apiKey: api_key, fromName: from_name, fromEmail: from_email, replyToName: reply_to_name, replyToEmail: reply_to_email, } api_headers = { "X-Appwrite-Project": @client.get_config('project'), "content-type": 'application/json', "accept": 'application/json', } @client.call( method: 'PATCH', path: api_path, headers: api_headers, params: api_params, response_type: Models::Provider ) end |
#update_ses_provider(provider_id:, name: nil, enabled: nil, access_key: nil, secret_key: nil, region: nil, from_name: nil, from_email: nil, reply_to_name: nil, reply_to_email: nil) ⇒ Provider
Update an Amazon SES provider by its unique ID.
1151 1152 1153 1154 1155 1156 1157 1158 1159 1160 1161 1162 1163 1164 1165 1166 1167 1168 1169 1170 1171 1172 1173 1174 1175 1176 1177 1178 1179 1180 1181 1182 1183 1184 1185 |
# File 'lib/appwrite/services/messaging.rb', line 1151 def update_ses_provider(provider_id:, name: nil, enabled: nil, access_key: nil, secret_key: nil, region: nil, from_name: nil, from_email: nil, reply_to_name: nil, reply_to_email: nil) api_path = '/messaging/providers/ses/{providerId}' .gsub('{providerId}', provider_id) if provider_id.nil? raise Appwrite::Exception.new('Missing required parameter: "providerId"') end api_params = { name: name, enabled: enabled, accessKey: access_key, secretKey: secret_key, region: region, fromName: from_name, fromEmail: from_email, replyToName: reply_to_name, replyToEmail: reply_to_email, } api_headers = { "X-Appwrite-Project": @client.get_config('project'), "content-type": 'application/json', "accept": 'application/json', } @client.call( method: 'PATCH', path: api_path, headers: api_headers, params: api_params, response_type: Models::Provider ) end |
#update_sms(message_id:, topics: nil, users: nil, targets: nil, content: nil, draft: nil, scheduled_at: nil) ⇒ Message
Update an SMS message by its unique ID. This endpoint only works on messages that are in draft status. Messages that are already processing, sent, or failed cannot be updated.
361 362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 381 382 383 384 385 386 387 388 389 390 391 392 |
# File 'lib/appwrite/services/messaging.rb', line 361 def update_sms(message_id:, topics: nil, users: nil, targets: nil, content: nil, draft: nil, scheduled_at: nil) api_path = '/messaging/messages/sms/{messageId}' .gsub('{messageId}', ) if .nil? raise Appwrite::Exception.new('Missing required parameter: "messageId"') end api_params = { topics: topics, users: users, targets: targets, content: content, draft: draft, scheduledAt: scheduled_at, } api_headers = { "X-Appwrite-Project": @client.get_config('project'), "content-type": 'application/json', "accept": 'application/json', } @client.call( method: 'PATCH', path: api_path, headers: api_headers, params: api_params, response_type: Models::Message ) end |
#update_smtp_provider(provider_id:, name: nil, host: nil, port: nil, username: nil, password: nil, encryption: nil, auto_tls: nil, mailer: nil, from_name: nil, from_email: nil, reply_to_name: nil, reply_to_email: nil, enabled: nil) ⇒ Provider
Update a SMTP provider by its unique ID.
1271 1272 1273 1274 1275 1276 1277 1278 1279 1280 1281 1282 1283 1284 1285 1286 1287 1288 1289 1290 1291 1292 1293 1294 1295 1296 1297 1298 1299 1300 1301 1302 1303 1304 1305 1306 1307 1308 1309 |
# File 'lib/appwrite/services/messaging.rb', line 1271 def update_smtp_provider(provider_id:, name: nil, host: nil, port: nil, username: nil, password: nil, encryption: nil, auto_tls: nil, mailer: nil, from_name: nil, from_email: nil, reply_to_name: nil, reply_to_email: nil, enabled: nil) api_path = '/messaging/providers/smtp/{providerId}' .gsub('{providerId}', provider_id) if provider_id.nil? raise Appwrite::Exception.new('Missing required parameter: "providerId"') end api_params = { name: name, host: host, port: port, username: username, password: password, encryption: encryption, autoTLS: auto_tls, mailer: mailer, fromName: from_name, fromEmail: from_email, replyToName: reply_to_name, replyToEmail: reply_to_email, enabled: enabled, } api_headers = { "X-Appwrite-Project": @client.get_config('project'), "content-type": 'application/json', "accept": 'application/json', } @client.call( method: 'PATCH', path: api_path, headers: api_headers, params: api_params, response_type: Models::Provider ) end |
#update_telesign_provider(provider_id:, name: nil, enabled: nil, customer_id: nil, api_key: nil, from: nil) ⇒ Provider
Update a Telesign provider by its unique ID.
1367 1368 1369 1370 1371 1372 1373 1374 1375 1376 1377 1378 1379 1380 1381 1382 1383 1384 1385 1386 1387 1388 1389 1390 1391 1392 1393 1394 1395 1396 1397 |
# File 'lib/appwrite/services/messaging.rb', line 1367 def update_telesign_provider(provider_id:, name: nil, enabled: nil, customer_id: nil, api_key: nil, from: nil) api_path = '/messaging/providers/telesign/{providerId}' .gsub('{providerId}', provider_id) if provider_id.nil? raise Appwrite::Exception.new('Missing required parameter: "providerId"') end api_params = { name: name, enabled: enabled, customerId: customer_id, apiKey: api_key, from: from, } api_headers = { "X-Appwrite-Project": @client.get_config('project'), "content-type": 'application/json', "accept": 'application/json', } @client.call( method: 'PATCH', path: api_path, headers: api_headers, params: api_params, response_type: Models::Provider ) end |
#update_textmagic_provider(provider_id:, name: nil, enabled: nil, username: nil, api_key: nil, from: nil) ⇒ Provider
Update a Textmagic provider by its unique ID.
1455 1456 1457 1458 1459 1460 1461 1462 1463 1464 1465 1466 1467 1468 1469 1470 1471 1472 1473 1474 1475 1476 1477 1478 1479 1480 1481 1482 1483 1484 1485 |
# File 'lib/appwrite/services/messaging.rb', line 1455 def update_textmagic_provider(provider_id:, name: nil, enabled: nil, username: nil, api_key: nil, from: nil) api_path = '/messaging/providers/textmagic/{providerId}' .gsub('{providerId}', provider_id) if provider_id.nil? raise Appwrite::Exception.new('Missing required parameter: "providerId"') end api_params = { name: name, enabled: enabled, username: username, apiKey: api_key, from: from, } api_headers = { "X-Appwrite-Project": @client.get_config('project'), "content-type": 'application/json', "accept": 'application/json', } @client.call( method: 'PATCH', path: api_path, headers: api_headers, params: api_params, response_type: Models::Provider ) end |
#update_topic(topic_id:, name: nil, subscribe: nil) ⇒ Topic
Update a topic by its unique ID.
1836 1837 1838 1839 1840 1841 1842 1843 1844 1845 1846 1847 1848 1849 1850 1851 1852 1853 1854 1855 1856 1857 1858 1859 1860 1861 1862 1863 |
# File 'lib/appwrite/services/messaging.rb', line 1836 def update_topic(topic_id:, name: nil, subscribe: nil) api_path = '/messaging/topics/{topicId}' .gsub('{topicId}', topic_id) if topic_id.nil? raise Appwrite::Exception.new('Missing required parameter: "topicId"') end api_params = { name: name, subscribe: subscribe, } api_headers = { "X-Appwrite-Project": @client.get_config('project'), "content-type": 'application/json', "accept": 'application/json', } @client.call( method: 'PATCH', path: api_path, headers: api_headers, params: api_params, response_type: Models::Topic ) end |
#update_twilio_provider(provider_id:, name: nil, enabled: nil, account_sid: nil, auth_token: nil, from: nil) ⇒ Provider
Update a Twilio provider by its unique ID.
1543 1544 1545 1546 1547 1548 1549 1550 1551 1552 1553 1554 1555 1556 1557 1558 1559 1560 1561 1562 1563 1564 1565 1566 1567 1568 1569 1570 1571 1572 1573 |
# File 'lib/appwrite/services/messaging.rb', line 1543 def update_twilio_provider(provider_id:, name: nil, enabled: nil, account_sid: nil, auth_token: nil, from: nil) api_path = '/messaging/providers/twilio/{providerId}' .gsub('{providerId}', provider_id) if provider_id.nil? raise Appwrite::Exception.new('Missing required parameter: "providerId"') end api_params = { name: name, enabled: enabled, accountSid: account_sid, authToken: auth_token, from: from, } api_headers = { "X-Appwrite-Project": @client.get_config('project'), "content-type": 'application/json', "accept": 'application/json', } @client.call( method: 'PATCH', path: api_path, headers: api_headers, params: api_params, response_type: Models::Provider ) end |
#update_vonage_provider(provider_id:, name: nil, enabled: nil, api_key: nil, api_secret: nil, from: nil) ⇒ Provider
Update a Vonage provider by its unique ID.
1631 1632 1633 1634 1635 1636 1637 1638 1639 1640 1641 1642 1643 1644 1645 1646 1647 1648 1649 1650 1651 1652 1653 1654 1655 1656 1657 1658 1659 1660 1661 |
# File 'lib/appwrite/services/messaging.rb', line 1631 def update_vonage_provider(provider_id:, name: nil, enabled: nil, api_key: nil, api_secret: nil, from: nil) api_path = '/messaging/providers/vonage/{providerId}' .gsub('{providerId}', provider_id) if provider_id.nil? raise Appwrite::Exception.new('Missing required parameter: "providerId"') end api_params = { name: name, enabled: enabled, apiKey: api_key, apiSecret: api_secret, from: from, } api_headers = { "X-Appwrite-Project": @client.get_config('project'), "content-type": 'application/json', "accept": 'application/json', } @client.call( method: 'PATCH', path: api_path, headers: api_headers, params: api_params, response_type: Models::Provider ) end |