Class: Appwrite::Users
- Defined in:
- lib/appwrite/services/users.rb
Instance Method Summary collapse
-
#create(user_id:, email: nil, phone: nil, password: nil, name: nil) ⇒ User
Create a new user.
-
#create_argon2_user(user_id:, email:, password:, name: nil) ⇒ User
Create a new user.
-
#create_bcrypt_user(user_id:, email:, password:, name: nil) ⇒ User
Create a new user.
-
#create_jwt(user_id:, session_id: nil, duration: nil) ⇒ Jwt
Use this endpoint to create a JSON Web Token for user by its unique ID.
-
#create_md5_user(user_id:, email:, password:, name: nil) ⇒ User
Create a new user.
-
#create_mfa_recovery_codes(user_id:) ⇒ MfaRecoveryCodes
Generate recovery codes used as backup for MFA flow for User ID.
-
#create_ph_pass_user(user_id:, email:, password:, name: nil) ⇒ User
Create a new user.
-
#create_scrypt_modified_user(user_id:, email:, password:, password_salt:, password_salt_separator:, password_signer_key:, name: nil) ⇒ User
Create a new user.
-
#create_scrypt_user(user_id:, email:, password:, password_salt:, password_cpu:, password_memory:, password_parallel:, password_length:, name: nil) ⇒ User
Create a new user.
-
#create_session(user_id:) ⇒ Session
Creates a session for a user.
-
#create_sha_user(user_id:, email:, password:, password_version: nil, name: nil) ⇒ User
Create a new user.
-
#create_target(user_id:, target_id:, provider_type:, identifier:, provider_id: nil, name: nil) ⇒ Target
Create a messaging target.
-
#create_token(user_id:, length: nil, expire: nil) ⇒ Token
Returns a token with a secret key for creating a session.
-
#delete(user_id:) ⇒ Object
Delete a user by its unique ID, thereby releasing it's ID.
-
#delete_identity(identity_id:) ⇒ Object
Delete an identity by its unique ID.
-
#delete_mfa_authenticator(user_id:, type:) ⇒ Object
Delete an authenticator app.
-
#delete_session(user_id:, session_id:) ⇒ Object
Delete a user sessions by its unique ID.
-
#delete_sessions(user_id:) ⇒ Object
Delete all user's sessions by using the user's unique ID.
-
#delete_target(user_id:, target_id:) ⇒ Object
Delete a messaging target.
-
#get(user_id:) ⇒ User
Get a user by its unique ID.
-
#get_mfa_recovery_codes(user_id:) ⇒ MfaRecoveryCodes
Get recovery codes that can be used as backup for MFA flow by User ID.
-
#get_prefs(user_id:) ⇒ Preferences
Get the user preferences by its unique ID.
-
#get_target(user_id:, target_id:) ⇒ Target
Get a user's push notification target by ID.
-
#initialize(client) ⇒ Users
constructor
A new instance of Users.
-
#list(queries: nil, search: nil, total: nil) ⇒ UserList
Get a list of all the project's users.
-
#list_identities(queries: nil, search: nil, total: nil) ⇒ IdentityList
Get identities for all users.
-
#list_logs(user_id:, queries: nil, total: nil) ⇒ LogList
Get the user activity logs list by its unique ID.
-
#list_memberships(user_id:, queries: nil, search: nil, total: nil) ⇒ MembershipList
Get the user membership list by its unique ID.
-
#list_mfa_factors(user_id:) ⇒ MfaFactors
List the factors available on the account to be used as a MFA challange.
-
#list_sessions(user_id:, total: nil) ⇒ SessionList
Get the user sessions list by its unique ID.
-
#list_targets(user_id:, queries: nil, total: nil) ⇒ TargetList
List the messaging targets that are associated with a user.
-
#update_email(user_id:, email:) ⇒ User
Update the user email by its unique ID.
-
#update_email_verification(user_id:, email_verification:) ⇒ User
Update the user email verification status by its unique ID.
-
#update_impersonator(user_id:, impersonator:) ⇒ User
Enable or disable whether a user can impersonate other users.
-
#update_labels(user_id:, labels:) ⇒ User
Update the user labels by its unique ID.
-
#update_mfa(user_id:, mfa:) ⇒ User
Enable or disable MFA on a user account.
-
#update_mfa_recovery_codes(user_id:) ⇒ MfaRecoveryCodes
Regenerate recovery codes that can be used as backup for MFA flow by User ID.
-
#update_name(user_id:, name:) ⇒ User
Update the user name by its unique ID.
-
#update_password(user_id:, password:) ⇒ User
Update the user password by its unique ID.
-
#update_phone(user_id:, number:) ⇒ User
Update the user phone by its unique ID.
-
#update_phone_verification(user_id:, phone_verification:) ⇒ User
Update the user phone verification status by its unique ID.
-
#update_prefs(user_id:, prefs:) ⇒ Preferences
Update the user preferences by its unique ID.
-
#update_status(user_id:, status:) ⇒ User
Update the user status by its unique ID.
-
#update_target(user_id:, target_id:, identifier: nil, provider_id: nil, name: nil) ⇒ Target
Update a messaging target.
Constructor Details
#initialize(client) ⇒ Users
Returns a new instance of Users.
6 7 8 |
# File 'lib/appwrite/services/users.rb', line 6 def initialize(client) @client = client end |
Instance Method Details
#create(user_id:, email: nil, phone: nil, password: nil, name: nil) ⇒ User
Create a new user.
51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 |
# File 'lib/appwrite/services/users.rb', line 51 def create(user_id:, email: nil, phone: nil, password: nil, name: nil) api_path = '/users' if user_id.nil? raise Appwrite::Exception.new('Missing required parameter: "userId"') end api_params = { userId: user_id, email: email, phone: phone, password: password, name: name, } api_headers = { "X-Appwrite-Project": @client.get_config('project'), "content-type": 'application/json', "accept": 'application/json', } @client.call( method: 'POST', path: api_path, headers: api_headers, params: api_params, response_type: Models::User ) end |
#create_argon2_user(user_id:, email:, password:, name: nil) ⇒ User
Create a new user. Password provided must be hashed with the Argon2 algorithm. Use the POST /users endpoint to create users with a plain text password.
93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 |
# File 'lib/appwrite/services/users.rb', line 93 def create_argon2_user(user_id:, email:, password:, name: nil) api_path = '/users/argon2' if user_id.nil? raise Appwrite::Exception.new('Missing required parameter: "userId"') end if email.nil? raise Appwrite::Exception.new('Missing required parameter: "email"') end if password.nil? raise Appwrite::Exception.new('Missing required parameter: "password"') end api_params = { userId: user_id, email: email, password: password, name: name, } api_headers = { "X-Appwrite-Project": @client.get_config('project'), "content-type": 'application/json', "accept": 'application/json', } @client.call( method: 'POST', path: api_path, headers: api_headers, params: api_params, response_type: Models::User ) end |
#create_bcrypt_user(user_id:, email:, password:, name: nil) ⇒ User
Create a new user. Password provided must be hashed with the Bcrypt algorithm. Use the POST /users endpoint to create users with a plain text password.
142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 |
# File 'lib/appwrite/services/users.rb', line 142 def create_bcrypt_user(user_id:, email:, password:, name: nil) api_path = '/users/bcrypt' if user_id.nil? raise Appwrite::Exception.new('Missing required parameter: "userId"') end if email.nil? raise Appwrite::Exception.new('Missing required parameter: "email"') end if password.nil? raise Appwrite::Exception.new('Missing required parameter: "password"') end api_params = { userId: user_id, email: email, password: password, name: name, } api_headers = { "X-Appwrite-Project": @client.get_config('project'), "content-type": 'application/json', "accept": 'application/json', } @client.call( method: 'POST', path: api_path, headers: api_headers, params: api_params, response_type: Models::User ) end |
#create_jwt(user_id:, session_id: nil, duration: nil) ⇒ Jwt
Use this endpoint to create a JSON Web Token for user by its unique ID. You can use the resulting JWT to authenticate on behalf of the user. The JWT secret will become invalid if the session it uses gets deleted.
693 694 695 696 697 698 699 700 701 702 703 704 705 706 707 708 709 710 711 712 713 714 715 716 717 718 719 720 |
# File 'lib/appwrite/services/users.rb', line 693 def create_jwt(user_id:, session_id: nil, duration: nil) api_path = '/users/{userId}/jwts' .gsub('{userId}', user_id) if user_id.nil? raise Appwrite::Exception.new('Missing required parameter: "userId"') end api_params = { sessionId: session_id, duration: duration, } api_headers = { "X-Appwrite-Project": @client.get_config('project'), "content-type": 'application/json', "accept": 'application/json', } @client.call( method: 'POST', path: api_path, headers: api_headers, params: api_params, response_type: Models::Jwt ) end |
#create_md5_user(user_id:, email:, password:, name: nil) ⇒ User
Create a new user. Password provided must be hashed with the MD5 algorithm. Use the POST /users endpoint to create users with a plain text password.
252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 |
# File 'lib/appwrite/services/users.rb', line 252 def create_md5_user(user_id:, email:, password:, name: nil) api_path = '/users/md5' if user_id.nil? raise Appwrite::Exception.new('Missing required parameter: "userId"') end if email.nil? raise Appwrite::Exception.new('Missing required parameter: "email"') end if password.nil? raise Appwrite::Exception.new('Missing required parameter: "password"') end api_params = { userId: user_id, email: email, password: password, name: name, } api_headers = { "X-Appwrite-Project": @client.get_config('project'), "content-type": 'application/json', "accept": 'application/json', } @client.call( method: 'POST', path: api_path, headers: api_headers, params: api_params, response_type: Models::User ) end |
#create_mfa_recovery_codes(user_id:) ⇒ MfaRecoveryCodes
Generate recovery codes used as backup for MFA flow for User ID. Recovery codes can be used as a MFA verification type in createMfaChallenge method by client SDK.
1019 1020 1021 1022 1023 1024 1025 1026 1027 1028 1029 1030 1031 1032 1033 1034 1035 1036 1037 1038 1039 1040 1041 1042 1043 1044 |
# File 'lib/appwrite/services/users.rb', line 1019 def create_mfa_recovery_codes(user_id:) api_path = '/users/{userId}/mfa/recovery-codes' .gsub('{userId}', user_id) if user_id.nil? raise Appwrite::Exception.new('Missing required parameter: "userId"') end api_params = { } api_headers = { "X-Appwrite-Project": @client.get_config('project'), "content-type": 'application/json', "accept": 'application/json', } @client.call( method: 'PATCH', path: api_path, headers: api_headers, params: api_params, response_type: Models::MfaRecoveryCodes ) end |
#create_ph_pass_user(user_id:, email:, password:, name: nil) ⇒ User
Create a new user. Password provided must be hashed with the PHPass algorithm. Use the POST /users endpoint to create users with a plain text password.
301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 |
# File 'lib/appwrite/services/users.rb', line 301 def create_ph_pass_user(user_id:, email:, password:, name: nil) api_path = '/users/phpass' if user_id.nil? raise Appwrite::Exception.new('Missing required parameter: "userId"') end if email.nil? raise Appwrite::Exception.new('Missing required parameter: "email"') end if password.nil? raise Appwrite::Exception.new('Missing required parameter: "password"') end api_params = { userId: user_id, email: email, password: password, name: name, } api_headers = { "X-Appwrite-Project": @client.get_config('project'), "content-type": 'application/json', "accept": 'application/json', } @client.call( method: 'POST', path: api_path, headers: api_headers, params: api_params, response_type: Models::User ) end |
#create_scrypt_modified_user(user_id:, email:, password:, password_salt:, password_salt_separator:, password_signer_key:, name: nil) ⇒ User
Create a new user. Password provided must be hashed with the Scrypt Modified algorithm. Use the POST /users endpoint to create users with a plain text password.
433 434 435 436 437 438 439 440 441 442 443 444 445 446 447 448 449 450 451 452 453 454 455 456 457 458 459 460 461 462 463 464 465 466 467 468 469 470 471 472 473 474 475 476 477 478 479 480 481 482 483 484 |
# File 'lib/appwrite/services/users.rb', line 433 def create_scrypt_modified_user(user_id:, email:, password:, password_salt:, password_salt_separator:, password_signer_key:, name: nil) api_path = '/users/scrypt-modified' if user_id.nil? raise Appwrite::Exception.new('Missing required parameter: "userId"') end if email.nil? raise Appwrite::Exception.new('Missing required parameter: "email"') end if password.nil? raise Appwrite::Exception.new('Missing required parameter: "password"') end if password_salt.nil? raise Appwrite::Exception.new('Missing required parameter: "passwordSalt"') end if password_salt_separator.nil? raise Appwrite::Exception.new('Missing required parameter: "passwordSaltSeparator"') end if password_signer_key.nil? raise Appwrite::Exception.new('Missing required parameter: "passwordSignerKey"') end api_params = { userId: user_id, email: email, password: password, passwordSalt: password_salt, passwordSaltSeparator: password_salt_separator, passwordSignerKey: password_signer_key, name: name, } api_headers = { "X-Appwrite-Project": @client.get_config('project'), "content-type": 'application/json', "accept": 'application/json', } @client.call( method: 'POST', path: api_path, headers: api_headers, params: api_params, response_type: Models::User ) end |
#create_scrypt_user(user_id:, email:, password:, password_salt:, password_cpu:, password_memory:, password_parallel:, password_length:, name: nil) ⇒ User
Create a new user. Password provided must be hashed with the Scrypt algorithm. Use the POST /users endpoint to create users with a plain text password.
355 356 357 358 359 360 361 362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 381 382 383 384 385 386 387 388 389 390 391 392 393 394 395 396 397 398 399 400 401 402 403 404 405 406 407 408 409 410 411 412 413 414 415 416 |
# File 'lib/appwrite/services/users.rb', line 355 def create_scrypt_user(user_id:, email:, password:, password_salt:, password_cpu:, password_memory:, password_parallel:, password_length:, name: nil) api_path = '/users/scrypt' if user_id.nil? raise Appwrite::Exception.new('Missing required parameter: "userId"') end if email.nil? raise Appwrite::Exception.new('Missing required parameter: "email"') end if password.nil? raise Appwrite::Exception.new('Missing required parameter: "password"') end if password_salt.nil? raise Appwrite::Exception.new('Missing required parameter: "passwordSalt"') end if password_cpu.nil? raise Appwrite::Exception.new('Missing required parameter: "passwordCpu"') end if password_memory.nil? raise Appwrite::Exception.new('Missing required parameter: "passwordMemory"') end if password_parallel.nil? raise Appwrite::Exception.new('Missing required parameter: "passwordParallel"') end if password_length.nil? raise Appwrite::Exception.new('Missing required parameter: "passwordLength"') end api_params = { userId: user_id, email: email, password: password, passwordSalt: password_salt, passwordCpu: password_cpu, passwordMemory: password_memory, passwordParallel: password_parallel, passwordLength: password_length, name: name, } api_headers = { "X-Appwrite-Project": @client.get_config('project'), "content-type": 'application/json', "accept": 'application/json', } @client.call( method: 'POST', path: api_path, headers: api_headers, params: api_params, response_type: Models::User ) end |
#create_session(user_id:) ⇒ Session
Creates a session for a user. Returns an immediately usable session object.
If you want to generate a token for a custom authentication flow, use the POST /users/userId/tokens endpoint.
1274 1275 1276 1277 1278 1279 1280 1281 1282 1283 1284 1285 1286 1287 1288 1289 1290 1291 1292 1293 1294 1295 1296 1297 1298 1299 |
# File 'lib/appwrite/services/users.rb', line 1274 def create_session(user_id:) api_path = '/users/{userId}/sessions' .gsub('{userId}', user_id) if user_id.nil? raise Appwrite::Exception.new('Missing required parameter: "userId"') end api_params = { } api_headers = { "X-Appwrite-Project": @client.get_config('project'), "content-type": 'application/json', "accept": 'application/json', } @client.call( method: 'POST', path: api_path, headers: api_headers, params: api_params, response_type: Models::Session ) end |
#create_sha_user(user_id:, email:, password:, password_version: nil, name: nil) ⇒ User
Create a new user. Password provided must be hashed with the SHA algorithm. Use the POST /users endpoint to create users with a plain text password.
498 499 500 501 502 503 504 505 506 507 508 509 510 511 512 513 514 515 516 517 518 519 520 521 522 523 524 525 526 527 528 529 530 531 532 533 534 535 |
# File 'lib/appwrite/services/users.rb', line 498 def create_sha_user(user_id:, email:, password:, password_version: nil, name: nil) api_path = '/users/sha' if user_id.nil? raise Appwrite::Exception.new('Missing required parameter: "userId"') end if email.nil? raise Appwrite::Exception.new('Missing required parameter: "email"') end if password.nil? raise Appwrite::Exception.new('Missing required parameter: "password"') end api_params = { userId: user_id, email: email, password: password, passwordVersion: password_version, name: name, } api_headers = { "X-Appwrite-Project": @client.get_config('project'), "content-type": 'application/json', "accept": 'application/json', } @client.call( method: 'POST', path: api_path, headers: api_headers, params: api_params, response_type: Models::User ) end |
#create_target(user_id:, target_id:, provider_type:, identifier:, provider_id: nil, name: nil) ⇒ Target
Create a messaging target.
1451 1452 1453 1454 1455 1456 1457 1458 1459 1460 1461 1462 1463 1464 1465 1466 1467 1468 1469 1470 1471 1472 1473 1474 1475 1476 1477 1478 1479 1480 1481 1482 1483 1484 1485 1486 1487 1488 1489 1490 1491 1492 1493 |
# File 'lib/appwrite/services/users.rb', line 1451 def create_target(user_id:, target_id:, provider_type:, identifier:, provider_id: nil, name: nil) api_path = '/users/{userId}/targets' .gsub('{userId}', user_id) if user_id.nil? raise Appwrite::Exception.new('Missing required parameter: "userId"') end if target_id.nil? raise Appwrite::Exception.new('Missing required parameter: "targetId"') end if provider_type.nil? raise Appwrite::Exception.new('Missing required parameter: "providerType"') end if identifier.nil? raise Appwrite::Exception.new('Missing required parameter: "identifier"') end api_params = { targetId: target_id, providerType: provider_type, identifier: identifier, providerId: provider_id, name: name, } api_headers = { "X-Appwrite-Project": @client.get_config('project'), "content-type": 'application/json', "accept": 'application/json', } @client.call( method: 'POST', path: api_path, headers: api_headers, params: api_params, response_type: Models::Target ) end |
#create_token(user_id:, length: nil, expire: nil) ⇒ Token
Returns a token with a secret key for creating a session. Use the user ID and secret and submit a request to the PUT /account/sessions/token endpoint to complete the login process.
1623 1624 1625 1626 1627 1628 1629 1630 1631 1632 1633 1634 1635 1636 1637 1638 1639 1640 1641 1642 1643 1644 1645 1646 1647 1648 1649 1650 |
# File 'lib/appwrite/services/users.rb', line 1623 def create_token(user_id:, length: nil, expire: nil) api_path = '/users/{userId}/tokens' .gsub('{userId}', user_id) if user_id.nil? raise Appwrite::Exception.new('Missing required parameter: "userId"') end api_params = { length: length, expire: expire, } api_headers = { "X-Appwrite-Project": @client.get_config('project'), "content-type": 'application/json', "accept": 'application/json', } @client.call( method: 'POST', path: api_path, headers: api_headers, params: api_params, response_type: Models::Token ) end |
#delete(user_id:) ⇒ Object
Delete a user by its unique ID, thereby releasing it's ID. Since ID is released and can be reused, all user-related resources like documents or storage files should be deleted before user deletion. If you want to keep ID reserved, use the updateStatus endpoint instead.
578 579 580 581 582 583 584 585 586 587 588 589 590 591 592 593 594 595 596 597 598 599 600 601 |
# File 'lib/appwrite/services/users.rb', line 578 def delete(user_id:) api_path = '/users/{userId}' .gsub('{userId}', user_id) if user_id.nil? raise Appwrite::Exception.new('Missing required parameter: "userId"') end api_params = { } api_headers = { "X-Appwrite-Project": @client.get_config('project'), "content-type": 'application/json', } @client.call( method: 'DELETE', path: api_path, headers: api_headers, params: api_params, ) end |
#delete_identity(identity_id:) ⇒ Object
Delete an identity by its unique ID.
216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 |
# File 'lib/appwrite/services/users.rb', line 216 def delete_identity(identity_id:) api_path = '/users/identities/{identityId}' .gsub('{identityId}', identity_id) if identity_id.nil? raise Appwrite::Exception.new('Missing required parameter: "identityId"') end api_params = { } api_headers = { "X-Appwrite-Project": @client.get_config('project'), "content-type": 'application/json', } @client.call( method: 'DELETE', path: api_path, headers: api_headers, params: api_params, ) end |
#delete_mfa_authenticator(user_id:, type:) ⇒ Object
Delete an authenticator app.
881 882 883 884 885 886 887 888 889 890 891 892 893 894 895 896 897 898 899 900 901 902 903 904 905 906 907 908 909 |
# File 'lib/appwrite/services/users.rb', line 881 def delete_mfa_authenticator(user_id:, type:) api_path = '/users/{userId}/mfa/authenticators/{type}' .gsub('{userId}', user_id) .gsub('{type}', type) if user_id.nil? raise Appwrite::Exception.new('Missing required parameter: "userId"') end if type.nil? raise Appwrite::Exception.new('Missing required parameter: "type"') end api_params = { } api_headers = { "X-Appwrite-Project": @client.get_config('project'), "content-type": 'application/json', } @client.call( method: 'DELETE', path: api_path, headers: api_headers, params: api_params, ) end |
#delete_session(user_id:, session_id:) ⇒ Object
Delete a user sessions by its unique ID.
1337 1338 1339 1340 1341 1342 1343 1344 1345 1346 1347 1348 1349 1350 1351 1352 1353 1354 1355 1356 1357 1358 1359 1360 1361 1362 1363 1364 1365 |
# File 'lib/appwrite/services/users.rb', line 1337 def delete_session(user_id:, session_id:) api_path = '/users/{userId}/sessions/{sessionId}' .gsub('{userId}', user_id) .gsub('{sessionId}', session_id) if user_id.nil? raise Appwrite::Exception.new('Missing required parameter: "userId"') end if session_id.nil? raise Appwrite::Exception.new('Missing required parameter: "sessionId"') end api_params = { } api_headers = { "X-Appwrite-Project": @client.get_config('project'), "content-type": 'application/json', } @client.call( method: 'DELETE', path: api_path, headers: api_headers, params: api_params, ) end |
#delete_sessions(user_id:) ⇒ Object
Delete all user's sessions by using the user's unique ID.
1306 1307 1308 1309 1310 1311 1312 1313 1314 1315 1316 1317 1318 1319 1320 1321 1322 1323 1324 1325 1326 1327 1328 1329 |
# File 'lib/appwrite/services/users.rb', line 1306 def delete_sessions(user_id:) api_path = '/users/{userId}/sessions' .gsub('{userId}', user_id) if user_id.nil? raise Appwrite::Exception.new('Missing required parameter: "userId"') end api_params = { } api_headers = { "X-Appwrite-Project": @client.get_config('project'), "content-type": 'application/json', } @client.call( method: 'DELETE', path: api_path, headers: api_headers, params: api_params, ) end |
#delete_target(user_id:, target_id:) ⇒ Object
Delete a messaging target.
1582 1583 1584 1585 1586 1587 1588 1589 1590 1591 1592 1593 1594 1595 1596 1597 1598 1599 1600 1601 1602 1603 1604 1605 1606 1607 1608 1609 1610 |
# File 'lib/appwrite/services/users.rb', line 1582 def delete_target(user_id:, target_id:) api_path = '/users/{userId}/targets/{targetId}' .gsub('{userId}', user_id) .gsub('{targetId}', target_id) if user_id.nil? raise Appwrite::Exception.new('Missing required parameter: "userId"') end if target_id.nil? raise Appwrite::Exception.new('Missing required parameter: "targetId"') end api_params = { } api_headers = { "X-Appwrite-Project": @client.get_config('project'), "content-type": 'application/json', } @client.call( method: 'DELETE', path: api_path, headers: api_headers, params: api_params, ) end |
#get(user_id:) ⇒ User
Get a user by its unique ID.
542 543 544 545 546 547 548 549 550 551 552 553 554 555 556 557 558 559 560 561 562 563 564 565 566 |
# File 'lib/appwrite/services/users.rb', line 542 def get(user_id:) api_path = '/users/{userId}' .gsub('{userId}', user_id) if user_id.nil? raise Appwrite::Exception.new('Missing required parameter: "userId"') end api_params = { } api_headers = { "X-Appwrite-Project": @client.get_config('project'), "accept": 'application/json', } @client.call( method: 'GET', path: api_path, headers: api_headers, params: api_params, response_type: Models::User ) end |
#get_mfa_recovery_codes(user_id:) ⇒ MfaRecoveryCodes
Get recovery codes that can be used as backup for MFA flow by User ID. Before getting codes, they must be generated using createMfaRecoveryCodes method.
950 951 952 953 954 955 956 957 958 959 960 961 962 963 964 965 966 967 968 969 970 971 972 973 974 |
# File 'lib/appwrite/services/users.rb', line 950 def get_mfa_recovery_codes(user_id:) api_path = '/users/{userId}/mfa/recovery-codes' .gsub('{userId}', user_id) if user_id.nil? raise Appwrite::Exception.new('Missing required parameter: "userId"') end api_params = { } api_headers = { "X-Appwrite-Project": @client.get_config('project'), "accept": 'application/json', } @client.call( method: 'GET', path: api_path, headers: api_headers, params: api_params, response_type: Models::MfaRecoveryCodes ) end |
#get_prefs(user_id:) ⇒ Preferences
Get the user preferences by its unique ID.
1165 1166 1167 1168 1169 1170 1171 1172 1173 1174 1175 1176 1177 1178 1179 1180 1181 1182 1183 1184 1185 1186 1187 1188 1189 |
# File 'lib/appwrite/services/users.rb', line 1165 def get_prefs(user_id:) api_path = '/users/{userId}/prefs' .gsub('{userId}', user_id) if user_id.nil? raise Appwrite::Exception.new('Missing required parameter: "userId"') end api_params = { } api_headers = { "X-Appwrite-Project": @client.get_config('project'), "accept": 'application/json', } @client.call( method: 'GET', path: api_path, headers: api_headers, params: api_params, response_type: Models::Preferences ) end |
#get_target(user_id:, target_id:) ⇒ Target
Get a user's push notification target by ID.
1501 1502 1503 1504 1505 1506 1507 1508 1509 1510 1511 1512 1513 1514 1515 1516 1517 1518 1519 1520 1521 1522 1523 1524 1525 1526 1527 1528 1529 1530 |
# File 'lib/appwrite/services/users.rb', line 1501 def get_target(user_id:, target_id:) api_path = '/users/{userId}/targets/{targetId}' .gsub('{userId}', user_id) .gsub('{targetId}', target_id) if user_id.nil? raise Appwrite::Exception.new('Missing required parameter: "userId"') end if target_id.nil? raise Appwrite::Exception.new('Missing required parameter: "targetId"') end api_params = { } api_headers = { "X-Appwrite-Project": @client.get_config('project'), "accept": 'application/json', } @client.call( method: 'GET', path: api_path, headers: api_headers, params: api_params, response_type: Models::Target ) end |
#list(queries: nil, search: nil, total: nil) ⇒ UserList
Get a list of all the project's users. You can use the query params to filter your results.
18 19 20 21 22 23 24 25 26 27 28 29 30 31 32 33 34 35 36 37 38 39 40 |
# File 'lib/appwrite/services/users.rb', line 18 def list(queries: nil, search: nil, total: nil) api_path = '/users' api_params = { queries: queries, search: search, total: total, } api_headers = { "X-Appwrite-Project": @client.get_config('project'), "accept": 'application/json', } @client.call( method: 'GET', path: api_path, headers: api_headers, params: api_params, response_type: Models::UserList ) end |
#list_identities(queries: nil, search: nil, total: nil) ⇒ IdentityList
Get identities for all users.
187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 |
# File 'lib/appwrite/services/users.rb', line 187 def list_identities(queries: nil, search: nil, total: nil) api_path = '/users/identities' api_params = { queries: queries, search: search, total: total, } api_headers = { "X-Appwrite-Project": @client.get_config('project'), "accept": 'application/json', } @client.call( method: 'GET', path: api_path, headers: api_headers, params: api_params, response_type: Models::IdentityList ) end |
#list_logs(user_id:, queries: nil, total: nil) ⇒ LogList
Get the user activity logs list by its unique ID.
772 773 774 775 776 777 778 779 780 781 782 783 784 785 786 787 788 789 790 791 792 793 794 795 796 797 798 |
# File 'lib/appwrite/services/users.rb', line 772 def list_logs(user_id:, queries: nil, total: nil) api_path = '/users/{userId}/logs' .gsub('{userId}', user_id) if user_id.nil? raise Appwrite::Exception.new('Missing required parameter: "userId"') end api_params = { queries: queries, total: total, } api_headers = { "X-Appwrite-Project": @client.get_config('project'), "accept": 'application/json', } @client.call( method: 'GET', path: api_path, headers: api_headers, params: api_params, response_type: Models::LogList ) end |
#list_memberships(user_id:, queries: nil, search: nil, total: nil) ⇒ MembershipList
Get the user membership list by its unique ID.
808 809 810 811 812 813 814 815 816 817 818 819 820 821 822 823 824 825 826 827 828 829 830 831 832 833 834 835 |
# File 'lib/appwrite/services/users.rb', line 808 def list_memberships(user_id:, queries: nil, search: nil, total: nil) api_path = '/users/{userId}/memberships' .gsub('{userId}', user_id) if user_id.nil? raise Appwrite::Exception.new('Missing required parameter: "userId"') end api_params = { queries: queries, search: search, total: total, } api_headers = { "X-Appwrite-Project": @client.get_config('project'), "accept": 'application/json', } @client.call( method: 'GET', path: api_path, headers: api_headers, params: api_params, response_type: Models::MembershipList ) end |
#list_mfa_factors(user_id:) ⇒ MfaFactors
List the factors available on the account to be used as a MFA challange.
916 917 918 919 920 921 922 923 924 925 926 927 928 929 930 931 932 933 934 935 936 937 938 939 940 |
# File 'lib/appwrite/services/users.rb', line 916 def list_mfa_factors(user_id:) api_path = '/users/{userId}/mfa/factors' .gsub('{userId}', user_id) if user_id.nil? raise Appwrite::Exception.new('Missing required parameter: "userId"') end api_params = { } api_headers = { "X-Appwrite-Project": @client.get_config('project'), "accept": 'application/json', } @client.call( method: 'GET', path: api_path, headers: api_headers, params: api_params, response_type: Models::MfaFactors ) end |
#list_sessions(user_id:, total: nil) ⇒ SessionList
Get the user sessions list by its unique ID.
1237 1238 1239 1240 1241 1242 1243 1244 1245 1246 1247 1248 1249 1250 1251 1252 1253 1254 1255 1256 1257 1258 1259 1260 1261 1262 |
# File 'lib/appwrite/services/users.rb', line 1237 def list_sessions(user_id:, total: nil) api_path = '/users/{userId}/sessions' .gsub('{userId}', user_id) if user_id.nil? raise Appwrite::Exception.new('Missing required parameter: "userId"') end api_params = { total: total, } api_headers = { "X-Appwrite-Project": @client.get_config('project'), "accept": 'application/json', } @client.call( method: 'GET', path: api_path, headers: api_headers, params: api_params, response_type: Models::SessionList ) end |
#list_targets(user_id:, queries: nil, total: nil) ⇒ TargetList
List the messaging targets that are associated with a user.
1413 1414 1415 1416 1417 1418 1419 1420 1421 1422 1423 1424 1425 1426 1427 1428 1429 1430 1431 1432 1433 1434 1435 1436 1437 1438 1439 |
# File 'lib/appwrite/services/users.rb', line 1413 def list_targets(user_id:, queries: nil, total: nil) api_path = '/users/{userId}/targets' .gsub('{userId}', user_id) if user_id.nil? raise Appwrite::Exception.new('Missing required parameter: "userId"') end api_params = { queries: queries, total: total, } api_headers = { "X-Appwrite-Project": @client.get_config('project'), "accept": 'application/json', } @client.call( method: 'GET', path: api_path, headers: api_headers, params: api_params, response_type: Models::TargetList ) end |
#update_email(user_id:, email:) ⇒ User
Update the user email by its unique ID.
609 610 611 612 613 614 615 616 617 618 619 620 621 622 623 624 625 626 627 628 629 630 631 632 633 634 635 636 637 638 639 |
# File 'lib/appwrite/services/users.rb', line 609 def update_email(user_id:, email:) api_path = '/users/{userId}/email' .gsub('{userId}', user_id) if user_id.nil? raise Appwrite::Exception.new('Missing required parameter: "userId"') end if email.nil? raise Appwrite::Exception.new('Missing required parameter: "email"') end api_params = { email: email, } api_headers = { "X-Appwrite-Project": @client.get_config('project'), "content-type": 'application/json', "accept": 'application/json', } @client.call( method: 'PATCH', path: api_path, headers: api_headers, params: api_params, response_type: Models::User ) end |
#update_email_verification(user_id:, email_verification:) ⇒ User
Update the user email verification status by its unique ID.
1658 1659 1660 1661 1662 1663 1664 1665 1666 1667 1668 1669 1670 1671 1672 1673 1674 1675 1676 1677 1678 1679 1680 1681 1682 1683 1684 1685 1686 1687 1688 |
# File 'lib/appwrite/services/users.rb', line 1658 def update_email_verification(user_id:, email_verification:) api_path = '/users/{userId}/verification' .gsub('{userId}', user_id) if user_id.nil? raise Appwrite::Exception.new('Missing required parameter: "userId"') end if email_verification.nil? raise Appwrite::Exception.new('Missing required parameter: "emailVerification"') end api_params = { emailVerification: email_verification, } api_headers = { "X-Appwrite-Project": @client.get_config('project'), "content-type": 'application/json', "accept": 'application/json', } @client.call( method: 'PATCH', path: api_path, headers: api_headers, params: api_params, response_type: Models::User ) end |
#update_impersonator(user_id:, impersonator:) ⇒ User
Enable or disable whether a user can impersonate other users. When impersonation headers are used, the request runs as the target user for API behavior, while internal audit logs still attribute the action to the original impersonator and store the impersonated target details only in internal audit payload data.
652 653 654 655 656 657 658 659 660 661 662 663 664 665 666 667 668 669 670 671 672 673 674 675 676 677 678 679 680 681 682 |
# File 'lib/appwrite/services/users.rb', line 652 def update_impersonator(user_id:, impersonator:) api_path = '/users/{userId}/impersonator' .gsub('{userId}', user_id) if user_id.nil? raise Appwrite::Exception.new('Missing required parameter: "userId"') end if impersonator.nil? raise Appwrite::Exception.new('Missing required parameter: "impersonator"') end api_params = { impersonator: impersonator, } api_headers = { "X-Appwrite-Project": @client.get_config('project'), "content-type": 'application/json', "accept": 'application/json', } @client.call( method: 'PATCH', path: api_path, headers: api_headers, params: api_params, response_type: Models::User ) end |
#update_labels(user_id:, labels:) ⇒ User
Update the user labels by its unique ID.
Labels can be used to grant access to resources. While teams are a way for user's to share access to a resource, labels can be defined by the developer to grant access without an invitation. See the Permissions docs for more info.
733 734 735 736 737 738 739 740 741 742 743 744 745 746 747 748 749 750 751 752 753 754 755 756 757 758 759 760 761 762 763 |
# File 'lib/appwrite/services/users.rb', line 733 def update_labels(user_id:, labels:) api_path = '/users/{userId}/labels' .gsub('{userId}', user_id) if user_id.nil? raise Appwrite::Exception.new('Missing required parameter: "userId"') end if labels.nil? raise Appwrite::Exception.new('Missing required parameter: "labels"') end api_params = { labels: labels, } api_headers = { "X-Appwrite-Project": @client.get_config('project'), "content-type": 'application/json', "accept": 'application/json', } @client.call( method: 'PUT', path: api_path, headers: api_headers, params: api_params, response_type: Models::User ) end |
#update_mfa(user_id:, mfa:) ⇒ User
Enable or disable MFA on a user account.
843 844 845 846 847 848 849 850 851 852 853 854 855 856 857 858 859 860 861 862 863 864 865 866 867 868 869 870 871 872 873 |
# File 'lib/appwrite/services/users.rb', line 843 def update_mfa(user_id:, mfa:) api_path = '/users/{userId}/mfa' .gsub('{userId}', user_id) if user_id.nil? raise Appwrite::Exception.new('Missing required parameter: "userId"') end if mfa.nil? raise Appwrite::Exception.new('Missing required parameter: "mfa"') end api_params = { mfa: mfa, } api_headers = { "X-Appwrite-Project": @client.get_config('project'), "content-type": 'application/json', "accept": 'application/json', } @client.call( method: 'PATCH', path: api_path, headers: api_headers, params: api_params, response_type: Models::User ) end |
#update_mfa_recovery_codes(user_id:) ⇒ MfaRecoveryCodes
Regenerate recovery codes that can be used as backup for MFA flow by User ID. Before regenerating codes, they must be first generated using createMfaRecoveryCodes method.
984 985 986 987 988 989 990 991 992 993 994 995 996 997 998 999 1000 1001 1002 1003 1004 1005 1006 1007 1008 1009 |
# File 'lib/appwrite/services/users.rb', line 984 def update_mfa_recovery_codes(user_id:) api_path = '/users/{userId}/mfa/recovery-codes' .gsub('{userId}', user_id) if user_id.nil? raise Appwrite::Exception.new('Missing required parameter: "userId"') end api_params = { } api_headers = { "X-Appwrite-Project": @client.get_config('project'), "content-type": 'application/json', "accept": 'application/json', } @client.call( method: 'PUT', path: api_path, headers: api_headers, params: api_params, response_type: Models::MfaRecoveryCodes ) end |
#update_name(user_id:, name:) ⇒ User
Update the user name by its unique ID.
1052 1053 1054 1055 1056 1057 1058 1059 1060 1061 1062 1063 1064 1065 1066 1067 1068 1069 1070 1071 1072 1073 1074 1075 1076 1077 1078 1079 1080 1081 1082 |
# File 'lib/appwrite/services/users.rb', line 1052 def update_name(user_id:, name:) api_path = '/users/{userId}/name' .gsub('{userId}', user_id) if user_id.nil? raise Appwrite::Exception.new('Missing required parameter: "userId"') end if name.nil? raise Appwrite::Exception.new('Missing required parameter: "name"') end api_params = { name: name, } api_headers = { "X-Appwrite-Project": @client.get_config('project'), "content-type": 'application/json', "accept": 'application/json', } @client.call( method: 'PATCH', path: api_path, headers: api_headers, params: api_params, response_type: Models::User ) end |
#update_password(user_id:, password:) ⇒ User
Update the user password by its unique ID.
1090 1091 1092 1093 1094 1095 1096 1097 1098 1099 1100 1101 1102 1103 1104 1105 1106 1107 1108 1109 1110 1111 1112 1113 1114 1115 1116 1117 1118 1119 1120 |
# File 'lib/appwrite/services/users.rb', line 1090 def update_password(user_id:, password:) api_path = '/users/{userId}/password' .gsub('{userId}', user_id) if user_id.nil? raise Appwrite::Exception.new('Missing required parameter: "userId"') end if password.nil? raise Appwrite::Exception.new('Missing required parameter: "password"') end api_params = { password: password, } api_headers = { "X-Appwrite-Project": @client.get_config('project'), "content-type": 'application/json', "accept": 'application/json', } @client.call( method: 'PATCH', path: api_path, headers: api_headers, params: api_params, response_type: Models::User ) end |
#update_phone(user_id:, number:) ⇒ User
Update the user phone by its unique ID.
1128 1129 1130 1131 1132 1133 1134 1135 1136 1137 1138 1139 1140 1141 1142 1143 1144 1145 1146 1147 1148 1149 1150 1151 1152 1153 1154 1155 1156 1157 1158 |
# File 'lib/appwrite/services/users.rb', line 1128 def update_phone(user_id:, number:) api_path = '/users/{userId}/phone' .gsub('{userId}', user_id) if user_id.nil? raise Appwrite::Exception.new('Missing required parameter: "userId"') end if number.nil? raise Appwrite::Exception.new('Missing required parameter: "number"') end api_params = { number: number, } api_headers = { "X-Appwrite-Project": @client.get_config('project'), "content-type": 'application/json', "accept": 'application/json', } @client.call( method: 'PATCH', path: api_path, headers: api_headers, params: api_params, response_type: Models::User ) end |
#update_phone_verification(user_id:, phone_verification:) ⇒ User
Update the user phone verification status by its unique ID.
1696 1697 1698 1699 1700 1701 1702 1703 1704 1705 1706 1707 1708 1709 1710 1711 1712 1713 1714 1715 1716 1717 1718 1719 1720 1721 1722 1723 1724 1725 1726 |
# File 'lib/appwrite/services/users.rb', line 1696 def update_phone_verification(user_id:, phone_verification:) api_path = '/users/{userId}/verification/phone' .gsub('{userId}', user_id) if user_id.nil? raise Appwrite::Exception.new('Missing required parameter: "userId"') end if phone_verification.nil? raise Appwrite::Exception.new('Missing required parameter: "phoneVerification"') end api_params = { phoneVerification: phone_verification, } api_headers = { "X-Appwrite-Project": @client.get_config('project'), "content-type": 'application/json', "accept": 'application/json', } @client.call( method: 'PATCH', path: api_path, headers: api_headers, params: api_params, response_type: Models::User ) end |
#update_prefs(user_id:, prefs:) ⇒ Preferences
Update the user preferences by its unique ID. The object you pass is stored as is, and replaces any previous value. The maximum allowed prefs size is 64kB and throws error if exceeded.
1199 1200 1201 1202 1203 1204 1205 1206 1207 1208 1209 1210 1211 1212 1213 1214 1215 1216 1217 1218 1219 1220 1221 1222 1223 1224 1225 1226 1227 1228 1229 |
# File 'lib/appwrite/services/users.rb', line 1199 def update_prefs(user_id:, prefs:) api_path = '/users/{userId}/prefs' .gsub('{userId}', user_id) if user_id.nil? raise Appwrite::Exception.new('Missing required parameter: "userId"') end if prefs.nil? raise Appwrite::Exception.new('Missing required parameter: "prefs"') end api_params = { prefs: prefs, } api_headers = { "X-Appwrite-Project": @client.get_config('project'), "content-type": 'application/json', "accept": 'application/json', } @client.call( method: 'PATCH', path: api_path, headers: api_headers, params: api_params, response_type: Models::Preferences ) end |
#update_status(user_id:, status:) ⇒ User
Update the user status by its unique ID. Use this endpoint as an alternative to deleting a user if you want to keep user's ID reserved.
1374 1375 1376 1377 1378 1379 1380 1381 1382 1383 1384 1385 1386 1387 1388 1389 1390 1391 1392 1393 1394 1395 1396 1397 1398 1399 1400 1401 1402 1403 1404 |
# File 'lib/appwrite/services/users.rb', line 1374 def update_status(user_id:, status:) api_path = '/users/{userId}/status' .gsub('{userId}', user_id) if user_id.nil? raise Appwrite::Exception.new('Missing required parameter: "userId"') end if status.nil? raise Appwrite::Exception.new('Missing required parameter: "status"') end api_params = { status: status, } api_headers = { "X-Appwrite-Project": @client.get_config('project'), "content-type": 'application/json', "accept": 'application/json', } @client.call( method: 'PATCH', path: api_path, headers: api_headers, params: api_params, response_type: Models::User ) end |
#update_target(user_id:, target_id:, identifier: nil, provider_id: nil, name: nil) ⇒ Target
Update a messaging target.
1541 1542 1543 1544 1545 1546 1547 1548 1549 1550 1551 1552 1553 1554 1555 1556 1557 1558 1559 1560 1561 1562 1563 1564 1565 1566 1567 1568 1569 1570 1571 1572 1573 1574 |
# File 'lib/appwrite/services/users.rb', line 1541 def update_target(user_id:, target_id:, identifier: nil, provider_id: nil, name: nil) api_path = '/users/{userId}/targets/{targetId}' .gsub('{userId}', user_id) .gsub('{targetId}', target_id) if user_id.nil? raise Appwrite::Exception.new('Missing required parameter: "userId"') end if target_id.nil? raise Appwrite::Exception.new('Missing required parameter: "targetId"') end api_params = { identifier: identifier, providerId: provider_id, name: name, } api_headers = { "X-Appwrite-Project": @client.get_config('project'), "content-type": 'application/json', "accept": 'application/json', } @client.call( method: 'PATCH', path: api_path, headers: api_headers, params: api_params, response_type: Models::Target ) end |