Class: Appwrite::Account
- Defined in:
- lib/appwrite/services/account.rb
Instance Method Summary collapse
-
#create(user_id:, email:, password:, name: nil) ⇒ User
Use this endpoint to allow a new user to register a new account in your project.
-
#create_anonymous_session ⇒ Session
Use this endpoint to allow a new user to register an anonymous account in your project.
-
#create_email_password_session(email:, password:) ⇒ Session
Allow the user to login into their account by providing a valid email and password combination.
-
#create_email_token(user_id:, email:, phrase: nil) ⇒ Token
Sends the user an email with a secret key for creating a session.
-
#create_email_verification(url:) ⇒ Token
Use this endpoint to send a verification message to your user email address to confirm they are the valid owners of that address.
-
#create_jwt(duration: nil) ⇒ Jwt
Use this endpoint to create a JSON Web Token.
-
#create_magic_url_token(user_id:, email:, url: nil, phrase: nil) ⇒ Token
Sends the user an email with a secret key for creating a session.
-
#create_mfa_authenticator(type:) ⇒ MfaType
Add an authenticator app to be used as an MFA factor.
-
#create_mfa_challenge(factor:) ⇒ MfaChallenge
Begin the process of MFA verification after sign-in.
-
#create_mfa_recovery_codes ⇒ MfaRecoveryCodes
Generate recovery codes as backup for MFA flow.
-
#create_o_auth2_token(provider:, success: nil, failure: nil, scopes: nil) ⇒ Object
Allow the user to login to their account using the OAuth2 provider of their choice.
-
#create_phone_token(user_id:, phone:) ⇒ Token
Sends the user an SMS with a secret key for creating a session.
-
#create_phone_verification ⇒ Token
Use this endpoint to send a verification SMS to the currently logged in user.
-
#create_recovery(email:, url:) ⇒ Token
Sends the user an email with a temporary secret key for password reset.
-
#create_session(user_id:, secret:) ⇒ Session
Use this endpoint to create a session from token.
-
#create_verification(url:) ⇒ Token
deprecated
Deprecated.
This API has been deprecated since 1.8.0. Please use
Account.createEmailVerificationinstead. -
#delete_identity(identity_id:) ⇒ Object
Delete an identity by its unique ID.
-
#delete_mfa_authenticator(type:) ⇒ Object
Delete an authenticator for a user by ID.
-
#delete_session(session_id:) ⇒ Object
Logout the user.
-
#delete_sessions ⇒ Object
Delete all sessions from the user account and remove any sessions cookies from the end client.
-
#get ⇒ User
Get the currently logged in user.
-
#get_mfa_recovery_codes ⇒ MfaRecoveryCodes
Get recovery codes that can be used as backup for MFA flow.
-
#get_prefs ⇒ Preferences
Get the preferences as a key-value object for the currently logged in user.
-
#get_session(session_id:) ⇒ Session
Use this endpoint to get a logged in user's session using a Session ID.
-
#initialize(client) ⇒ Account
constructor
A new instance of Account.
-
#list_identities(queries: nil, total: nil) ⇒ IdentityList
Get the list of identities for the currently logged in user.
-
#list_logs(queries: nil, total: nil) ⇒ LogList
Get the list of latest security activity logs for the currently logged in user.
-
#list_mfa_factors ⇒ MfaFactors
List the factors available on the account to be used as a MFA challange.
-
#list_sessions ⇒ SessionList
Get the list of active sessions across different devices for the currently logged in user.
-
#update_email(email:, password:) ⇒ User
Update currently logged in user account email address.
-
#update_email_verification(user_id:, secret:) ⇒ Token
Use this endpoint to complete the user email verification process.
-
#update_magic_url_session(user_id:, secret:) ⇒ Session
deprecated
Deprecated.
This API has been deprecated since 1.6.0. Please use
Account.createSessioninstead. -
#update_mfa(mfa:) ⇒ User
Enable or disable MFA on an account.
-
#update_mfa_authenticator(type:, otp:) ⇒ User
Verify an authenticator app after adding it using the add authenticator method.
-
#update_mfa_challenge(challenge_id:, otp:) ⇒ Session
Complete the MFA challenge by providing the one-time password.
-
#update_mfa_recovery_codes ⇒ MfaRecoveryCodes
Regenerate recovery codes that can be used as backup for MFA flow.
-
#update_name(name:) ⇒ User
Update currently logged in user account name.
-
#update_password(password:, old_password: nil) ⇒ User
Update currently logged in user password.
-
#update_phone(phone:, password:) ⇒ User
Update the currently logged in user's phone number.
-
#update_phone_session(user_id:, secret:) ⇒ Session
deprecated
Deprecated.
This API has been deprecated since 1.6.0. Please use
Account.createSessioninstead. -
#update_phone_verification(user_id:, secret:) ⇒ Token
Use this endpoint to complete the user phone verification process.
-
#update_prefs(prefs:) ⇒ User
Update currently logged in user account preferences.
-
#update_recovery(user_id:, secret:, password:) ⇒ Token
Use this endpoint to complete the user account password reset.
-
#update_session(session_id:) ⇒ Session
Use this endpoint to extend a session's length.
-
#update_status ⇒ User
Block the currently logged in user account.
-
#update_verification(user_id:, secret:) ⇒ Token
deprecated
Deprecated.
This API has been deprecated since 1.8.0. Please use
Account.updateEmailVerificationinstead.
Constructor Details
#initialize(client) ⇒ Account
Returns a new instance of Account.
6 7 8 |
# File 'lib/appwrite/services/account.rb', line 6 def initialize(client) @client = client end |
Instance Method Details
#create(user_id:, email:, password:, name: nil) ⇒ User
Use this endpoint to allow a new user to register a new account in your project. After the user registration completes successfully, you can use the /account/verfication route to start verifying the user email address. To allow the new user to login to their new account, you need to create a new account session.
49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 |
# File 'lib/appwrite/services/account.rb', line 49 def create(user_id:, email:, password:, name: nil) api_path = '/account' if user_id.nil? raise Appwrite::Exception.new('Missing required parameter: "userId"') end if email.nil? raise Appwrite::Exception.new('Missing required parameter: "email"') end if password.nil? raise Appwrite::Exception.new('Missing required parameter: "password"') end api_params = { userId: user_id, email: email, password: password, name: name, } api_headers = { "X-Appwrite-Project": @client.get_config('project'), "content-type": 'application/json', "accept": 'application/json', } @client.call( method: 'POST', path: api_path, headers: api_headers, params: api_params, response_type: Models::User ) end |
#create_anonymous_session ⇒ Session
Use this endpoint to allow a new user to register an anonymous account in your project. This route will also create a new session for the user. To allow the new user to convert an anonymous account to a normal account, you need to update its email and password or create an OAuth2 session.
906 907 908 909 910 911 912 913 914 915 916 917 918 919 920 921 922 923 924 925 926 |
# File 'lib/appwrite/services/account.rb', line 906 def create_anonymous_session() api_path = '/account/sessions/anonymous' api_params = { } api_headers = { "X-Appwrite-Project": @client.get_config('project'), "content-type": 'application/json', "accept": 'application/json', } @client.call( method: 'POST', path: api_path, headers: api_headers, params: api_params, response_type: Models::Session ) end |
#create_email_password_session(email:, password:) ⇒ Session
Allow the user to login into their account by providing a valid email and password combination. This route will create a new session for the user.
A user is limited to 10 active sessions at a time by default. Learn more about session limits.
939 940 941 942 943 944 945 946 947 948 949 950 951 952 953 954 955 956 957 958 959 960 961 962 963 964 965 966 967 968 969 |
# File 'lib/appwrite/services/account.rb', line 939 def create_email_password_session(email:, password:) api_path = '/account/sessions/email' if email.nil? raise Appwrite::Exception.new('Missing required parameter: "email"') end if password.nil? raise Appwrite::Exception.new('Missing required parameter: "password"') end api_params = { email: email, password: password, } api_headers = { "X-Appwrite-Project": @client.get_config('project'), "content-type": 'application/json', "accept": 'application/json', } @client.call( method: 'POST', path: api_path, headers: api_headers, params: api_params, response_type: Models::Session ) end |
#create_email_token(user_id:, email:, phrase: nil) ⇒ Token
Sends the user an email with a secret key for creating a session. If the
email address has never been used, a new account is created using the
provided userId. Otherwise, if the email address is already attached to
an account, the user ID is ignored. Then, the user will receive an
email with the one-time password. Use the returned user ID and secret and
submit a request to the POST
/v1/account/sessions/token
endpoint to complete the login process. The secret sent to the user's email
is valid for 15 minutes.
A user is limited to 10 active sessions at a time by default. Learn more about session limits.
1245 1246 1247 1248 1249 1250 1251 1252 1253 1254 1255 1256 1257 1258 1259 1260 1261 1262 1263 1264 1265 1266 1267 1268 1269 1270 1271 1272 1273 1274 1275 1276 |
# File 'lib/appwrite/services/account.rb', line 1245 def create_email_token(user_id:, email:, phrase: nil) api_path = '/account/tokens/email' if user_id.nil? raise Appwrite::Exception.new('Missing required parameter: "userId"') end if email.nil? raise Appwrite::Exception.new('Missing required parameter: "email"') end api_params = { userId: user_id, email: email, phrase: phrase, } api_headers = { "X-Appwrite-Project": @client.get_config('project'), "content-type": 'application/json', "accept": 'application/json', } @client.call( method: 'POST', path: api_path, headers: api_headers, params: api_params, response_type: Models::Token ) end |
#create_email_verification(url:) ⇒ Token
Use this endpoint to send a verification message to your user email address to confirm they are the valid owners of that address. Both the userId and secret arguments will be passed as query parameters to the URL you have provided to be attached to the verification email. The provided URL should redirect the user back to your app and allow you to complete the verification process by verifying both the userId and secret parameters. Learn more about how to complete the verification process. The verification link sent to the user's email address is valid for 7 days.
Please note that in order to avoid a Redirect Attack, the only valid redirect URLs are the ones from domains you have set when adding your platforms in the console interface.
1449 1450 1451 1452 1453 1454 1455 1456 1457 1458 1459 1460 1461 1462 1463 1464 1465 1466 1467 1468 1469 1470 1471 1472 1473 1474 |
# File 'lib/appwrite/services/account.rb', line 1449 def create_email_verification(url:) api_path = '/account/verifications/email' if url.nil? raise Appwrite::Exception.new('Missing required parameter: "url"') end api_params = { url: url, } api_headers = { "X-Appwrite-Project": @client.get_config('project'), "content-type": 'application/json', "accept": 'application/json', } @client.call( method: 'POST', path: api_path, headers: api_headers, params: api_params, response_type: Models::Token ) end |
#create_jwt(duration: nil) ⇒ Jwt
Use this endpoint to create a JSON Web Token. You can use the resulting JWT to authenticate on behalf of the current user when working with the Appwrite server-side API and SDKs. The JWT secret is valid for 15 minutes from its creation and will be invalid if the user will logout in that time frame.
200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 |
# File 'lib/appwrite/services/account.rb', line 200 def create_jwt(duration: nil) api_path = '/account/jwts' api_params = { duration: duration, } api_headers = { "X-Appwrite-Project": @client.get_config('project'), "content-type": 'application/json', "accept": 'application/json', } @client.call( method: 'POST', path: api_path, headers: api_headers, params: api_params, response_type: Models::Jwt ) end |
#create_magic_url_token(user_id:, email:, url: nil, phrase: nil) ⇒ Token
Sends the user an email with a secret key for creating a session. If the provided user ID has not been registered, a new user will be created. When the user clicks the link in the email, the user is redirected back to the URL you provided with the secret key and userId values attached to the URL query string. Use the query string parameters to submit a request to the POST /v1/account/sessions/token endpoint to complete the login process. The link sent to the user's email address is valid for 1 hour.
A user is limited to 10 active sessions at a time by default. Learn more about session limits.
1299 1300 1301 1302 1303 1304 1305 1306 1307 1308 1309 1310 1311 1312 1313 1314 1315 1316 1317 1318 1319 1320 1321 1322 1323 1324 1325 1326 1327 1328 1329 1330 1331 |
# File 'lib/appwrite/services/account.rb', line 1299 def create_magic_url_token(user_id:, email:, url: nil, phrase: nil) api_path = '/account/tokens/magic-url' if user_id.nil? raise Appwrite::Exception.new('Missing required parameter: "userId"') end if email.nil? raise Appwrite::Exception.new('Missing required parameter: "email"') end api_params = { userId: user_id, email: email, url: url, phrase: phrase, } api_headers = { "X-Appwrite-Project": @client.get_config('project'), "content-type": 'application/json', "accept": 'application/json', } @client.call( method: 'POST', path: api_path, headers: api_headers, params: api_params, response_type: Models::Token ) end |
#create_mfa_authenticator(type:) ⇒ MfaType
Add an authenticator app to be used as an MFA factor. Verify the authenticator using the verify authenticator method.
293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 |
# File 'lib/appwrite/services/account.rb', line 293 def create_mfa_authenticator(type:) api_path = '/account/mfa/authenticators/{type}' .gsub('{type}', type) if type.nil? raise Appwrite::Exception.new('Missing required parameter: "type"') end api_params = { } api_headers = { "X-Appwrite-Project": @client.get_config('project'), "content-type": 'application/json', "accept": 'application/json', } @client.call( method: 'POST', path: api_path, headers: api_headers, params: api_params, response_type: Models::MfaType ) end |
#create_mfa_challenge(factor:) ⇒ MfaChallenge
Begin the process of MFA verification after sign-in. Finish the flow with updateMfaChallenge method.
397 398 399 400 401 402 403 404 405 406 407 408 409 410 411 412 413 414 415 416 417 418 419 420 421 422 |
# File 'lib/appwrite/services/account.rb', line 397 def create_mfa_challenge(factor:) api_path = '/account/mfa/challenges' if factor.nil? raise Appwrite::Exception.new('Missing required parameter: "factor"') end api_params = { factor: factor, } api_headers = { "X-Appwrite-Project": @client.get_config('project'), "content-type": 'application/json', "accept": 'application/json', } @client.call( method: 'POST', path: api_path, headers: api_headers, params: api_params, response_type: Models::MfaChallenge ) end |
#create_mfa_recovery_codes ⇒ MfaRecoveryCodes
Generate recovery codes as backup for MFA flow. It's recommended to generate and show then immediately after user successfully adds their authehticator. Recovery codes can be used as a MFA verification type in createMfaChallenge method.
527 528 529 530 531 532 533 534 535 536 537 538 539 540 541 542 543 544 545 546 547 |
# File 'lib/appwrite/services/account.rb', line 527 def create_mfa_recovery_codes() api_path = '/account/mfa/recovery-codes' api_params = { } api_headers = { "X-Appwrite-Project": @client.get_config('project'), "content-type": 'application/json', "accept": 'application/json', } @client.call( method: 'POST', path: api_path, headers: api_headers, params: api_params, response_type: Models::MfaRecoveryCodes ) end |
#create_o_auth2_token(provider:, success: nil, failure: nil, scopes: nil) ⇒ Object
Allow the user to login to their account using the OAuth2 provider of their choice. Each OAuth2 provider should be enabled from the Appwrite console first. Use the success and failure arguments to provide a redirect URL's back to your app when login is completed.
If authentication succeeds, userId and secret of a token will be
appended to the success URL as query parameters. These can be used to
create a new session using the Create
session
endpoint.
A user is limited to 10 active sessions at a time by default. Learn more about session limits.
1354 1355 1356 1357 1358 1359 1360 1361 1362 1363 1364 1365 1366 1367 1368 1369 1370 1371 1372 1373 1374 1375 1376 1377 1378 1379 1380 1381 |
# File 'lib/appwrite/services/account.rb', line 1354 def create_o_auth2_token(provider:, success: nil, failure: nil, scopes: nil) api_path = '/account/tokens/oauth2/{provider}' .gsub('{provider}', provider) if provider.nil? raise Appwrite::Exception.new('Missing required parameter: "provider"') end api_params = { success: success, failure: failure, scopes: scopes, } api_headers = { "X-Appwrite-Project": @client.get_config('project'), "accept": 'text/html', } @client.call( method: 'GET', path: api_path, headers: api_headers, params: api_params, response_type: "location" ) end |
#create_phone_token(user_id:, phone:) ⇒ Token
Sends the user an SMS with a secret key for creating a session. If the provided user ID has not be registered, a new user will be created. Use the returned user ID and secret and submit a request to the POST /v1/account/sessions/token endpoint to complete the login process. The secret sent to the user's phone is valid for 15 minutes.
A user is limited to 10 active sessions at a time by default. Learn more about session limits.
1398 1399 1400 1401 1402 1403 1404 1405 1406 1407 1408 1409 1410 1411 1412 1413 1414 1415 1416 1417 1418 1419 1420 1421 1422 1423 1424 1425 1426 1427 1428 |
# File 'lib/appwrite/services/account.rb', line 1398 def create_phone_token(user_id:, phone:) api_path = '/account/tokens/phone' if user_id.nil? raise Appwrite::Exception.new('Missing required parameter: "userId"') end if phone.nil? raise Appwrite::Exception.new('Missing required parameter: "phone"') end api_params = { userId: user_id, phone: phone, } api_headers = { "X-Appwrite-Project": @client.get_config('project'), "content-type": 'application/json', "accept": 'application/json', } @client.call( method: 'POST', path: api_path, headers: api_headers, params: api_params, response_type: Models::Token ) end |
#create_phone_verification ⇒ Token
Use this endpoint to send a verification SMS to the currently logged in user. This endpoint is meant for use after updating a user's phone number using the accountUpdatePhone endpoint. Learn more about how to complete the verification process. The verification code sent to the user's phone number is valid for 15 minutes.
1621 1622 1623 1624 1625 1626 1627 1628 1629 1630 1631 1632 1633 1634 1635 1636 1637 1638 1639 1640 1641 |
# File 'lib/appwrite/services/account.rb', line 1621 def create_phone_verification() api_path = '/account/verifications/phone' api_params = { } api_headers = { "X-Appwrite-Project": @client.get_config('project'), "content-type": 'application/json', "accept": 'application/json', } @client.call( method: 'POST', path: api_path, headers: api_headers, params: api_params, response_type: Models::Token ) end |
#create_recovery(email:, url:) ⇒ Token
Sends the user an email with a temporary secret key for password reset. When the user clicks the confirmation link he is redirected back to your app password reset URL with the secret key and email address values attached to the URL query string. Use the query string params to submit a request to the PUT /account/recovery endpoint to complete the process. The verification link sent to the user's email address is valid for 1 hour.
760 761 762 763 764 765 766 767 768 769 770 771 772 773 774 775 776 777 778 779 780 781 782 783 784 785 786 787 788 789 790 |
# File 'lib/appwrite/services/account.rb', line 760 def create_recovery(email:, url:) api_path = '/account/recovery' if email.nil? raise Appwrite::Exception.new('Missing required parameter: "email"') end if url.nil? raise Appwrite::Exception.new('Missing required parameter: "url"') end api_params = { email: email, url: url, } api_headers = { "X-Appwrite-Project": @client.get_config('project'), "content-type": 'application/json', "accept": 'application/json', } @client.call( method: 'POST', path: api_path, headers: api_headers, params: api_params, response_type: Models::Token ) end |
#create_session(user_id:, secret:) ⇒ Session
Use this endpoint to create a session from token. Provide the userId and secret parameters from the successful response of authentication flows initiated by token creation. For example, magic URL and phone login.
1065 1066 1067 1068 1069 1070 1071 1072 1073 1074 1075 1076 1077 1078 1079 1080 1081 1082 1083 1084 1085 1086 1087 1088 1089 1090 1091 1092 1093 1094 1095 |
# File 'lib/appwrite/services/account.rb', line 1065 def create_session(user_id:, secret:) api_path = '/account/sessions/token' if user_id.nil? raise Appwrite::Exception.new('Missing required parameter: "userId"') end if secret.nil? raise Appwrite::Exception.new('Missing required parameter: "secret"') end api_params = { userId: user_id, secret: secret, } api_headers = { "X-Appwrite-Project": @client.get_config('project'), "content-type": 'application/json', "accept": 'application/json', } @client.call( method: 'POST', path: api_path, headers: api_headers, params: api_params, response_type: Models::Session ) end |
#create_verification(url:) ⇒ Token
This API has been deprecated since 1.8.0. Please use Account.createEmailVerification instead.
Use this endpoint to send a verification message to your user email address to confirm they are the valid owners of that address. Both the userId and secret arguments will be passed as query parameters to the URL you have provided to be attached to the verification email. The provided URL should redirect the user back to your app and allow you to complete the verification process by verifying both the userId and secret parameters. Learn more about how to complete the verification process. The verification link sent to the user's email address is valid for 7 days.
Please note that in order to avoid a Redirect Attack, the only valid redirect URLs are the ones from domains you have set when adding your platforms in the console interface.
1498 1499 1500 1501 1502 1503 1504 1505 1506 1507 1508 1509 1510 1511 1512 1513 1514 1515 1516 1517 1518 1519 1520 1521 1522 1523 |
# File 'lib/appwrite/services/account.rb', line 1498 def create_verification(url:) api_path = '/account/verifications/email' if url.nil? raise Appwrite::Exception.new('Missing required parameter: "url"') end api_params = { url: url, } api_headers = { "X-Appwrite-Project": @client.get_config('project'), "content-type": 'application/json', "accept": 'application/json', } @client.call( method: 'POST', path: api_path, headers: api_headers, params: api_params, response_type: Models::Token ) end |
#delete_identity(identity_id:) ⇒ Object
Delete an identity by its unique ID.
166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 |
# File 'lib/appwrite/services/account.rb', line 166 def delete_identity(identity_id:) api_path = '/account/identities/{identityId}' .gsub('{identityId}', identity_id) if identity_id.nil? raise Appwrite::Exception.new('Missing required parameter: "identityId"') end api_params = { } api_headers = { "X-Appwrite-Project": @client.get_config('project'), "content-type": 'application/json', } @client.call( method: 'DELETE', path: api_path, headers: api_headers, params: api_params, ) end |
#delete_mfa_authenticator(type:) ⇒ Object
Delete an authenticator for a user by ID.
365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 381 382 383 384 385 386 387 388 |
# File 'lib/appwrite/services/account.rb', line 365 def delete_mfa_authenticator(type:) api_path = '/account/mfa/authenticators/{type}' .gsub('{type}', type) if type.nil? raise Appwrite::Exception.new('Missing required parameter: "type"') end api_params = { } api_headers = { "X-Appwrite-Project": @client.get_config('project'), "content-type": 'application/json', } @client.call( method: 'DELETE', path: api_path, headers: api_headers, params: api_params, ) end |
#delete_session(session_id:) ⇒ Object
Logout the user. Use 'current' as the session ID to logout on this device, use a session ID to logout on another device. If you're looking to logout the user on all devices, use Delete Sessions instead.
1172 1173 1174 1175 1176 1177 1178 1179 1180 1181 1182 1183 1184 1185 1186 1187 1188 1189 1190 1191 1192 1193 1194 1195 |
# File 'lib/appwrite/services/account.rb', line 1172 def delete_session(session_id:) api_path = '/account/sessions/{sessionId}' .gsub('{sessionId}', session_id) if session_id.nil? raise Appwrite::Exception.new('Missing required parameter: "sessionId"') end api_params = { } api_headers = { "X-Appwrite-Project": @client.get_config('project'), "content-type": 'application/json', } @client.call( method: 'DELETE', path: api_path, headers: api_headers, params: api_params, ) end |
#delete_sessions ⇒ Object
Delete all sessions from the user account and remove any sessions cookies from the end client.
876 877 878 879 880 881 882 883 884 885 886 887 888 889 890 891 892 893 894 |
# File 'lib/appwrite/services/account.rb', line 876 def delete_sessions() api_path = '/account/sessions' api_params = { } api_headers = { "X-Appwrite-Project": @client.get_config('project'), "content-type": 'application/json', } @client.call( method: 'DELETE', path: api_path, headers: api_headers, params: api_params, ) end |
#get ⇒ User
Get the currently logged in user.
14 15 16 17 18 19 20 21 22 23 24 25 26 27 28 29 30 31 32 33 |
# File 'lib/appwrite/services/account.rb', line 14 def get() api_path = '/account' api_params = { } api_headers = { "X-Appwrite-Project": @client.get_config('project'), "accept": 'application/json', } @client.call( method: 'GET', path: api_path, headers: api_headers, params: api_params, response_type: Models::User ) end |
#get_mfa_recovery_codes ⇒ MfaRecoveryCodes
Get recovery codes that can be used as backup for MFA flow. Before getting codes, they must be generated using createMfaRecoveryCodes method. An OTP challenge is required to read recovery codes.
498 499 500 501 502 503 504 505 506 507 508 509 510 511 512 513 514 515 516 517 |
# File 'lib/appwrite/services/account.rb', line 498 def get_mfa_recovery_codes() api_path = '/account/mfa/recovery-codes' api_params = { } api_headers = { "X-Appwrite-Project": @client.get_config('project'), "accept": 'application/json', } @client.call( method: 'GET', path: api_path, headers: api_headers, params: api_params, response_type: Models::MfaRecoveryCodes ) end |
#get_prefs ⇒ Preferences
Get the preferences as a key-value object for the currently logged in user.
692 693 694 695 696 697 698 699 700 701 702 703 704 705 706 707 708 709 710 711 |
# File 'lib/appwrite/services/account.rb', line 692 def get_prefs() api_path = '/account/prefs' api_params = { } api_headers = { "X-Appwrite-Project": @client.get_config('project'), "accept": 'application/json', } @client.call( method: 'GET', path: api_path, headers: api_headers, params: api_params, response_type: Models::Preferences ) end |
#get_session(session_id:) ⇒ Session
Use this endpoint to get a logged in user's session using a Session ID. Inputting 'current' will return the current session being used.
1103 1104 1105 1106 1107 1108 1109 1110 1111 1112 1113 1114 1115 1116 1117 1118 1119 1120 1121 1122 1123 1124 1125 1126 1127 |
# File 'lib/appwrite/services/account.rb', line 1103 def get_session(session_id:) api_path = '/account/sessions/{sessionId}' .gsub('{sessionId}', session_id) if session_id.nil? raise Appwrite::Exception.new('Missing required parameter: "sessionId"') end api_params = { } api_headers = { "X-Appwrite-Project": @client.get_config('project'), "accept": 'application/json', } @client.call( method: 'GET', path: api_path, headers: api_headers, params: api_params, response_type: Models::Session ) end |
#list_identities(queries: nil, total: nil) ⇒ IdentityList
Get the list of identities for the currently logged in user.
138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 |
# File 'lib/appwrite/services/account.rb', line 138 def list_identities(queries: nil, total: nil) api_path = '/account/identities' api_params = { queries: queries, total: total, } api_headers = { "X-Appwrite-Project": @client.get_config('project'), "accept": 'application/json', } @client.call( method: 'GET', path: api_path, headers: api_headers, params: api_params, response_type: Models::IdentityList ) end |
#list_logs(queries: nil, total: nil) ⇒ LogList
Get the list of latest security activity logs for the currently logged in user. Each log returns user IP address, location and date and time of log.
230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 |
# File 'lib/appwrite/services/account.rb', line 230 def list_logs(queries: nil, total: nil) api_path = '/account/logs' api_params = { queries: queries, total: total, } api_headers = { "X-Appwrite-Project": @client.get_config('project'), "accept": 'application/json', } @client.call( method: 'GET', path: api_path, headers: api_headers, params: api_params, response_type: Models::LogList ) end |
#list_mfa_factors ⇒ MfaFactors
List the factors available on the account to be used as a MFA challange.
470 471 472 473 474 475 476 477 478 479 480 481 482 483 484 485 486 487 488 489 |
# File 'lib/appwrite/services/account.rb', line 470 def list_mfa_factors() api_path = '/account/mfa/factors' api_params = { } api_headers = { "X-Appwrite-Project": @client.get_config('project'), "accept": 'application/json', } @client.call( method: 'GET', path: api_path, headers: api_headers, params: api_params, response_type: Models::MfaFactors ) end |
#list_sessions ⇒ SessionList
Get the list of active sessions across different devices for the currently logged in user.
850 851 852 853 854 855 856 857 858 859 860 861 862 863 864 865 866 867 868 869 |
# File 'lib/appwrite/services/account.rb', line 850 def list_sessions() api_path = '/account/sessions' api_params = { } api_headers = { "X-Appwrite-Project": @client.get_config('project'), "accept": 'application/json', } @client.call( method: 'GET', path: api_path, headers: api_headers, params: api_params, response_type: Models::SessionList ) end |
#update_email(email:, password:) ⇒ User
Update currently logged in user account email address. After changing user address, the user confirmation status will get reset. A new confirmation email is not sent automatically however you can use the send confirmation email endpoint again to send the confirmation email. For security measures, user password is required to complete this request. This endpoint can also be used to convert an anonymous account to a normal one, by passing an email address and a new password.
100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 |
# File 'lib/appwrite/services/account.rb', line 100 def update_email(email:, password:) api_path = '/account/email' if email.nil? raise Appwrite::Exception.new('Missing required parameter: "email"') end if password.nil? raise Appwrite::Exception.new('Missing required parameter: "password"') end api_params = { email: email, password: password, } api_headers = { "X-Appwrite-Project": @client.get_config('project'), "content-type": 'application/json', "accept": 'application/json', } @client.call( method: 'PATCH', path: api_path, headers: api_headers, params: api_params, response_type: Models::User ) end |
#update_email_verification(user_id:, secret:) ⇒ Token
Use this endpoint to complete the user email verification process. Use both the userId and secret parameters that were attached to your app URL to verify the user email ownership. If confirmed this route will return a 200 status code.
1534 1535 1536 1537 1538 1539 1540 1541 1542 1543 1544 1545 1546 1547 1548 1549 1550 1551 1552 1553 1554 1555 1556 1557 1558 1559 1560 1561 1562 1563 1564 |
# File 'lib/appwrite/services/account.rb', line 1534 def update_email_verification(user_id:, secret:) api_path = '/account/verifications/email' if user_id.nil? raise Appwrite::Exception.new('Missing required parameter: "userId"') end if secret.nil? raise Appwrite::Exception.new('Missing required parameter: "secret"') end api_params = { userId: user_id, secret: secret, } api_headers = { "X-Appwrite-Project": @client.get_config('project'), "content-type": 'application/json', "accept": 'application/json', } @client.call( method: 'PUT', path: api_path, headers: api_headers, params: api_params, response_type: Models::Token ) end |
#update_magic_url_session(user_id:, secret:) ⇒ Session
This API has been deprecated since 1.6.0. Please use Account.createSession instead.
Use this endpoint to create a session from token. Provide the userId and secret parameters from the successful response of authentication flows initiated by token creation. For example, magic URL and phone login.
982 983 984 985 986 987 988 989 990 991 992 993 994 995 996 997 998 999 1000 1001 1002 1003 1004 1005 1006 1007 1008 1009 1010 1011 1012 |
# File 'lib/appwrite/services/account.rb', line 982 def update_magic_url_session(user_id:, secret:) api_path = '/account/sessions/magic-url' if user_id.nil? raise Appwrite::Exception.new('Missing required parameter: "userId"') end if secret.nil? raise Appwrite::Exception.new('Missing required parameter: "secret"') end api_params = { userId: user_id, secret: secret, } api_headers = { "X-Appwrite-Project": @client.get_config('project'), "content-type": 'application/json', "accept": 'application/json', } @client.call( method: 'PUT', path: api_path, headers: api_headers, params: api_params, response_type: Models::Session ) end |
#update_mfa(mfa:) ⇒ User
Enable or disable MFA on an account.
258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 |
# File 'lib/appwrite/services/account.rb', line 258 def update_mfa(mfa:) api_path = '/account/mfa' if mfa.nil? raise Appwrite::Exception.new('Missing required parameter: "mfa"') end api_params = { mfa: mfa, } api_headers = { "X-Appwrite-Project": @client.get_config('project'), "content-type": 'application/json', "accept": 'application/json', } @client.call( method: 'PATCH', path: api_path, headers: api_headers, params: api_params, response_type: Models::User ) end |
#update_mfa_authenticator(type:, otp:) ⇒ User
Verify an authenticator app after adding it using the add authenticator method.
328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 350 351 352 353 354 355 356 357 358 |
# File 'lib/appwrite/services/account.rb', line 328 def update_mfa_authenticator(type:, otp:) api_path = '/account/mfa/authenticators/{type}' .gsub('{type}', type) if type.nil? raise Appwrite::Exception.new('Missing required parameter: "type"') end if otp.nil? raise Appwrite::Exception.new('Missing required parameter: "otp"') end api_params = { otp: otp, } api_headers = { "X-Appwrite-Project": @client.get_config('project'), "content-type": 'application/json', "accept": 'application/json', } @client.call( method: 'PUT', path: api_path, headers: api_headers, params: api_params, response_type: Models::User ) end |
#update_mfa_challenge(challenge_id:, otp:) ⇒ Session
Complete the MFA challenge by providing the one-time password. Finish the process of MFA verification by providing the one-time password. To begin the flow, use createMfaChallenge method.
434 435 436 437 438 439 440 441 442 443 444 445 446 447 448 449 450 451 452 453 454 455 456 457 458 459 460 461 462 463 464 |
# File 'lib/appwrite/services/account.rb', line 434 def update_mfa_challenge(challenge_id:, otp:) api_path = '/account/mfa/challenges' if challenge_id.nil? raise Appwrite::Exception.new('Missing required parameter: "challengeId"') end if otp.nil? raise Appwrite::Exception.new('Missing required parameter: "otp"') end api_params = { challengeId: challenge_id, otp: otp, } api_headers = { "X-Appwrite-Project": @client.get_config('project'), "content-type": 'application/json', "accept": 'application/json', } @client.call( method: 'PUT', path: api_path, headers: api_headers, params: api_params, response_type: Models::Session ) end |
#update_mfa_recovery_codes ⇒ MfaRecoveryCodes
Regenerate recovery codes that can be used as backup for MFA flow. Before regenerating codes, they must be first generated using createMfaRecoveryCodes method. An OTP challenge is required to regenreate recovery codes.
556 557 558 559 560 561 562 563 564 565 566 567 568 569 570 571 572 573 574 575 576 |
# File 'lib/appwrite/services/account.rb', line 556 def update_mfa_recovery_codes() api_path = '/account/mfa/recovery-codes' api_params = { } api_headers = { "X-Appwrite-Project": @client.get_config('project'), "content-type": 'application/json', "accept": 'application/json', } @client.call( method: 'PATCH', path: api_path, headers: api_headers, params: api_params, response_type: Models::MfaRecoveryCodes ) end |
#update_name(name:) ⇒ User
Update currently logged in user account name.
583 584 585 586 587 588 589 590 591 592 593 594 595 596 597 598 599 600 601 602 603 604 605 606 607 608 |
# File 'lib/appwrite/services/account.rb', line 583 def update_name(name:) api_path = '/account/name' if name.nil? raise Appwrite::Exception.new('Missing required parameter: "name"') end api_params = { name: name, } api_headers = { "X-Appwrite-Project": @client.get_config('project'), "content-type": 'application/json', "accept": 'application/json', } @client.call( method: 'PATCH', path: api_path, headers: api_headers, params: api_params, response_type: Models::User ) end |
#update_password(password:, old_password: nil) ⇒ User
Update currently logged in user password. For validation, user is required to pass in the new password, and the old password. For users created with OAuth, Team Invites and Magic URL, oldPassword is optional.
618 619 620 621 622 623 624 625 626 627 628 629 630 631 632 633 634 635 636 637 638 639 640 641 642 643 644 |
# File 'lib/appwrite/services/account.rb', line 618 def update_password(password:, old_password: nil) api_path = '/account/password' if password.nil? raise Appwrite::Exception.new('Missing required parameter: "password"') end api_params = { password: password, oldPassword: old_password, } api_headers = { "X-Appwrite-Project": @client.get_config('project'), "content-type": 'application/json', "accept": 'application/json', } @client.call( method: 'PATCH', path: api_path, headers: api_headers, params: api_params, response_type: Models::User ) end |
#update_phone(phone:, password:) ⇒ User
Update the currently logged in user's phone number. After updating the phone number, the phone verification status will be reset. A confirmation SMS is not sent automatically, however you can use the POST /account/verification/phone endpoint to send a confirmation SMS.
656 657 658 659 660 661 662 663 664 665 666 667 668 669 670 671 672 673 674 675 676 677 678 679 680 681 682 683 684 685 686 |
# File 'lib/appwrite/services/account.rb', line 656 def update_phone(phone:, password:) api_path = '/account/phone' if phone.nil? raise Appwrite::Exception.new('Missing required parameter: "phone"') end if password.nil? raise Appwrite::Exception.new('Missing required parameter: "password"') end api_params = { phone: phone, password: password, } api_headers = { "X-Appwrite-Project": @client.get_config('project'), "content-type": 'application/json', "accept": 'application/json', } @client.call( method: 'PATCH', path: api_path, headers: api_headers, params: api_params, response_type: Models::User ) end |
#update_phone_session(user_id:, secret:) ⇒ Session
This API has been deprecated since 1.6.0. Please use Account.createSession instead.
Use this endpoint to create a session from token. Provide the userId and secret parameters from the successful response of authentication flows initiated by token creation. For example, magic URL and phone login.
1025 1026 1027 1028 1029 1030 1031 1032 1033 1034 1035 1036 1037 1038 1039 1040 1041 1042 1043 1044 1045 1046 1047 1048 1049 1050 1051 1052 1053 1054 1055 |
# File 'lib/appwrite/services/account.rb', line 1025 def update_phone_session(user_id:, secret:) api_path = '/account/sessions/phone' if user_id.nil? raise Appwrite::Exception.new('Missing required parameter: "userId"') end if secret.nil? raise Appwrite::Exception.new('Missing required parameter: "secret"') end api_params = { userId: user_id, secret: secret, } api_headers = { "X-Appwrite-Project": @client.get_config('project'), "content-type": 'application/json', "accept": 'application/json', } @client.call( method: 'PUT', path: api_path, headers: api_headers, params: api_params, response_type: Models::Session ) end |
#update_phone_verification(user_id:, secret:) ⇒ Token
Use this endpoint to complete the user phone verification process. Use the userId and secret that were sent to your user's phone number to verify the user email ownership. If confirmed this route will return a 200 status code.
1652 1653 1654 1655 1656 1657 1658 1659 1660 1661 1662 1663 1664 1665 1666 1667 1668 1669 1670 1671 1672 1673 1674 1675 1676 1677 1678 1679 1680 1681 1682 |
# File 'lib/appwrite/services/account.rb', line 1652 def update_phone_verification(user_id:, secret:) api_path = '/account/verifications/phone' if user_id.nil? raise Appwrite::Exception.new('Missing required parameter: "userId"') end if secret.nil? raise Appwrite::Exception.new('Missing required parameter: "secret"') end api_params = { userId: user_id, secret: secret, } api_headers = { "X-Appwrite-Project": @client.get_config('project'), "content-type": 'application/json', "accept": 'application/json', } @client.call( method: 'PUT', path: api_path, headers: api_headers, params: api_params, response_type: Models::Token ) end |
#update_prefs(prefs:) ⇒ User
Update currently logged in user account preferences. The object you pass is stored as is, and replaces any previous value. The maximum allowed prefs size is 64kB and throws error if exceeded.
720 721 722 723 724 725 726 727 728 729 730 731 732 733 734 735 736 737 738 739 740 741 742 743 744 745 |
# File 'lib/appwrite/services/account.rb', line 720 def update_prefs(prefs:) api_path = '/account/prefs' if prefs.nil? raise Appwrite::Exception.new('Missing required parameter: "prefs"') end api_params = { prefs: prefs, } api_headers = { "X-Appwrite-Project": @client.get_config('project'), "content-type": 'application/json', "accept": 'application/json', } @client.call( method: 'PATCH', path: api_path, headers: api_headers, params: api_params, response_type: Models::User ) end |
#update_recovery(user_id:, secret:, password:) ⇒ Token
Use this endpoint to complete the user account password reset. Both the userId and secret arguments will be passed as query parameters to the redirect URL you have provided when sending your request to the POST /account/recovery endpoint.
Please note that in order to avoid a Redirect Attack the only valid redirect URLs are the ones from domains you have set when adding your platforms in the console interface.
808 809 810 811 812 813 814 815 816 817 818 819 820 821 822 823 824 825 826 827 828 829 830 831 832 833 834 835 836 837 838 839 840 841 842 843 |
# File 'lib/appwrite/services/account.rb', line 808 def update_recovery(user_id:, secret:, password:) api_path = '/account/recovery' if user_id.nil? raise Appwrite::Exception.new('Missing required parameter: "userId"') end if secret.nil? raise Appwrite::Exception.new('Missing required parameter: "secret"') end if password.nil? raise Appwrite::Exception.new('Missing required parameter: "password"') end api_params = { userId: user_id, secret: secret, password: password, } api_headers = { "X-Appwrite-Project": @client.get_config('project'), "content-type": 'application/json', "accept": 'application/json', } @client.call( method: 'PUT', path: api_path, headers: api_headers, params: api_params, response_type: Models::Token ) end |
#update_session(session_id:) ⇒ Session
Use this endpoint to extend a session's length. Extending a session is useful when session expiry is short. If the session was created using an OAuth provider, this endpoint refreshes the access token from the provider.
1136 1137 1138 1139 1140 1141 1142 1143 1144 1145 1146 1147 1148 1149 1150 1151 1152 1153 1154 1155 1156 1157 1158 1159 1160 1161 |
# File 'lib/appwrite/services/account.rb', line 1136 def update_session(session_id:) api_path = '/account/sessions/{sessionId}' .gsub('{sessionId}', session_id) if session_id.nil? raise Appwrite::Exception.new('Missing required parameter: "sessionId"') end api_params = { } api_headers = { "X-Appwrite-Project": @client.get_config('project'), "content-type": 'application/json', "accept": 'application/json', } @client.call( method: 'PATCH', path: api_path, headers: api_headers, params: api_params, response_type: Models::Session ) end |
#update_status ⇒ User
Block the currently logged in user account. Behind the scene, the user record is not deleted but permanently blocked from any access. To completely delete a user, use the Users API instead.
1203 1204 1205 1206 1207 1208 1209 1210 1211 1212 1213 1214 1215 1216 1217 1218 1219 1220 1221 1222 1223 |
# File 'lib/appwrite/services/account.rb', line 1203 def update_status() api_path = '/account/status' api_params = { } api_headers = { "X-Appwrite-Project": @client.get_config('project'), "content-type": 'application/json', "accept": 'application/json', } @client.call( method: 'PATCH', path: api_path, headers: api_headers, params: api_params, response_type: Models::User ) end |
#update_verification(user_id:, secret:) ⇒ Token
This API has been deprecated since 1.8.0. Please use Account.updateEmailVerification instead.
Use this endpoint to complete the user email verification process. Use both the userId and secret parameters that were attached to your app URL to verify the user email ownership. If confirmed this route will return a 200 status code.
1578 1579 1580 1581 1582 1583 1584 1585 1586 1587 1588 1589 1590 1591 1592 1593 1594 1595 1596 1597 1598 1599 1600 1601 1602 1603 1604 1605 1606 1607 1608 |
# File 'lib/appwrite/services/account.rb', line 1578 def update_verification(user_id:, secret:) api_path = '/account/verifications/email' if user_id.nil? raise Appwrite::Exception.new('Missing required parameter: "userId"') end if secret.nil? raise Appwrite::Exception.new('Missing required parameter: "secret"') end api_params = { userId: user_id, secret: secret, } api_headers = { "X-Appwrite-Project": @client.get_config('project'), "content-type": 'application/json', "accept": 'application/json', } @client.call( method: 'PUT', path: api_path, headers: api_headers, params: api_params, response_type: Models::Token ) end |