Class: Appwrite::Client
- Inherits:
-
Object
- Object
- Appwrite::Client
- Defined in:
- lib/appwrite/client.rb
Instance Method Summary collapse
-
#add_header(key, value) ⇒ self
Add Header.
-
#call(method:, path: '', headers: {}, params: {}, response_type: nil) ⇒ self
Send the HTTP request.
- #chunked_upload(path:, headers:, params:, param_name: '', id_param_name: nil, on_progress: nil, response_type: nil) ⇒ Object
-
#get_headers ⇒ Hash
Get request headers.
-
#initialize ⇒ Client
constructor
A new instance of Client.
-
#set_cookie(value) ⇒ self
Set Cookie.
-
#set_dev_key(value) ⇒ self
Set DevKey.
-
#set_endpoint(endpoint) ⇒ self
Set endpoint.
-
#set_forwarded_user_agent(value) ⇒ self
Set ForwardedUserAgent.
-
#set_impersonate_user_email(value) ⇒ self
Set ImpersonateUserEmail.
-
#set_impersonate_user_id(value) ⇒ self
Set ImpersonateUserId.
-
#set_impersonate_user_phone(value) ⇒ self
Set ImpersonateUserPhone.
-
#set_jwt(value) ⇒ self
Set JWT.
-
#set_key(value) ⇒ self
Set Key.
-
#set_locale(value) ⇒ self
Set Locale.
-
#set_project(value) ⇒ self
Set Project.
-
#set_self_signed(self_signed = true) ⇒ self
Set self signed.
-
#set_session(value) ⇒ self
Set Session.
Constructor Details
#initialize ⇒ Client
Returns a new instance of Client.
11 12 13 14 15 16 17 18 19 20 21 22 |
# File 'lib/appwrite/client.rb', line 11 def initialize @chunk_size = 5*1024*1024 @headers = { 'user-agent' => RUBY_PLATFORM + ':ruby-' + RUBY_VERSION, 'x-sdk-name'=> 'Ruby', 'x-sdk-platform'=> 'server', 'x-sdk-language'=> 'ruby', 'x-sdk-version'=> '23.1.0', 'X-Appwrite-Response-Format' => '1.9.4' } @endpoint = 'https://cloud.appwrite.io/v1' end |
Instance Method Details
#add_header(key, value) ⇒ self
Add Header
197 198 199 200 201 |
# File 'lib/appwrite/client.rb', line 197 def add_header(key, value) @headers[key.downcase] = value self end |
#call(method:, path: '', headers: {}, params: {}, response_type: nil) ⇒ self
Send the HTTP request.
219 220 221 222 223 224 225 226 227 228 229 |
# File 'lib/appwrite/client.rb', line 219 def call( method:, path: '', headers: {}, params: {}, response_type: nil ) uri = URI.parse(@endpoint + path + ((method == "GET" && params.length) ? '?' + encode(params) : '')) fetch(method, uri, headers, params, response_type) end |
#chunked_upload(path:, headers:, params:, param_name: '', id_param_name: nil, on_progress: nil, response_type: nil) ⇒ Object
231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 |
# File 'lib/appwrite/client.rb', line 231 def chunked_upload( path:, headers:, params:, param_name: '', id_param_name: nil, on_progress: nil, response_type: nil ) input_file = params[param_name.to_sym] case input_file.source_type when 'path' size = ::File.size(input_file.path) when 'string' size = input_file.data.bytesize end if size < @chunk_size if input_file.source_type == 'path' input_file.data = IO.read(input_file.path) end params[param_name.to_sym] = input_file return call( method: 'POST', path: path, headers: headers, params: params, response_type: response_type, ) end offset = 0 id_param_name = id_param_name.to_sym if id_param_name if id_param_name&.empty? == false # Make a request to check if a file already exists current = call( method: "GET", path: "#{path}/#{params[id_param_name]}", headers: headers, params: {} ) chunks_uploaded = current['chunksUploaded'].to_i offset = chunks_uploaded * @chunk_size end while offset < size case input_file.source_type when 'path' string = IO.read(input_file.path, @chunk_size, offset) when 'string' string = input_file.data.byteslice(offset, [@chunk_size, size - offset].min) end params[param_name.to_sym] = InputFile::from_string( string, filename: input_file.filename, mime_type: input_file.mime_type ) headers['content-range'] = "bytes #{offset}-#{[offset + @chunk_size - 1, size - 1].min}/#{size}" result = call( method: 'POST', path: path, headers: headers, params: params, ) offset += @chunk_size if defined? result['$id'] headers['x-appwrite-id'] = result['$id'] end on_progress.call({ id: result['$id'], progress: ([offset, size].min).to_f/size.to_f * 100.0, size_uploaded: [offset, size].min, chunks_total: result['chunksTotal'], chunks_uploaded: result['chunksUploaded'] }) unless on_progress.nil? end return result unless response_type.respond_to?("from") response_type.from(map: result) end |
#get_headers ⇒ Hash
Get request headers
206 207 208 |
# File 'lib/appwrite/client.rb', line 206 def get_headers @headers.dup end |
#set_cookie(value) ⇒ self
Set Cookie
The user cookie to authenticate with. Used by SDKs that forward an incoming Cookie header in server-side runtimes.
120 121 122 123 124 |
# File 'lib/appwrite/client.rb', line 120 def (value) add_header('cookie', value) self end |
#set_dev_key(value) ⇒ self
Set DevKey
Your secret dev API key
107 108 109 110 111 |
# File 'lib/appwrite/client.rb', line 107 def set_dev_key(value) add_header('x-appwrite-dev-key', value) self end |
#set_endpoint(endpoint) ⇒ self
Set endpoint.
170 171 172 173 174 175 176 177 178 |
# File 'lib/appwrite/client.rb', line 170 def set_endpoint(endpoint) if not endpoint.start_with?('http://') and not endpoint.start_with?('https://') raise Appwrite::Exception.new('Invalid endpoint URL: ' + endpoint) end @endpoint = endpoint self end |
#set_forwarded_user_agent(value) ⇒ self
Set ForwardedUserAgent
The user agent string of the client that made the request
94 95 96 97 98 |
# File 'lib/appwrite/client.rb', line 94 def set_forwarded_user_agent(value) add_header('x-forwarded-user-agent', value) self end |
#set_impersonate_user_email(value) ⇒ self
Set ImpersonateUserEmail
Impersonate a user by email on an already user-authenticated request. Requires the current request to be authenticated as a user with impersonator capability; X-Appwrite-Key alone is not sufficient. Impersonator users are intentionally granted users.read so they can discover a target before impersonation begins. Internal audit logs still attribute actions to the original impersonator and record the impersonated target only in internal audit payload data.
146 147 148 149 150 |
# File 'lib/appwrite/client.rb', line 146 def set_impersonate_user_email(value) add_header('x-appwrite-impersonate-user-email', value) self end |
#set_impersonate_user_id(value) ⇒ self
Set ImpersonateUserId
Impersonate a user by ID on an already user-authenticated request. Requires the current request to be authenticated as a user with impersonator capability; X-Appwrite-Key alone is not sufficient. Impersonator users are intentionally granted users.read so they can discover a target before impersonation begins. Internal audit logs still attribute actions to the original impersonator and record the impersonated target only in internal audit payload data.
133 134 135 136 137 |
# File 'lib/appwrite/client.rb', line 133 def set_impersonate_user_id(value) add_header('x-appwrite-impersonate-user-id', value) self end |
#set_impersonate_user_phone(value) ⇒ self
Set ImpersonateUserPhone
Impersonate a user by phone on an already user-authenticated request. Requires the current request to be authenticated as a user with impersonator capability; X-Appwrite-Key alone is not sufficient. Impersonator users are intentionally granted users.read so they can discover a target before impersonation begins. Internal audit logs still attribute actions to the original impersonator and record the impersonated target only in internal audit payload data.
159 160 161 162 163 |
# File 'lib/appwrite/client.rb', line 159 def set_impersonate_user_phone(value) add_header('x-appwrite-impersonate-user-phone', value) self end |
#set_jwt(value) ⇒ self
Set JWT
Your secret JSON Web Token
57 58 59 60 61 |
# File 'lib/appwrite/client.rb', line 57 def set_jwt(value) add_header('x-appwrite-jwt', value) self end |
#set_key(value) ⇒ self
Set Key
Your secret API key
44 45 46 47 48 |
# File 'lib/appwrite/client.rb', line 44 def set_key(value) add_header('x-appwrite-key', value) self end |
#set_locale(value) ⇒ self
Set Locale
68 69 70 71 72 |
# File 'lib/appwrite/client.rb', line 68 def set_locale(value) add_header('x-appwrite-locale', value) self end |
#set_project(value) ⇒ self
Set Project
Your project ID
31 32 33 34 35 |
# File 'lib/appwrite/client.rb', line 31 def set_project(value) add_header('x-appwrite-project', value) self end |
#set_self_signed(self_signed = true) ⇒ self
Set self signed.
185 186 187 188 189 |
# File 'lib/appwrite/client.rb', line 185 def set_self_signed(self_signed = true) @self_signed = self_signed self end |
#set_session(value) ⇒ self
Set Session
The user session to authenticate with
81 82 83 84 85 |
# File 'lib/appwrite/client.rb', line 81 def set_session(value) add_header('x-appwrite-session', value) self end |