Class: Appwrite::Functions
- Defined in:
- lib/appwrite/services/functions.rb
Instance Method Summary collapse
-
#create(function_id:, name:, runtime:, execute: nil, events: nil, schedule: nil, timeout: nil, enabled: nil, logging: nil, entrypoint: nil, commands: nil, scopes: nil, installation_id: nil, provider_repository_id: nil, provider_branch: nil, provider_silent_mode: nil, provider_root_directory: nil, provider_branches: nil, provider_paths: nil, build_specification: nil, runtime_specification: nil, deployment_retention: nil) ⇒ Function
Create a new function.
-
#create_deployment(function_id:, code:, activate:, entrypoint: nil, commands: nil, on_progress: nil) ⇒ Deployment
Create a new function code deployment.
-
#create_duplicate_deployment(function_id:, deployment_id:, build_id: nil) ⇒ Deployment
Create a new build for an existing function deployment.
-
#create_execution(function_id:, body: nil, async: nil, xpath: nil, method: nil, headers: nil, scheduled_at: nil) ⇒ Execution
Trigger a function execution.
-
#create_template_deployment(function_id:, repository:, owner:, root_directory:, type:, reference:, activate: nil) ⇒ Deployment
Create a deployment based on a template.
-
#create_variable(function_id:, variable_id:, key:, value:, secret: nil) ⇒ Variable
Create a new function environment variable.
-
#create_vcs_deployment(function_id:, type:, reference:, activate: nil) ⇒ Deployment
Create a deployment when a function is connected to VCS.
-
#delete(function_id:) ⇒ Object
Delete a function by its unique ID.
-
#delete_deployment(function_id:, deployment_id:) ⇒ Object
Delete a code deployment by its unique ID.
-
#delete_execution(function_id:, execution_id:) ⇒ Object
Delete a function execution by its unique ID.
-
#delete_variable(function_id:, variable_id:) ⇒ Object
Delete a variable by its unique ID.
-
#get(function_id:) ⇒ Function
Get a function by its unique ID.
-
#get_deployment(function_id:, deployment_id:) ⇒ Deployment
Get a function deployment by its unique ID.
-
#get_deployment_download(function_id:, deployment_id:, type: nil) ⇒ Object
Get a function deployment content by its unique ID.
-
#get_execution(function_id:, execution_id:) ⇒ Execution
Get a function execution log by its unique ID.
-
#get_variable(function_id:, variable_id:) ⇒ Variable
Get a variable by its unique ID.
-
#initialize(client) ⇒ Functions
constructor
A new instance of Functions.
-
#list(queries: nil, search: nil, total: nil) ⇒ FunctionList
Get a list of all the project’s functions.
-
#list_deployments(function_id:, queries: nil, search: nil, total: nil) ⇒ DeploymentList
Get a list of all the function’s code deployments.
-
#list_executions(function_id:, queries: nil, total: nil) ⇒ ExecutionList
Get a list of all the current user function execution logs.
-
#list_runtimes ⇒ RuntimeList
Get a list of all runtimes that are currently active on your instance.
-
#list_specifications ⇒ SpecificationList
List allowed function specifications for this instance.
-
#list_variables(function_id:, queries: nil, total: nil) ⇒ VariableList
Get a list of all variables of a specific function.
-
#update(function_id:, name:, runtime: nil, execute: nil, events: nil, schedule: nil, timeout: nil, enabled: nil, logging: nil, entrypoint: nil, commands: nil, scopes: nil, installation_id: nil, provider_repository_id: nil, provider_branch: nil, provider_silent_mode: nil, provider_root_directory: nil, provider_branches: nil, provider_paths: nil, build_specification: nil, runtime_specification: nil, deployment_retention: nil) ⇒ Function
Update function by its unique ID.
-
#update_deployment_status(function_id:, deployment_id:) ⇒ Deployment
Cancel an ongoing function deployment build.
-
#update_function_deployment(function_id:, deployment_id:) ⇒ Function
Update the function active deployment.
-
#update_variable(function_id:, variable_id:, key: nil, value: nil, secret: nil) ⇒ Variable
Update variable by its unique ID.
Constructor Details
#initialize(client) ⇒ Functions
Returns a new instance of Functions.
6 7 8 |
# File 'lib/appwrite/services/functions.rb', line 6 def initialize(client) @client = client end |
Instance Method Details
#create(function_id:, name:, runtime:, execute: nil, events: nil, schedule: nil, timeout: nil, enabled: nil, logging: nil, entrypoint: nil, commands: nil, scopes: nil, installation_id: nil, provider_repository_id: nil, provider_branch: nil, provider_silent_mode: nil, provider_root_directory: nil, provider_branches: nil, provider_paths: nil, build_specification: nil, runtime_specification: nil, deployment_retention: nil) ⇒ Function
Create a new function. You can pass a list of [permissions](appwrite.io/docs/permissions) to allow different project users or team with access to execute the function using the client API.
70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 |
# File 'lib/appwrite/services/functions.rb', line 70 def create(function_id:, name:, runtime:, execute: nil, events: nil, schedule: nil, timeout: nil, enabled: nil, logging: nil, entrypoint: nil, commands: nil, scopes: nil, installation_id: nil, provider_repository_id: nil, provider_branch: nil, provider_silent_mode: nil, provider_root_directory: nil, provider_branches: nil, provider_paths: nil, build_specification: nil, runtime_specification: nil, deployment_retention: nil) api_path = '/functions' if function_id.nil? raise Appwrite::Exception.new('Missing required parameter: "functionId"') end if name.nil? raise Appwrite::Exception.new('Missing required parameter: "name"') end if runtime.nil? raise Appwrite::Exception.new('Missing required parameter: "runtime"') end api_params = { functionId: function_id, name: name, runtime: runtime, execute: execute, events: events, schedule: schedule, timeout: timeout, enabled: enabled, logging: logging, entrypoint: entrypoint, commands: commands, scopes: scopes, installationId: installation_id, providerRepositoryId: provider_repository_id, providerBranch: provider_branch, providerSilentMode: provider_silent_mode, providerRootDirectory: provider_root_directory, providerBranches: provider_branches, providerPaths: provider_paths, buildSpecification: build_specification, runtimeSpecification: runtime_specification, deploymentRetention: deployment_retention, } api_headers = { "X-Appwrite-Project": @client.get_config('project'), "content-type": 'application/json', } @client.call( method: 'POST', path: api_path, headers: api_headers, params: api_params, response_type: Models::Function ) end |
#create_deployment(function_id:, code:, activate:, entrypoint: nil, commands: nil, on_progress: nil) ⇒ Deployment
Create a new function code deployment. Use this endpoint to upload a new version of your code function. To execute your newly uploaded code, you’ll need to update the function’s deployment to use your new deployment UID.
This endpoint accepts a tar.gz file compressed with your code. Make sure to include any dependencies your code has within the compressed file. You can learn more about code packaging in the [Appwrite Cloud Functions tutorial](appwrite.io/docs/functions).
Use the “command” param to set the entrypoint used to execute your code.
403 404 405 406 407 408 409 410 411 412 413 414 415 416 417 418 419 420 421 422 423 424 425 426 427 428 429 430 431 432 433 434 435 436 437 438 439 440 441 442 443 444 |
# File 'lib/appwrite/services/functions.rb', line 403 def create_deployment(function_id:, code:, activate:, entrypoint: nil, commands: nil, on_progress: nil) api_path = '/functions/{functionId}/deployments' .gsub('{functionId}', function_id) if function_id.nil? raise Appwrite::Exception.new('Missing required parameter: "functionId"') end if code.nil? raise Appwrite::Exception.new('Missing required parameter: "code"') end if activate.nil? raise Appwrite::Exception.new('Missing required parameter: "activate"') end api_params = { entrypoint: entrypoint, commands: commands, code: code, activate: activate, } api_headers = { "X-Appwrite-Project": @client.get_config('project'), "content-type": 'multipart/form-data', } id_param_name = nil param_name = 'code' @client.chunked_upload( path: api_path, headers: api_headers, params: api_params, param_name: param_name, id_param_name: id_param_name, on_progress: on_progress, response_type: Models::Deployment ) end |
#create_duplicate_deployment(function_id:, deployment_id:, build_id: nil) ⇒ Deployment
Create a new build for an existing function deployment. This endpoint allows you to rebuild a deployment with the updated function configuration, including its entrypoint and build commands if they have been modified. The build process will be queued and executed asynchronously. The original deployment’s code will be preserved and used for the new build.
457 458 459 460 461 462 463 464 465 466 467 468 469 470 471 472 473 474 475 476 477 478 479 480 481 482 483 484 485 486 487 |
# File 'lib/appwrite/services/functions.rb', line 457 def create_duplicate_deployment(function_id:, deployment_id:, build_id: nil) api_path = '/functions/{functionId}/deployments/duplicate' .gsub('{functionId}', function_id) if function_id.nil? raise Appwrite::Exception.new('Missing required parameter: "functionId"') end if deployment_id.nil? raise Appwrite::Exception.new('Missing required parameter: "deploymentId"') end api_params = { deploymentId: deployment_id, buildId: build_id, } api_headers = { "X-Appwrite-Project": @client.get_config('project'), "content-type": 'application/json', } @client.call( method: 'POST', path: api_path, headers: api_headers, params: api_params, response_type: Models::Deployment ) end |
#create_execution(function_id:, body: nil, async: nil, xpath: nil, method: nil, headers: nil, scheduled_at: nil) ⇒ Execution
Trigger a function execution. The returned object will return you the current execution status. You can ping the ‘Get Execution` endpoint to get updates on the current execution status. Once this endpoint is called, your function execution process will start asynchronously.
804 805 806 807 808 809 810 811 812 813 814 815 816 817 818 819 820 821 822 823 824 825 826 827 828 829 830 831 832 833 834 |
# File 'lib/appwrite/services/functions.rb', line 804 def create_execution(function_id:, body: nil, async: nil, xpath: nil, method: nil, headers: nil, scheduled_at: nil) api_path = '/functions/{functionId}/executions' .gsub('{functionId}', function_id) if function_id.nil? raise Appwrite::Exception.new('Missing required parameter: "functionId"') end api_params = { body: body, async: async, path: xpath, method: method, headers: headers, scheduledAt: scheduled_at, } api_headers = { "X-Appwrite-Project": @client.get_config('project'), "content-type": 'application/json', } @client.call( method: 'POST', path: api_path, headers: api_headers, params: api_params, response_type: Models::Execution ) end |
#create_template_deployment(function_id:, repository:, owner:, root_directory:, type:, reference:, activate: nil) ⇒ Deployment
Create a deployment based on a template.
Use this endpoint with combination of [listTemplates](appwrite.io/docs/products/functions/templates) to find the template details.
504 505 506 507 508 509 510 511 512 513 514 515 516 517 518 519 520 521 522 523 524 525 526 527 528 529 530 531 532 533 534 535 536 537 538 539 540 541 542 543 544 545 546 547 548 549 550 551 552 553 554 |
# File 'lib/appwrite/services/functions.rb', line 504 def create_template_deployment(function_id:, repository:, owner:, root_directory:, type:, reference:, activate: nil) api_path = '/functions/{functionId}/deployments/template' .gsub('{functionId}', function_id) if function_id.nil? raise Appwrite::Exception.new('Missing required parameter: "functionId"') end if repository.nil? raise Appwrite::Exception.new('Missing required parameter: "repository"') end if owner.nil? raise Appwrite::Exception.new('Missing required parameter: "owner"') end if root_directory.nil? raise Appwrite::Exception.new('Missing required parameter: "rootDirectory"') end if type.nil? raise Appwrite::Exception.new('Missing required parameter: "type"') end if reference.nil? raise Appwrite::Exception.new('Missing required parameter: "reference"') end api_params = { repository: repository, owner: owner, rootDirectory: root_directory, type: type, reference: reference, activate: activate, } api_headers = { "X-Appwrite-Project": @client.get_config('project'), "content-type": 'application/json', } @client.call( method: 'POST', path: api_path, headers: api_headers, params: api_params, response_type: Models::Deployment ) end |
#create_variable(function_id:, variable_id:, key:, value:, secret: nil) ⇒ Variable
Create a new function environment variable. These variables can be accessed in the function at runtime as environment variables.
952 953 954 955 956 957 958 959 960 961 962 963 964 965 966 967 968 969 970 971 972 973 974 975 976 977 978 979 980 981 982 983 984 985 986 987 988 989 990 991 992 |
# File 'lib/appwrite/services/functions.rb', line 952 def create_variable(function_id:, variable_id:, key:, value:, secret: nil) api_path = '/functions/{functionId}/variables' .gsub('{functionId}', function_id) if function_id.nil? raise Appwrite::Exception.new('Missing required parameter: "functionId"') end if variable_id.nil? raise Appwrite::Exception.new('Missing required parameter: "variableId"') end if key.nil? raise Appwrite::Exception.new('Missing required parameter: "key"') end if value.nil? raise Appwrite::Exception.new('Missing required parameter: "value"') end api_params = { variableId: variable_id, key: key, value: value, secret: secret, } api_headers = { "X-Appwrite-Project": @client.get_config('project'), "content-type": 'application/json', } @client.call( method: 'POST', path: api_path, headers: api_headers, params: api_params, response_type: Models::Variable ) end |
#create_vcs_deployment(function_id:, type:, reference:, activate: nil) ⇒ Deployment
Create a deployment when a function is connected to VCS.
This endpoint lets you create deployment from a branch, commit, or a tag.
566 567 568 569 570 571 572 573 574 575 576 577 578 579 580 581 582 583 584 585 586 587 588 589 590 591 592 593 594 595 596 597 598 599 600 601 |
# File 'lib/appwrite/services/functions.rb', line 566 def create_vcs_deployment(function_id:, type:, reference:, activate: nil) api_path = '/functions/{functionId}/deployments/vcs' .gsub('{functionId}', function_id) if function_id.nil? raise Appwrite::Exception.new('Missing required parameter: "functionId"') end if type.nil? raise Appwrite::Exception.new('Missing required parameter: "type"') end if reference.nil? raise Appwrite::Exception.new('Missing required parameter: "reference"') end api_params = { type: type, reference: reference, activate: activate, } api_headers = { "X-Appwrite-Project": @client.get_config('project'), "content-type": 'application/json', } @client.call( method: 'POST', path: api_path, headers: api_headers, params: api_params, response_type: Models::Deployment ) end |
#delete(function_id:) ⇒ Object
Delete a function by its unique ID.
285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 |
# File 'lib/appwrite/services/functions.rb', line 285 def delete(function_id:) api_path = '/functions/{functionId}' .gsub('{functionId}', function_id) if function_id.nil? raise Appwrite::Exception.new('Missing required parameter: "functionId"') end api_params = { } api_headers = { "X-Appwrite-Project": @client.get_config('project'), "content-type": 'application/json', } @client.call( method: 'DELETE', path: api_path, headers: api_headers, params: api_params, ) end |
#delete_deployment(function_id:, deployment_id:) ⇒ Object
Delete a code deployment by its unique ID.
645 646 647 648 649 650 651 652 653 654 655 656 657 658 659 660 661 662 663 664 665 666 667 668 669 670 671 672 673 |
# File 'lib/appwrite/services/functions.rb', line 645 def delete_deployment(function_id:, deployment_id:) api_path = '/functions/{functionId}/deployments/{deploymentId}' .gsub('{functionId}', function_id) .gsub('{deploymentId}', deployment_id) if function_id.nil? raise Appwrite::Exception.new('Missing required parameter: "functionId"') end if deployment_id.nil? raise Appwrite::Exception.new('Missing required parameter: "deploymentId"') end api_params = { } api_headers = { "X-Appwrite-Project": @client.get_config('project'), "content-type": 'application/json', } @client.call( method: 'DELETE', path: api_path, headers: api_headers, params: api_params, ) end |
#delete_execution(function_id:, execution_id:) ⇒ Object
Delete a function execution by its unique ID.
878 879 880 881 882 883 884 885 886 887 888 889 890 891 892 893 894 895 896 897 898 899 900 901 902 903 904 905 906 |
# File 'lib/appwrite/services/functions.rb', line 878 def delete_execution(function_id:, execution_id:) api_path = '/functions/{functionId}/executions/{executionId}' .gsub('{functionId}', function_id) .gsub('{executionId}', execution_id) if function_id.nil? raise Appwrite::Exception.new('Missing required parameter: "functionId"') end if execution_id.nil? raise Appwrite::Exception.new('Missing required parameter: "executionId"') end api_params = { } api_headers = { "X-Appwrite-Project": @client.get_config('project'), "content-type": 'application/json', } @client.call( method: 'DELETE', path: api_path, headers: api_headers, params: api_params, ) end |
#delete_variable(function_id:, variable_id:) ⇒ Object
Delete a variable by its unique ID.
1079 1080 1081 1082 1083 1084 1085 1086 1087 1088 1089 1090 1091 1092 1093 1094 1095 1096 1097 1098 1099 1100 1101 1102 1103 1104 1105 1106 1107 |
# File 'lib/appwrite/services/functions.rb', line 1079 def delete_variable(function_id:, variable_id:) api_path = '/functions/{functionId}/variables/{variableId}' .gsub('{functionId}', function_id) .gsub('{variableId}', variable_id) if function_id.nil? raise Appwrite::Exception.new('Missing required parameter: "functionId"') end if variable_id.nil? raise Appwrite::Exception.new('Missing required parameter: "variableId"') end api_params = { } api_headers = { "X-Appwrite-Project": @client.get_config('project'), "content-type": 'application/json', } @client.call( method: 'DELETE', path: api_path, headers: api_headers, params: api_params, ) end |
#get(function_id:) ⇒ Function
Get a function by its unique ID.
178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 |
# File 'lib/appwrite/services/functions.rb', line 178 def get(function_id:) api_path = '/functions/{functionId}' .gsub('{functionId}', function_id) if function_id.nil? raise Appwrite::Exception.new('Missing required parameter: "functionId"') end api_params = { } api_headers = { "X-Appwrite-Project": @client.get_config('project'), } @client.call( method: 'GET', path: api_path, headers: api_headers, params: api_params, response_type: Models::Function ) end |
#get_deployment(function_id:, deployment_id:) ⇒ Deployment
Get a function deployment by its unique ID.
609 610 611 612 613 614 615 616 617 618 619 620 621 622 623 624 625 626 627 628 629 630 631 632 633 634 635 636 637 |
# File 'lib/appwrite/services/functions.rb', line 609 def get_deployment(function_id:, deployment_id:) api_path = '/functions/{functionId}/deployments/{deploymentId}' .gsub('{functionId}', function_id) .gsub('{deploymentId}', deployment_id) if function_id.nil? raise Appwrite::Exception.new('Missing required parameter: "functionId"') end if deployment_id.nil? raise Appwrite::Exception.new('Missing required parameter: "deploymentId"') end api_params = { } api_headers = { "X-Appwrite-Project": @client.get_config('project'), } @client.call( method: 'GET', path: api_path, headers: api_headers, params: api_params, response_type: Models::Deployment ) end |
#get_deployment_download(function_id:, deployment_id:, type: nil) ⇒ Object
Get a function deployment content by its unique ID. The endpoint response return with a ‘Content-Disposition: attachment’ header that tells the browser to start downloading the file to user downloads directory.
684 685 686 687 688 689 690 691 692 693 694 695 696 697 698 699 700 701 702 703 704 705 706 707 708 709 710 711 712 |
# File 'lib/appwrite/services/functions.rb', line 684 def get_deployment_download(function_id:, deployment_id:, type: nil) api_path = '/functions/{functionId}/deployments/{deploymentId}/download' .gsub('{functionId}', function_id) .gsub('{deploymentId}', deployment_id) if function_id.nil? raise Appwrite::Exception.new('Missing required parameter: "functionId"') end if deployment_id.nil? raise Appwrite::Exception.new('Missing required parameter: "deploymentId"') end api_params = { type: type, } api_headers = { "X-Appwrite-Project": @client.get_config('project'), } @client.call( method: 'GET', path: api_path, headers: api_headers, params: api_params, ) end |
#get_execution(function_id:, execution_id:) ⇒ Execution
Get a function execution log by its unique ID.
842 843 844 845 846 847 848 849 850 851 852 853 854 855 856 857 858 859 860 861 862 863 864 865 866 867 868 869 870 |
# File 'lib/appwrite/services/functions.rb', line 842 def get_execution(function_id:, execution_id:) api_path = '/functions/{functionId}/executions/{executionId}' .gsub('{functionId}', function_id) .gsub('{executionId}', execution_id) if function_id.nil? raise Appwrite::Exception.new('Missing required parameter: "functionId"') end if execution_id.nil? raise Appwrite::Exception.new('Missing required parameter: "executionId"') end api_params = { } api_headers = { "X-Appwrite-Project": @client.get_config('project'), } @client.call( method: 'GET', path: api_path, headers: api_headers, params: api_params, response_type: Models::Execution ) end |
#get_variable(function_id:, variable_id:) ⇒ Variable
Get a variable by its unique ID.
1000 1001 1002 1003 1004 1005 1006 1007 1008 1009 1010 1011 1012 1013 1014 1015 1016 1017 1018 1019 1020 1021 1022 1023 1024 1025 1026 1027 1028 |
# File 'lib/appwrite/services/functions.rb', line 1000 def get_variable(function_id:, variable_id:) api_path = '/functions/{functionId}/variables/{variableId}' .gsub('{functionId}', function_id) .gsub('{variableId}', variable_id) if function_id.nil? raise Appwrite::Exception.new('Missing required parameter: "functionId"') end if variable_id.nil? raise Appwrite::Exception.new('Missing required parameter: "variableId"') end api_params = { } api_headers = { "X-Appwrite-Project": @client.get_config('project'), } @client.call( method: 'GET', path: api_path, headers: api_headers, params: api_params, response_type: Models::Variable ) end |
#list(queries: nil, search: nil, total: nil) ⇒ FunctionList
Get a list of all the project’s functions. You can use the query params to filter your results.
18 19 20 21 22 23 24 25 26 27 28 29 30 31 32 33 34 35 36 37 38 39 |
# File 'lib/appwrite/services/functions.rb', line 18 def list(queries: nil, search: nil, total: nil) api_path = '/functions' api_params = { queries: queries, search: search, total: total, } api_headers = { "X-Appwrite-Project": @client.get_config('project'), } @client.call( method: 'GET', path: api_path, headers: api_headers, params: api_params, response_type: Models::FunctionList ) end |
#list_deployments(function_id:, queries: nil, search: nil, total: nil) ⇒ DeploymentList
Get a list of all the function’s code deployments. You can use the query params to filter your results.
357 358 359 360 361 362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 381 382 383 |
# File 'lib/appwrite/services/functions.rb', line 357 def list_deployments(function_id:, queries: nil, search: nil, total: nil) api_path = '/functions/{functionId}/deployments' .gsub('{functionId}', function_id) if function_id.nil? raise Appwrite::Exception.new('Missing required parameter: "functionId"') end api_params = { queries: queries, search: search, total: total, } api_headers = { "X-Appwrite-Project": @client.get_config('project'), } @client.call( method: 'GET', path: api_path, headers: api_headers, params: api_params, response_type: Models::DeploymentList ) end |
#list_executions(function_id:, queries: nil, total: nil) ⇒ ExecutionList
Get a list of all the current user function execution logs. You can use the query params to filter your results.
763 764 765 766 767 768 769 770 771 772 773 774 775 776 777 778 779 780 781 782 783 784 785 786 787 788 |
# File 'lib/appwrite/services/functions.rb', line 763 def list_executions(function_id:, queries: nil, total: nil) api_path = '/functions/{functionId}/executions' .gsub('{functionId}', function_id) if function_id.nil? raise Appwrite::Exception.new('Missing required parameter: "functionId"') end api_params = { queries: queries, total: total, } api_headers = { "X-Appwrite-Project": @client.get_config('project'), } @client.call( method: 'GET', path: api_path, headers: api_headers, params: api_params, response_type: Models::ExecutionList ) end |
#list_runtimes ⇒ RuntimeList
Get a list of all runtimes that are currently active on your instance.
129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 |
# File 'lib/appwrite/services/functions.rb', line 129 def list_runtimes() api_path = '/functions/runtimes' api_params = { } api_headers = { "X-Appwrite-Project": @client.get_config('project'), } @client.call( method: 'GET', path: api_path, headers: api_headers, params: api_params, response_type: Models::RuntimeList ) end |
#list_specifications ⇒ SpecificationList
List allowed function specifications for this instance.
153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 |
# File 'lib/appwrite/services/functions.rb', line 153 def list_specifications() api_path = '/functions/specifications' api_params = { } api_headers = { "X-Appwrite-Project": @client.get_config('project'), } @client.call( method: 'GET', path: api_path, headers: api_headers, params: api_params, response_type: Models::SpecificationList ) end |
#list_variables(function_id:, queries: nil, total: nil) ⇒ VariableList
Get a list of all variables of a specific function.
915 916 917 918 919 920 921 922 923 924 925 926 927 928 929 930 931 932 933 934 935 936 937 938 939 940 |
# File 'lib/appwrite/services/functions.rb', line 915 def list_variables(function_id:, queries: nil, total: nil) api_path = '/functions/{functionId}/variables' .gsub('{functionId}', function_id) if function_id.nil? raise Appwrite::Exception.new('Missing required parameter: "functionId"') end api_params = { queries: queries, total: total, } api_headers = { "X-Appwrite-Project": @client.get_config('project'), } @client.call( method: 'GET', path: api_path, headers: api_headers, params: api_params, response_type: Models::VariableList ) end |
#update(function_id:, name:, runtime: nil, execute: nil, events: nil, schedule: nil, timeout: nil, enabled: nil, logging: nil, entrypoint: nil, commands: nil, scopes: nil, installation_id: nil, provider_repository_id: nil, provider_branch: nil, provider_silent_mode: nil, provider_root_directory: nil, provider_branches: nil, provider_paths: nil, build_specification: nil, runtime_specification: nil, deployment_retention: nil) ⇒ Function
Update function by its unique ID.
229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 |
# File 'lib/appwrite/services/functions.rb', line 229 def update(function_id:, name:, runtime: nil, execute: nil, events: nil, schedule: nil, timeout: nil, enabled: nil, logging: nil, entrypoint: nil, commands: nil, scopes: nil, installation_id: nil, provider_repository_id: nil, provider_branch: nil, provider_silent_mode: nil, provider_root_directory: nil, provider_branches: nil, provider_paths: nil, build_specification: nil, runtime_specification: nil, deployment_retention: nil) api_path = '/functions/{functionId}' .gsub('{functionId}', function_id) if function_id.nil? raise Appwrite::Exception.new('Missing required parameter: "functionId"') end if name.nil? raise Appwrite::Exception.new('Missing required parameter: "name"') end api_params = { name: name, runtime: runtime, execute: execute, events: events, schedule: schedule, timeout: timeout, enabled: enabled, logging: logging, entrypoint: entrypoint, commands: commands, scopes: scopes, installationId: installation_id, providerRepositoryId: provider_repository_id, providerBranch: provider_branch, providerSilentMode: provider_silent_mode, providerRootDirectory: provider_root_directory, providerBranches: provider_branches, providerPaths: provider_paths, buildSpecification: build_specification, runtimeSpecification: runtime_specification, deploymentRetention: deployment_retention, } api_headers = { "X-Appwrite-Project": @client.get_config('project'), "content-type": 'application/json', } @client.call( method: 'PUT', path: api_path, headers: api_headers, params: api_params, response_type: Models::Function ) end |
#update_deployment_status(function_id:, deployment_id:) ⇒ Deployment
Cancel an ongoing function deployment build. If the build is already in progress, it will be stopped and marked as canceled. If the build hasn’t started yet, it will be marked as canceled without executing. You cannot cancel builds that have already completed (status ‘ready’) or failed. The response includes the final build status and details.
724 725 726 727 728 729 730 731 732 733 734 735 736 737 738 739 740 741 742 743 744 745 746 747 748 749 750 751 752 753 |
# File 'lib/appwrite/services/functions.rb', line 724 def update_deployment_status(function_id:, deployment_id:) api_path = '/functions/{functionId}/deployments/{deploymentId}/status' .gsub('{functionId}', function_id) .gsub('{deploymentId}', deployment_id) if function_id.nil? raise Appwrite::Exception.new('Missing required parameter: "functionId"') end if deployment_id.nil? raise Appwrite::Exception.new('Missing required parameter: "deploymentId"') end api_params = { } api_headers = { "X-Appwrite-Project": @client.get_config('project'), "content-type": 'application/json', } @client.call( method: 'PATCH', path: api_path, headers: api_headers, params: api_params, response_type: Models::Deployment ) end |
#update_function_deployment(function_id:, deployment_id:) ⇒ Function
Update the function active deployment. Use this endpoint to switch the code deployment that should be used when visitor opens your function.
317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 |
# File 'lib/appwrite/services/functions.rb', line 317 def update_function_deployment(function_id:, deployment_id:) api_path = '/functions/{functionId}/deployment' .gsub('{functionId}', function_id) if function_id.nil? raise Appwrite::Exception.new('Missing required parameter: "functionId"') end if deployment_id.nil? raise Appwrite::Exception.new('Missing required parameter: "deploymentId"') end api_params = { deploymentId: deployment_id, } api_headers = { "X-Appwrite-Project": @client.get_config('project'), "content-type": 'application/json', } @client.call( method: 'PATCH', path: api_path, headers: api_headers, params: api_params, response_type: Models::Function ) end |
#update_variable(function_id:, variable_id:, key: nil, value: nil, secret: nil) ⇒ Variable
Update variable by its unique ID.
1039 1040 1041 1042 1043 1044 1045 1046 1047 1048 1049 1050 1051 1052 1053 1054 1055 1056 1057 1058 1059 1060 1061 1062 1063 1064 1065 1066 1067 1068 1069 1070 1071 |
# File 'lib/appwrite/services/functions.rb', line 1039 def update_variable(function_id:, variable_id:, key: nil, value: nil, secret: nil) api_path = '/functions/{functionId}/variables/{variableId}' .gsub('{functionId}', function_id) .gsub('{variableId}', variable_id) if function_id.nil? raise Appwrite::Exception.new('Missing required parameter: "functionId"') end if variable_id.nil? raise Appwrite::Exception.new('Missing required parameter: "variableId"') end api_params = { key: key, value: value, secret: secret, } api_headers = { "X-Appwrite-Project": @client.get_config('project'), "content-type": 'application/json', } @client.call( method: 'PUT', path: api_path, headers: api_headers, params: api_params, response_type: Models::Variable ) end |