Class: Appwrite::Functions
- Defined in:
- lib/appwrite/services/functions.rb
Instance Method Summary collapse
-
#create(function_id:, name:, runtime:, execute: nil, events: nil, schedule: nil, timeout: nil, enabled: nil, logging: nil, entrypoint: nil, commands: nil, scopes: nil, installation_id: nil, provider_repository_id: nil, provider_branch: nil, provider_silent_mode: nil, provider_root_directory: nil, build_specification: nil, runtime_specification: nil, deployment_retention: nil) ⇒ Function
Create a new function.
-
#create_deployment(function_id:, code:, activate:, entrypoint: nil, commands: nil, on_progress: nil) ⇒ Deployment
Create a new function code deployment.
-
#create_duplicate_deployment(function_id:, deployment_id:, build_id: nil) ⇒ Deployment
Create a new build for an existing function deployment.
-
#create_execution(function_id:, body: nil, async: nil, xpath: nil, method: nil, headers: nil, scheduled_at: nil) ⇒ Execution
Trigger a function execution.
-
#create_template_deployment(function_id:, repository:, owner:, root_directory:, type:, reference:, activate: nil) ⇒ Deployment
Create a deployment based on a template.
-
#create_variable(function_id:, key:, value:, secret: nil) ⇒ Variable
Create a new function environment variable.
-
#create_vcs_deployment(function_id:, type:, reference:, activate: nil) ⇒ Deployment
Create a deployment when a function is connected to VCS.
-
#delete(function_id:) ⇒ Object
Delete a function by its unique ID.
-
#delete_deployment(function_id:, deployment_id:) ⇒ Object
Delete a code deployment by its unique ID.
-
#delete_execution(function_id:, execution_id:) ⇒ Object
Delete a function execution by its unique ID.
-
#delete_variable(function_id:, variable_id:) ⇒ Object
Delete a variable by its unique ID.
-
#get(function_id:) ⇒ Function
Get a function by its unique ID.
-
#get_deployment(function_id:, deployment_id:) ⇒ Deployment
Get a function deployment by its unique ID.
-
#get_deployment_download(function_id:, deployment_id:, type: nil) ⇒ Object
Get a function deployment content by its unique ID.
-
#get_execution(function_id:, execution_id:) ⇒ Execution
Get a function execution log by its unique ID.
-
#get_variable(function_id:, variable_id:) ⇒ Variable
Get a variable by its unique ID.
-
#initialize(client) ⇒ Functions
constructor
A new instance of Functions.
-
#list(queries: nil, search: nil, total: nil) ⇒ FunctionList
Get a list of all the project’s functions.
-
#list_deployments(function_id:, queries: nil, search: nil, total: nil) ⇒ DeploymentList
Get a list of all the function’s code deployments.
-
#list_executions(function_id:, queries: nil, total: nil) ⇒ ExecutionList
Get a list of all the current user function execution logs.
-
#list_runtimes ⇒ RuntimeList
Get a list of all runtimes that are currently active on your instance.
-
#list_specifications ⇒ SpecificationList
List allowed function specifications for this instance.
-
#list_variables(function_id:) ⇒ VariableList
Get a list of all variables of a specific function.
-
#update(function_id:, name:, runtime: nil, execute: nil, events: nil, schedule: nil, timeout: nil, enabled: nil, logging: nil, entrypoint: nil, commands: nil, scopes: nil, installation_id: nil, provider_repository_id: nil, provider_branch: nil, provider_silent_mode: nil, provider_root_directory: nil, build_specification: nil, runtime_specification: nil, deployment_retention: nil) ⇒ Function
Update function by its unique ID.
-
#update_deployment_status(function_id:, deployment_id:) ⇒ Deployment
Cancel an ongoing function deployment build.
-
#update_function_deployment(function_id:, deployment_id:) ⇒ Function
Update the function active deployment.
-
#update_variable(function_id:, variable_id:, key:, value: nil, secret: nil) ⇒ Variable
Update variable by its unique ID.
Constructor Details
#initialize(client) ⇒ Functions
Returns a new instance of Functions.
6 7 8 |
# File 'lib/appwrite/services/functions.rb', line 6 def initialize(client) @client = client end |
Instance Method Details
#create(function_id:, name:, runtime:, execute: nil, events: nil, schedule: nil, timeout: nil, enabled: nil, logging: nil, entrypoint: nil, commands: nil, scopes: nil, installation_id: nil, provider_repository_id: nil, provider_branch: nil, provider_silent_mode: nil, provider_root_directory: nil, build_specification: nil, runtime_specification: nil, deployment_retention: nil) ⇒ Function
Create a new function. You can pass a list of [permissions](appwrite.io/docs/permissions) to allow different project users or team with access to execute the function using the client API.
67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 |
# File 'lib/appwrite/services/functions.rb', line 67 def create(function_id:, name:, runtime:, execute: nil, events: nil, schedule: nil, timeout: nil, enabled: nil, logging: nil, entrypoint: nil, commands: nil, scopes: nil, installation_id: nil, provider_repository_id: nil, provider_branch: nil, provider_silent_mode: nil, provider_root_directory: nil, build_specification: nil, runtime_specification: nil, deployment_retention: nil) api_path = '/functions' if function_id.nil? raise Appwrite::Exception.new('Missing required parameter: "functionId"') end if name.nil? raise Appwrite::Exception.new('Missing required parameter: "name"') end if runtime.nil? raise Appwrite::Exception.new('Missing required parameter: "runtime"') end api_params = { functionId: function_id, name: name, runtime: runtime, execute: execute, events: events, schedule: schedule, timeout: timeout, enabled: enabled, logging: logging, entrypoint: entrypoint, commands: commands, scopes: scopes, installationId: installation_id, providerRepositoryId: provider_repository_id, providerBranch: provider_branch, providerSilentMode: provider_silent_mode, providerRootDirectory: provider_root_directory, buildSpecification: build_specification, runtimeSpecification: runtime_specification, deploymentRetention: deployment_retention, } api_headers = { "content-type": 'application/json', } @client.call( method: 'POST', path: api_path, headers: api_headers, params: api_params, response_type: Models::Function ) end |
#create_deployment(function_id:, code:, activate:, entrypoint: nil, commands: nil, on_progress: nil) ⇒ Deployment
Create a new function code deployment. Use this endpoint to upload a new version of your code function. To execute your newly uploaded code, you’ll need to update the function’s deployment to use your new deployment UID.
This endpoint accepts a tar.gz file compressed with your code. Make sure to include any dependencies your code has within the compressed file. You can learn more about code packaging in the [Appwrite Cloud Functions tutorial](appwrite.io/docs/functions).
Use the “command” param to set the entrypoint used to execute your code.
386 387 388 389 390 391 392 393 394 395 396 397 398 399 400 401 402 403 404 405 406 407 408 409 410 411 412 413 414 415 416 417 418 419 420 421 422 423 424 425 426 |
# File 'lib/appwrite/services/functions.rb', line 386 def create_deployment(function_id:, code:, activate:, entrypoint: nil, commands: nil, on_progress: nil) api_path = '/functions/{functionId}/deployments' .gsub('{functionId}', function_id) if function_id.nil? raise Appwrite::Exception.new('Missing required parameter: "functionId"') end if code.nil? raise Appwrite::Exception.new('Missing required parameter: "code"') end if activate.nil? raise Appwrite::Exception.new('Missing required parameter: "activate"') end api_params = { entrypoint: entrypoint, commands: commands, code: code, activate: activate, } api_headers = { "content-type": 'multipart/form-data', } id_param_name = nil param_name = 'code' @client.chunked_upload( path: api_path, headers: api_headers, params: api_params, param_name: param_name, id_param_name: id_param_name, on_progress: on_progress, response_type: Models::Deployment ) end |
#create_duplicate_deployment(function_id:, deployment_id:, build_id: nil) ⇒ Deployment
Create a new build for an existing function deployment. This endpoint allows you to rebuild a deployment with the updated function configuration, including its entrypoint and build commands if they have been modified. The build process will be queued and executed asynchronously. The original deployment’s code will be preserved and used for the new build.
439 440 441 442 443 444 445 446 447 448 449 450 451 452 453 454 455 456 457 458 459 460 461 462 463 464 465 466 467 468 |
# File 'lib/appwrite/services/functions.rb', line 439 def create_duplicate_deployment(function_id:, deployment_id:, build_id: nil) api_path = '/functions/{functionId}/deployments/duplicate' .gsub('{functionId}', function_id) if function_id.nil? raise Appwrite::Exception.new('Missing required parameter: "functionId"') end if deployment_id.nil? raise Appwrite::Exception.new('Missing required parameter: "deploymentId"') end api_params = { deploymentId: deployment_id, buildId: build_id, } api_headers = { "content-type": 'application/json', } @client.call( method: 'POST', path: api_path, headers: api_headers, params: api_params, response_type: Models::Deployment ) end |
#create_execution(function_id:, body: nil, async: nil, xpath: nil, method: nil, headers: nil, scheduled_at: nil) ⇒ Execution
Trigger a function execution. The returned object will return you the current execution status. You can ping the ‘Get Execution` endpoint to get updates on the current execution status. Once this endpoint is called, your function execution process will start asynchronously.
778 779 780 781 782 783 784 785 786 787 788 789 790 791 792 793 794 795 796 797 798 799 800 801 802 803 804 805 806 807 |
# File 'lib/appwrite/services/functions.rb', line 778 def create_execution(function_id:, body: nil, async: nil, xpath: nil, method: nil, headers: nil, scheduled_at: nil) api_path = '/functions/{functionId}/executions' .gsub('{functionId}', function_id) if function_id.nil? raise Appwrite::Exception.new('Missing required parameter: "functionId"') end api_params = { body: body, async: async, path: xpath, method: method, headers: headers, scheduledAt: scheduled_at, } api_headers = { "content-type": 'application/json', } @client.call( method: 'POST', path: api_path, headers: api_headers, params: api_params, response_type: Models::Execution ) end |
#create_template_deployment(function_id:, repository:, owner:, root_directory:, type:, reference:, activate: nil) ⇒ Deployment
Create a deployment based on a template.
Use this endpoint with combination of [listTemplates](appwrite.io/docs/products/functions/templates) to find the template details.
485 486 487 488 489 490 491 492 493 494 495 496 497 498 499 500 501 502 503 504 505 506 507 508 509 510 511 512 513 514 515 516 517 518 519 520 521 522 523 524 525 526 527 528 529 530 531 532 533 534 |
# File 'lib/appwrite/services/functions.rb', line 485 def create_template_deployment(function_id:, repository:, owner:, root_directory:, type:, reference:, activate: nil) api_path = '/functions/{functionId}/deployments/template' .gsub('{functionId}', function_id) if function_id.nil? raise Appwrite::Exception.new('Missing required parameter: "functionId"') end if repository.nil? raise Appwrite::Exception.new('Missing required parameter: "repository"') end if owner.nil? raise Appwrite::Exception.new('Missing required parameter: "owner"') end if root_directory.nil? raise Appwrite::Exception.new('Missing required parameter: "rootDirectory"') end if type.nil? raise Appwrite::Exception.new('Missing required parameter: "type"') end if reference.nil? raise Appwrite::Exception.new('Missing required parameter: "reference"') end api_params = { repository: repository, owner: owner, rootDirectory: root_directory, type: type, reference: reference, activate: activate, } api_headers = { "content-type": 'application/json', } @client.call( method: 'POST', path: api_path, headers: api_headers, params: api_params, response_type: Models::Deployment ) end |
#create_variable(function_id:, key:, value:, secret: nil) ⇒ Variable
Create a new function environment variable. These variables can be accessed in the function at runtime as environment variables.
917 918 919 920 921 922 923 924 925 926 927 928 929 930 931 932 933 934 935 936 937 938 939 940 941 942 943 944 945 946 947 948 949 950 951 |
# File 'lib/appwrite/services/functions.rb', line 917 def create_variable(function_id:, key:, value:, secret: nil) api_path = '/functions/{functionId}/variables' .gsub('{functionId}', function_id) if function_id.nil? raise Appwrite::Exception.new('Missing required parameter: "functionId"') end if key.nil? raise Appwrite::Exception.new('Missing required parameter: "key"') end if value.nil? raise Appwrite::Exception.new('Missing required parameter: "value"') end api_params = { key: key, value: value, secret: secret, } api_headers = { "content-type": 'application/json', } @client.call( method: 'POST', path: api_path, headers: api_headers, params: api_params, response_type: Models::Variable ) end |
#create_vcs_deployment(function_id:, type:, reference:, activate: nil) ⇒ Deployment
Create a deployment when a function is connected to VCS.
This endpoint lets you create deployment from a branch, commit, or a tag.
546 547 548 549 550 551 552 553 554 555 556 557 558 559 560 561 562 563 564 565 566 567 568 569 570 571 572 573 574 575 576 577 578 579 580 |
# File 'lib/appwrite/services/functions.rb', line 546 def create_vcs_deployment(function_id:, type:, reference:, activate: nil) api_path = '/functions/{functionId}/deployments/vcs' .gsub('{functionId}', function_id) if function_id.nil? raise Appwrite::Exception.new('Missing required parameter: "functionId"') end if type.nil? raise Appwrite::Exception.new('Missing required parameter: "type"') end if reference.nil? raise Appwrite::Exception.new('Missing required parameter: "reference"') end api_params = { type: type, reference: reference, activate: activate, } api_headers = { "content-type": 'application/json', } @client.call( method: 'POST', path: api_path, headers: api_headers, params: api_params, response_type: Models::Deployment ) end |
#delete(function_id:) ⇒ Object
Delete a function by its unique ID.
271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 |
# File 'lib/appwrite/services/functions.rb', line 271 def delete(function_id:) api_path = '/functions/{functionId}' .gsub('{functionId}', function_id) if function_id.nil? raise Appwrite::Exception.new('Missing required parameter: "functionId"') end api_params = { } api_headers = { "content-type": 'application/json', } @client.call( method: 'DELETE', path: api_path, headers: api_headers, params: api_params, ) end |
#delete_deployment(function_id:, deployment_id:) ⇒ Object
Delete a code deployment by its unique ID.
623 624 625 626 627 628 629 630 631 632 633 634 635 636 637 638 639 640 641 642 643 644 645 646 647 648 649 650 |
# File 'lib/appwrite/services/functions.rb', line 623 def delete_deployment(function_id:, deployment_id:) api_path = '/functions/{functionId}/deployments/{deploymentId}' .gsub('{functionId}', function_id) .gsub('{deploymentId}', deployment_id) if function_id.nil? raise Appwrite::Exception.new('Missing required parameter: "functionId"') end if deployment_id.nil? raise Appwrite::Exception.new('Missing required parameter: "deploymentId"') end api_params = { } api_headers = { "content-type": 'application/json', } @client.call( method: 'DELETE', path: api_path, headers: api_headers, params: api_params, ) end |
#delete_execution(function_id:, execution_id:) ⇒ Object
Delete a function execution by its unique ID.
850 851 852 853 854 855 856 857 858 859 860 861 862 863 864 865 866 867 868 869 870 871 872 873 874 875 876 877 |
# File 'lib/appwrite/services/functions.rb', line 850 def delete_execution(function_id:, execution_id:) api_path = '/functions/{functionId}/executions/{executionId}' .gsub('{functionId}', function_id) .gsub('{executionId}', execution_id) if function_id.nil? raise Appwrite::Exception.new('Missing required parameter: "functionId"') end if execution_id.nil? raise Appwrite::Exception.new('Missing required parameter: "executionId"') end api_params = { } api_headers = { "content-type": 'application/json', } @client.call( method: 'DELETE', path: api_path, headers: api_headers, params: api_params, ) end |
#delete_variable(function_id:, variable_id:) ⇒ Object
Delete a variable by its unique ID.
1040 1041 1042 1043 1044 1045 1046 1047 1048 1049 1050 1051 1052 1053 1054 1055 1056 1057 1058 1059 1060 1061 1062 1063 1064 1065 1066 1067 |
# File 'lib/appwrite/services/functions.rb', line 1040 def delete_variable(function_id:, variable_id:) api_path = '/functions/{functionId}/variables/{variableId}' .gsub('{functionId}', function_id) .gsub('{variableId}', variable_id) if function_id.nil? raise Appwrite::Exception.new('Missing required parameter: "functionId"') end if variable_id.nil? raise Appwrite::Exception.new('Missing required parameter: "variableId"') end api_params = { } api_headers = { "content-type": 'application/json', } @client.call( method: 'DELETE', path: api_path, headers: api_headers, params: api_params, ) end |
#get(function_id:) ⇒ Function
Get a function by its unique ID.
170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 |
# File 'lib/appwrite/services/functions.rb', line 170 def get(function_id:) api_path = '/functions/{functionId}' .gsub('{functionId}', function_id) if function_id.nil? raise Appwrite::Exception.new('Missing required parameter: "functionId"') end api_params = { } api_headers = { } @client.call( method: 'GET', path: api_path, headers: api_headers, params: api_params, response_type: Models::Function ) end |
#get_deployment(function_id:, deployment_id:) ⇒ Deployment
Get a function deployment by its unique ID.
588 589 590 591 592 593 594 595 596 597 598 599 600 601 602 603 604 605 606 607 608 609 610 611 612 613 614 615 |
# File 'lib/appwrite/services/functions.rb', line 588 def get_deployment(function_id:, deployment_id:) api_path = '/functions/{functionId}/deployments/{deploymentId}' .gsub('{functionId}', function_id) .gsub('{deploymentId}', deployment_id) if function_id.nil? raise Appwrite::Exception.new('Missing required parameter: "functionId"') end if deployment_id.nil? raise Appwrite::Exception.new('Missing required parameter: "deploymentId"') end api_params = { } api_headers = { } @client.call( method: 'GET', path: api_path, headers: api_headers, params: api_params, response_type: Models::Deployment ) end |
#get_deployment_download(function_id:, deployment_id:, type: nil) ⇒ Object
Get a function deployment content by its unique ID. The endpoint response return with a ‘Content-Disposition: attachment’ header that tells the browser to start downloading the file to user downloads directory.
661 662 663 664 665 666 667 668 669 670 671 672 673 674 675 676 677 678 679 680 681 682 683 684 685 686 687 688 |
# File 'lib/appwrite/services/functions.rb', line 661 def get_deployment_download(function_id:, deployment_id:, type: nil) api_path = '/functions/{functionId}/deployments/{deploymentId}/download' .gsub('{functionId}', function_id) .gsub('{deploymentId}', deployment_id) if function_id.nil? raise Appwrite::Exception.new('Missing required parameter: "functionId"') end if deployment_id.nil? raise Appwrite::Exception.new('Missing required parameter: "deploymentId"') end api_params = { type: type, } api_headers = { } @client.call( method: 'GET', path: api_path, headers: api_headers, params: api_params, ) end |
#get_execution(function_id:, execution_id:) ⇒ Execution
Get a function execution log by its unique ID.
815 816 817 818 819 820 821 822 823 824 825 826 827 828 829 830 831 832 833 834 835 836 837 838 839 840 841 842 |
# File 'lib/appwrite/services/functions.rb', line 815 def get_execution(function_id:, execution_id:) api_path = '/functions/{functionId}/executions/{executionId}' .gsub('{functionId}', function_id) .gsub('{executionId}', execution_id) if function_id.nil? raise Appwrite::Exception.new('Missing required parameter: "functionId"') end if execution_id.nil? raise Appwrite::Exception.new('Missing required parameter: "executionId"') end api_params = { } api_headers = { } @client.call( method: 'GET', path: api_path, headers: api_headers, params: api_params, response_type: Models::Execution ) end |
#get_variable(function_id:, variable_id:) ⇒ Variable
Get a variable by its unique ID.
959 960 961 962 963 964 965 966 967 968 969 970 971 972 973 974 975 976 977 978 979 980 981 982 983 984 985 986 |
# File 'lib/appwrite/services/functions.rb', line 959 def get_variable(function_id:, variable_id:) api_path = '/functions/{functionId}/variables/{variableId}' .gsub('{functionId}', function_id) .gsub('{variableId}', variable_id) if function_id.nil? raise Appwrite::Exception.new('Missing required parameter: "functionId"') end if variable_id.nil? raise Appwrite::Exception.new('Missing required parameter: "variableId"') end api_params = { } api_headers = { } @client.call( method: 'GET', path: api_path, headers: api_headers, params: api_params, response_type: Models::Variable ) end |
#list(queries: nil, search: nil, total: nil) ⇒ FunctionList
Get a list of all the project’s functions. You can use the query params to filter your results.
18 19 20 21 22 23 24 25 26 27 28 29 30 31 32 33 34 35 36 37 38 |
# File 'lib/appwrite/services/functions.rb', line 18 def list(queries: nil, search: nil, total: nil) api_path = '/functions' api_params = { queries: queries, search: search, total: total, } api_headers = { } @client.call( method: 'GET', path: api_path, headers: api_headers, params: api_params, response_type: Models::FunctionList ) end |
#list_deployments(function_id:, queries: nil, search: nil, total: nil) ⇒ DeploymentList
Get a list of all the function’s code deployments. You can use the query params to filter your results.
341 342 343 344 345 346 347 348 349 350 351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 366 |
# File 'lib/appwrite/services/functions.rb', line 341 def list_deployments(function_id:, queries: nil, search: nil, total: nil) api_path = '/functions/{functionId}/deployments' .gsub('{functionId}', function_id) if function_id.nil? raise Appwrite::Exception.new('Missing required parameter: "functionId"') end api_params = { queries: queries, search: search, total: total, } api_headers = { } @client.call( method: 'GET', path: api_path, headers: api_headers, params: api_params, response_type: Models::DeploymentList ) end |
#list_executions(function_id:, queries: nil, total: nil) ⇒ ExecutionList
Get a list of all the current user function execution logs. You can use the query params to filter your results.
738 739 740 741 742 743 744 745 746 747 748 749 750 751 752 753 754 755 756 757 758 759 760 761 762 |
# File 'lib/appwrite/services/functions.rb', line 738 def list_executions(function_id:, queries: nil, total: nil) api_path = '/functions/{functionId}/executions' .gsub('{functionId}', function_id) if function_id.nil? raise Appwrite::Exception.new('Missing required parameter: "functionId"') end api_params = { queries: queries, total: total, } api_headers = { } @client.call( method: 'GET', path: api_path, headers: api_headers, params: api_params, response_type: Models::ExecutionList ) end |
#list_runtimes ⇒ RuntimeList
Get a list of all runtimes that are currently active on your instance.
123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 |
# File 'lib/appwrite/services/functions.rb', line 123 def list_runtimes() api_path = '/functions/runtimes' api_params = { } api_headers = { } @client.call( method: 'GET', path: api_path, headers: api_headers, params: api_params, response_type: Models::RuntimeList ) end |
#list_specifications ⇒ SpecificationList
List allowed function specifications for this instance.
146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 |
# File 'lib/appwrite/services/functions.rb', line 146 def list_specifications() api_path = '/functions/specifications' api_params = { } api_headers = { } @client.call( method: 'GET', path: api_path, headers: api_headers, params: api_params, response_type: Models::SpecificationList ) end |
#list_variables(function_id:) ⇒ VariableList
Get a list of all variables of a specific function.
884 885 886 887 888 889 890 891 892 893 894 895 896 897 898 899 900 901 902 903 904 905 906 |
# File 'lib/appwrite/services/functions.rb', line 884 def list_variables(function_id:) api_path = '/functions/{functionId}/variables' .gsub('{functionId}', function_id) if function_id.nil? raise Appwrite::Exception.new('Missing required parameter: "functionId"') end api_params = { } api_headers = { } @client.call( method: 'GET', path: api_path, headers: api_headers, params: api_params, response_type: Models::VariableList ) end |
#update(function_id:, name:, runtime: nil, execute: nil, events: nil, schedule: nil, timeout: nil, enabled: nil, logging: nil, entrypoint: nil, commands: nil, scopes: nil, installation_id: nil, provider_repository_id: nil, provider_branch: nil, provider_silent_mode: nil, provider_root_directory: nil, build_specification: nil, runtime_specification: nil, deployment_retention: nil) ⇒ Function
Update function by its unique ID.
218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 |
# File 'lib/appwrite/services/functions.rb', line 218 def update(function_id:, name:, runtime: nil, execute: nil, events: nil, schedule: nil, timeout: nil, enabled: nil, logging: nil, entrypoint: nil, commands: nil, scopes: nil, installation_id: nil, provider_repository_id: nil, provider_branch: nil, provider_silent_mode: nil, provider_root_directory: nil, build_specification: nil, runtime_specification: nil, deployment_retention: nil) api_path = '/functions/{functionId}' .gsub('{functionId}', function_id) if function_id.nil? raise Appwrite::Exception.new('Missing required parameter: "functionId"') end if name.nil? raise Appwrite::Exception.new('Missing required parameter: "name"') end api_params = { name: name, runtime: runtime, execute: execute, events: events, schedule: schedule, timeout: timeout, enabled: enabled, logging: logging, entrypoint: entrypoint, commands: commands, scopes: scopes, installationId: installation_id, providerRepositoryId: provider_repository_id, providerBranch: provider_branch, providerSilentMode: provider_silent_mode, providerRootDirectory: provider_root_directory, buildSpecification: build_specification, runtimeSpecification: runtime_specification, deploymentRetention: deployment_retention, } api_headers = { "content-type": 'application/json', } @client.call( method: 'PUT', path: api_path, headers: api_headers, params: api_params, response_type: Models::Function ) end |
#update_deployment_status(function_id:, deployment_id:) ⇒ Deployment
Cancel an ongoing function deployment build. If the build is already in progress, it will be stopped and marked as canceled. If the build hasn’t started yet, it will be marked as canceled without executing. You cannot cancel builds that have already completed (status ‘ready’) or failed. The response includes the final build status and details.
700 701 702 703 704 705 706 707 708 709 710 711 712 713 714 715 716 717 718 719 720 721 722 723 724 725 726 727 728 |
# File 'lib/appwrite/services/functions.rb', line 700 def update_deployment_status(function_id:, deployment_id:) api_path = '/functions/{functionId}/deployments/{deploymentId}/status' .gsub('{functionId}', function_id) .gsub('{deploymentId}', deployment_id) if function_id.nil? raise Appwrite::Exception.new('Missing required parameter: "functionId"') end if deployment_id.nil? raise Appwrite::Exception.new('Missing required parameter: "deploymentId"') end api_params = { } api_headers = { "content-type": 'application/json', } @client.call( method: 'PATCH', path: api_path, headers: api_headers, params: api_params, response_type: Models::Deployment ) end |
#update_function_deployment(function_id:, deployment_id:) ⇒ Function
Update the function active deployment. Use this endpoint to switch the code deployment that should be used when visitor opens your function.
302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 |
# File 'lib/appwrite/services/functions.rb', line 302 def update_function_deployment(function_id:, deployment_id:) api_path = '/functions/{functionId}/deployment' .gsub('{functionId}', function_id) if function_id.nil? raise Appwrite::Exception.new('Missing required parameter: "functionId"') end if deployment_id.nil? raise Appwrite::Exception.new('Missing required parameter: "deploymentId"') end api_params = { deploymentId: deployment_id, } api_headers = { "content-type": 'application/json', } @client.call( method: 'PATCH', path: api_path, headers: api_headers, params: api_params, response_type: Models::Function ) end |
#update_variable(function_id:, variable_id:, key:, value: nil, secret: nil) ⇒ Variable
Update variable by its unique ID.
997 998 999 1000 1001 1002 1003 1004 1005 1006 1007 1008 1009 1010 1011 1012 1013 1014 1015 1016 1017 1018 1019 1020 1021 1022 1023 1024 1025 1026 1027 1028 1029 1030 1031 1032 |
# File 'lib/appwrite/services/functions.rb', line 997 def update_variable(function_id:, variable_id:, key:, value: nil, secret: nil) api_path = '/functions/{functionId}/variables/{variableId}' .gsub('{functionId}', function_id) .gsub('{variableId}', variable_id) if function_id.nil? raise Appwrite::Exception.new('Missing required parameter: "functionId"') end if variable_id.nil? raise Appwrite::Exception.new('Missing required parameter: "variableId"') end if key.nil? raise Appwrite::Exception.new('Missing required parameter: "key"') end api_params = { key: key, value: value, secret: secret, } api_headers = { "content-type": 'application/json', } @client.call( method: 'PUT', path: api_path, headers: api_headers, params: api_params, response_type: Models::Variable ) end |