Class: Appwrite::Health

Inherits:
Service show all
Defined in:
lib/appwrite/services/health.rb

Instance Method Summary collapse

Constructor Details

#initialize(client) ⇒ Health

Returns a new instance of Health.



6
7
8
# File 'lib/appwrite/services/health.rb', line 6

def initialize(client)
    @client = client
end

Instance Method Details

#getHealthStatus

Check the Appwrite HTTP server is up and responsive.

Returns:

  • (HealthStatus)


14
15
16
17
18
19
20
21
22
23
24
25
26
27
28
29
30
31
# File 'lib/appwrite/services/health.rb', line 14

def get()
    api_path = '/health'

    api_params = {
    }
    
    api_headers = {
    }

    @client.call(
        method: 'GET',
        path: api_path,
        headers: api_headers,
        params: api_params,
        response_type: Models::HealthStatus
    )

end

#get_antivirusHealthAntivirus

Check the Appwrite Antivirus server is up and connection is successful.

Returns:

  • (HealthAntivirus)


37
38
39
40
41
42
43
44
45
46
47
48
49
50
51
52
53
54
# File 'lib/appwrite/services/health.rb', line 37

def get_antivirus()
    api_path = '/health/anti-virus'

    api_params = {
    }
    
    api_headers = {
    }

    @client.call(
        method: 'GET',
        path: api_path,
        headers: api_headers,
        params: api_params,
        response_type: Models::HealthAntivirus
    )

end

#get_cacheHealthStatusList

Check the Appwrite in-memory cache servers are up and connection is successful.

Returns:

  • (HealthStatusList)


61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
# File 'lib/appwrite/services/health.rb', line 61

def get_cache()
    api_path = '/health/cache'

    api_params = {
    }
    
    api_headers = {
    }

    @client.call(
        method: 'GET',
        path: api_path,
        headers: api_headers,
        params: api_params,
        response_type: Models::HealthStatusList
    )

end

#get_certificate(domain: nil) ⇒ HealthCertificate

Get the SSL certificate for a domain

Parameters:

  • domain (String) (defaults to: nil)

    string

Returns:

  • (HealthCertificate)


85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
# File 'lib/appwrite/services/health.rb', line 85

def get_certificate(domain: nil)
    api_path = '/health/certificate'

    api_params = {
        domain: domain,
    }
    
    api_headers = {
    }

    @client.call(
        method: 'GET',
        path: api_path,
        headers: api_headers,
        params: api_params,
        response_type: Models::HealthCertificate
    )

end

#get_console_pausing(threshold: nil, inactivity_days: nil) ⇒ HealthStatus

Get console pausing health status. Monitors projects approaching the pause threshold to detect potential issues with console access tracking.

Parameters:

  • threshold (Integer) (defaults to: nil)

    Percentage threshold of projects approaching pause. When hit (equal or higher), endpoint returns server error. Default value is 10.

  • inactivity_days (Integer) (defaults to: nil)

    Number of days of inactivity before a project is paused. Should match the plan’s projectInactivityDays setting. Default value is 7.

Returns:

  • (HealthStatus)


113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
# File 'lib/appwrite/services/health.rb', line 113

def get_console_pausing(threshold: nil, inactivity_days: nil)
    api_path = '/health/console-pausing'

    api_params = {
        threshold: threshold,
        inactivityDays: inactivity_days,
    }
    
    api_headers = {
    }

    @client.call(
        method: 'GET',
        path: api_path,
        headers: api_headers,
        params: api_params,
        response_type: Models::HealthStatus
    )

end

#get_dbHealthStatusList

Check the Appwrite database servers are up and connection is successful.

Returns:

  • (HealthStatusList)


138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
# File 'lib/appwrite/services/health.rb', line 138

def get_db()
    api_path = '/health/db'

    api_params = {
    }
    
    api_headers = {
    }

    @client.call(
        method: 'GET',
        path: api_path,
        headers: api_headers,
        params: api_params,
        response_type: Models::HealthStatusList
    )

end

#get_failed_jobs(name:, threshold: nil) ⇒ HealthQueue

Returns the amount of failed jobs in a given queue.

Parameters:

  • name (Name)

    The name of the queue

  • threshold (Integer) (defaults to: nil)

    Queue size threshold. When hit (equal or higher), endpoint returns server error. Default value is 5000.

Returns:

  • (HealthQueue)


321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
343
344
# File 'lib/appwrite/services/health.rb', line 321

def get_failed_jobs(name:, threshold: nil)
    api_path = '/health/queue/failed/{name}'
        .gsub('{name}', name)

    if name.nil?
      raise Appwrite::Exception.new('Missing required parameter: "name"')
    end

    api_params = {
        threshold: threshold,
    }
    
    api_headers = {
    }

    @client.call(
        method: 'GET',
        path: api_path,
        headers: api_headers,
        params: api_params,
        response_type: Models::HealthQueue
    )

end

#get_pub_subHealthStatusList

Check the Appwrite pub-sub servers are up and connection is successful.

Returns:

  • (HealthStatusList)


161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
# File 'lib/appwrite/services/health.rb', line 161

def get_pub_sub()
    api_path = '/health/pubsub'

    api_params = {
    }
    
    api_headers = {
    }

    @client.call(
        method: 'GET',
        path: api_path,
        headers: api_headers,
        params: api_params,
        response_type: Models::HealthStatusList
    )

end

#get_queue_audits(threshold: nil) ⇒ HealthQueue

Get the number of audit logs that are waiting to be processed in the Appwrite internal queue server.

Parameters:

  • threshold (Integer) (defaults to: nil)

    Queue size threshold. When hit (equal or higher), endpoint returns server error. Default value is 5000.

Returns:

  • (HealthQueue)


187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
# File 'lib/appwrite/services/health.rb', line 187

def get_queue_audits(threshold: nil)
    api_path = '/health/queue/audits'

    api_params = {
        threshold: threshold,
    }
    
    api_headers = {
    }

    @client.call(
        method: 'GET',
        path: api_path,
        headers: api_headers,
        params: api_params,
        response_type: Models::HealthQueue
    )

end

#get_queue_builds(threshold: nil) ⇒ HealthQueue

Get the number of builds that are waiting to be processed in the Appwrite internal queue server.

Parameters:

  • threshold (Integer) (defaults to: nil)

    Queue size threshold. When hit (equal or higher), endpoint returns server error. Default value is 5000.

Returns:

  • (HealthQueue)


213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
# File 'lib/appwrite/services/health.rb', line 213

def get_queue_builds(threshold: nil)
    api_path = '/health/queue/builds'

    api_params = {
        threshold: threshold,
    }
    
    api_headers = {
    }

    @client.call(
        method: 'GET',
        path: api_path,
        headers: api_headers,
        params: api_params,
        response_type: Models::HealthQueue
    )

end

#get_queue_certificates(threshold: nil) ⇒ HealthQueue

Get the number of certificates that are waiting to be issued against [Letsencrypt](letsencrypt.org/) in the Appwrite internal queue server.

Parameters:

  • threshold (Integer) (defaults to: nil)

    Queue size threshold. When hit (equal or higher), endpoint returns server error. Default value is 5000.

Returns:

  • (HealthQueue)


240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
# File 'lib/appwrite/services/health.rb', line 240

def get_queue_certificates(threshold: nil)
    api_path = '/health/queue/certificates'

    api_params = {
        threshold: threshold,
    }
    
    api_headers = {
    }

    @client.call(
        method: 'GET',
        path: api_path,
        headers: api_headers,
        params: api_params,
        response_type: Models::HealthQueue
    )

end

#get_queue_databases(name: nil, threshold: nil) ⇒ HealthQueue

Get the number of database changes that are waiting to be processed in the Appwrite internal queue server.

Parameters:

  • name (String) (defaults to: nil)

    Queue name for which to check the queue size

  • threshold (Integer) (defaults to: nil)

    Queue size threshold. When hit (equal or higher), endpoint returns server error. Default value is 5000.

Returns:

  • (HealthQueue)


267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
# File 'lib/appwrite/services/health.rb', line 267

def get_queue_databases(name: nil, threshold: nil)
    api_path = '/health/queue/databases'

    api_params = {
        name: name,
        threshold: threshold,
    }
    
    api_headers = {
    }

    @client.call(
        method: 'GET',
        path: api_path,
        headers: api_headers,
        params: api_params,
        response_type: Models::HealthQueue
    )

end

#get_queue_deletes(threshold: nil) ⇒ HealthQueue

Get the number of background destructive changes that are waiting to be processed in the Appwrite internal queue server.

Parameters:

  • threshold (Integer) (defaults to: nil)

    Queue size threshold. When hit (equal or higher), endpoint returns server error. Default value is 5000.

Returns:

  • (HealthQueue)


294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
# File 'lib/appwrite/services/health.rb', line 294

def get_queue_deletes(threshold: nil)
    api_path = '/health/queue/deletes'

    api_params = {
        threshold: threshold,
    }
    
    api_headers = {
    }

    @client.call(
        method: 'GET',
        path: api_path,
        headers: api_headers,
        params: api_params,
        response_type: Models::HealthQueue
    )

end

#get_queue_functions(threshold: nil) ⇒ HealthQueue

Get the number of function executions that are waiting to be processed in the Appwrite internal queue server.

Parameters:

  • threshold (Integer) (defaults to: nil)

    Queue size threshold. When hit (equal or higher), endpoint returns server error. Default value is 5000.

Returns:

  • (HealthQueue)


352
353
354
355
356
357
358
359
360
361
362
363
364
365
366
367
368
369
370
# File 'lib/appwrite/services/health.rb', line 352

def get_queue_functions(threshold: nil)
    api_path = '/health/queue/functions'

    api_params = {
        threshold: threshold,
    }
    
    api_headers = {
    }

    @client.call(
        method: 'GET',
        path: api_path,
        headers: api_headers,
        params: api_params,
        response_type: Models::HealthQueue
    )

end

#get_queue_logs(threshold: nil) ⇒ HealthQueue

Get the number of logs that are waiting to be processed in the Appwrite internal queue server.

Parameters:

  • threshold (Integer) (defaults to: nil)

    Queue size threshold. When hit (equal or higher), endpoint returns server error. Default value is 5000.

Returns:

  • (HealthQueue)


378
379
380
381
382
383
384
385
386
387
388
389
390
391
392
393
394
395
396
# File 'lib/appwrite/services/health.rb', line 378

def get_queue_logs(threshold: nil)
    api_path = '/health/queue/logs'

    api_params = {
        threshold: threshold,
    }
    
    api_headers = {
    }

    @client.call(
        method: 'GET',
        path: api_path,
        headers: api_headers,
        params: api_params,
        response_type: Models::HealthQueue
    )

end

#get_queue_mails(threshold: nil) ⇒ HealthQueue

Get the number of mails that are waiting to be processed in the Appwrite internal queue server.

Parameters:

  • threshold (Integer) (defaults to: nil)

    Queue size threshold. When hit (equal or higher), endpoint returns server error. Default value is 5000.

Returns:

  • (HealthQueue)


404
405
406
407
408
409
410
411
412
413
414
415
416
417
418
419
420
421
422
# File 'lib/appwrite/services/health.rb', line 404

def get_queue_mails(threshold: nil)
    api_path = '/health/queue/mails'

    api_params = {
        threshold: threshold,
    }
    
    api_headers = {
    }

    @client.call(
        method: 'GET',
        path: api_path,
        headers: api_headers,
        params: api_params,
        response_type: Models::HealthQueue
    )

end

#get_queue_messaging(threshold: nil) ⇒ HealthQueue

Get the number of messages that are waiting to be processed in the Appwrite internal queue server.

Parameters:

  • threshold (Integer) (defaults to: nil)

    Queue size threshold. When hit (equal or higher), endpoint returns server error. Default value is 5000.

Returns:

  • (HealthQueue)


430
431
432
433
434
435
436
437
438
439
440
441
442
443
444
445
446
447
448
# File 'lib/appwrite/services/health.rb', line 430

def get_queue_messaging(threshold: nil)
    api_path = '/health/queue/messaging'

    api_params = {
        threshold: threshold,
    }
    
    api_headers = {
    }

    @client.call(
        method: 'GET',
        path: api_path,
        headers: api_headers,
        params: api_params,
        response_type: Models::HealthQueue
    )

end

#get_queue_migrations(threshold: nil) ⇒ HealthQueue

Get the number of migrations that are waiting to be processed in the Appwrite internal queue server.

Parameters:

  • threshold (Integer) (defaults to: nil)

    Queue size threshold. When hit (equal or higher), endpoint returns server error. Default value is 5000.

Returns:

  • (HealthQueue)


456
457
458
459
460
461
462
463
464
465
466
467
468
469
470
471
472
473
474
# File 'lib/appwrite/services/health.rb', line 456

def get_queue_migrations(threshold: nil)
    api_path = '/health/queue/migrations'

    api_params = {
        threshold: threshold,
    }
    
    api_headers = {
    }

    @client.call(
        method: 'GET',
        path: api_path,
        headers: api_headers,
        params: api_params,
        response_type: Models::HealthQueue
    )

end

#get_queue_stats_resources(threshold: nil) ⇒ HealthQueue

Get the number of metrics that are waiting to be processed in the Appwrite stats resources queue.

Parameters:

  • threshold (Integer) (defaults to: nil)

    Queue size threshold. When hit (equal or higher), endpoint returns server error. Default value is 5000.

Returns:

  • (HealthQueue)


482
483
484
485
486
487
488
489
490
491
492
493
494
495
496
497
498
499
500
# File 'lib/appwrite/services/health.rb', line 482

def get_queue_stats_resources(threshold: nil)
    api_path = '/health/queue/stats-resources'

    api_params = {
        threshold: threshold,
    }
    
    api_headers = {
    }

    @client.call(
        method: 'GET',
        path: api_path,
        headers: api_headers,
        params: api_params,
        response_type: Models::HealthQueue
    )

end

#get_queue_usage(threshold: nil) ⇒ HealthQueue

Get the number of metrics that are waiting to be processed in the Appwrite internal queue server.

Parameters:

  • threshold (Integer) (defaults to: nil)

    Queue size threshold. When hit (equal or higher), endpoint returns server error. Default value is 5000.

Returns:

  • (HealthQueue)


508
509
510
511
512
513
514
515
516
517
518
519
520
521
522
523
524
525
526
# File 'lib/appwrite/services/health.rb', line 508

def get_queue_usage(threshold: nil)
    api_path = '/health/queue/stats-usage'

    api_params = {
        threshold: threshold,
    }
    
    api_headers = {
    }

    @client.call(
        method: 'GET',
        path: api_path,
        headers: api_headers,
        params: api_params,
        response_type: Models::HealthQueue
    )

end

#get_queue_webhooks(threshold: nil) ⇒ HealthQueue

Get the number of webhooks that are waiting to be processed in the Appwrite internal queue server.

Parameters:

  • threshold (Integer) (defaults to: nil)

    Queue size threshold. When hit (equal or higher), endpoint returns server error. Default value is 5000.

Returns:

  • (HealthQueue)


534
535
536
537
538
539
540
541
542
543
544
545
546
547
548
549
550
551
552
# File 'lib/appwrite/services/health.rb', line 534

def get_queue_webhooks(threshold: nil)
    api_path = '/health/queue/webhooks'

    api_params = {
        threshold: threshold,
    }
    
    api_headers = {
    }

    @client.call(
        method: 'GET',
        path: api_path,
        headers: api_headers,
        params: api_params,
        response_type: Models::HealthQueue
    )

end

#get_storageHealthStatus

Check the Appwrite storage device is up and connection is successful.

Returns:

  • (HealthStatus)


558
559
560
561
562
563
564
565
566
567
568
569
570
571
572
573
574
575
# File 'lib/appwrite/services/health.rb', line 558

def get_storage()
    api_path = '/health/storage'

    api_params = {
    }
    
    api_headers = {
    }

    @client.call(
        method: 'GET',
        path: api_path,
        headers: api_headers,
        params: api_params,
        response_type: Models::HealthStatus
    )

end

#get_storage_localHealthStatus

Check the Appwrite local storage device is up and connection is successful.

Returns:

  • (HealthStatus)


581
582
583
584
585
586
587
588
589
590
591
592
593
594
595
596
597
598
# File 'lib/appwrite/services/health.rb', line 581

def get_storage_local()
    api_path = '/health/storage/local'

    api_params = {
    }
    
    api_headers = {
    }

    @client.call(
        method: 'GET',
        path: api_path,
        headers: api_headers,
        params: api_params,
        response_type: Models::HealthStatus
    )

end

#get_timeHealthTime

Check the Appwrite server time is synced with Google remote NTP server. We use this technology to smoothly handle leap seconds with no disruptive events. The [Network Time Protocol](en.wikipedia.org/wiki/Network_Time_Protocol) (NTP) is used by hundreds of millions of computers and devices to synchronize their clocks over the Internet. If your computer sets its own clock, it likely uses NTP.

Returns:

  • (HealthTime)


610
611
612
613
614
615
616
617
618
619
620
621
622
623
624
625
626
627
# File 'lib/appwrite/services/health.rb', line 610

def get_time()
    api_path = '/health/time'

    api_params = {
    }
    
    api_headers = {
    }

    @client.call(
        method: 'GET',
        path: api_path,
        headers: api_headers,
        params: api_params,
        response_type: Models::HealthTime
    )

end