Class: Appwrite::Health

Inherits:
Service show all
Defined in:
lib/appwrite/services/health.rb

Instance Method Summary collapse

Constructor Details

#initialize(client) ⇒ Health



6
7
8
# File 'lib/appwrite/services/health.rb', line 6

def initialize(client)
    @client = client
end

Instance Method Details

#getHealthStatus

Check the Appwrite HTTP server is up and responsive.



14
15
16
17
18
19
20
21
22
23
24
25
26
27
28
29
30
# File 'lib/appwrite/services/health.rb', line 14

def get()
    api_path = '/health'

    api_params = {
    }
    
    api_headers = {
    }

    @client.call(
        method: 'GET',
        path: api_path,
        headers: api_headers,
        params: api_params,
        response_type: Models::HealthStatus
    )
end

#get_antivirusHealthAntivirus

Check the Appwrite Antivirus server is up and connection is successful.



37
38
39
40
41
42
43
44
45
46
47
48
49
50
51
52
53
# File 'lib/appwrite/services/health.rb', line 37

def get_antivirus()
    api_path = '/health/anti-virus'

    api_params = {
    }
    
    api_headers = {
    }

    @client.call(
        method: 'GET',
        path: api_path,
        headers: api_headers,
        params: api_params,
        response_type: Models::HealthAntivirus
    )
end

#get_cacheHealthStatus

Check the Appwrite in-memory cache servers are up and connection is successful.



61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
# File 'lib/appwrite/services/health.rb', line 61

def get_cache()
    api_path = '/health/cache'

    api_params = {
    }
    
    api_headers = {
    }

    @client.call(
        method: 'GET',
        path: api_path,
        headers: api_headers,
        params: api_params,
        response_type: Models::HealthStatus
    )
end

#get_certificate(domain: nil) ⇒ HealthCertificate

Get the SSL certificate for a domain



85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
# File 'lib/appwrite/services/health.rb', line 85

def get_certificate(domain: nil)
    api_path = '/health/certificate'

    api_params = {
        domain: domain,
    }
    
    api_headers = {
    }

    @client.call(
        method: 'GET',
        path: api_path,
        headers: api_headers,
        params: api_params,
        response_type: Models::HealthCertificate
    )
end

#get_dbHealthStatus

Check the Appwrite database servers are up and connection is successful.



109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
# File 'lib/appwrite/services/health.rb', line 109

def get_db()
    api_path = '/health/db'

    api_params = {
    }
    
    api_headers = {
    }

    @client.call(
        method: 'GET',
        path: api_path,
        headers: api_headers,
        params: api_params,
        response_type: Models::HealthStatus
    )
end

#get_failed_jobs(name:, threshold: nil) ⇒ HealthQueue

Returns the amount of failed jobs in a given queue.



265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
# File 'lib/appwrite/services/health.rb', line 265

def get_failed_jobs(name:, threshold: nil)
    api_path = '/health/queue/failed/{name}'
        .gsub('{name}', name)

    if name.nil?
      raise Appwrite::Exception.new('Missing required parameter: "name"')
    end

    api_params = {
        threshold: threshold,
    }
    
    api_headers = {
    }

    @client.call(
        method: 'GET',
        path: api_path,
        headers: api_headers,
        params: api_params,
        response_type: Models::HealthQueue
    )
end

#get_pub_subHealthStatus

Check the Appwrite pub-sub servers are up and connection is successful.



132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
# File 'lib/appwrite/services/health.rb', line 132

def get_pub_sub()
    api_path = '/health/pubsub'

    api_params = {
    }
    
    api_headers = {
    }

    @client.call(
        method: 'GET',
        path: api_path,
        headers: api_headers,
        params: api_params,
        response_type: Models::HealthStatus
    )
end

#get_queue_builds(threshold: nil) ⇒ HealthQueue

Get the number of builds that are waiting to be processed in the Appwrite internal queue server.



157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
# File 'lib/appwrite/services/health.rb', line 157

def get_queue_builds(threshold: nil)
    api_path = '/health/queue/builds'

    api_params = {
        threshold: threshold,
    }
    
    api_headers = {
    }

    @client.call(
        method: 'GET',
        path: api_path,
        headers: api_headers,
        params: api_params,
        response_type: Models::HealthQueue
    )
end

#get_queue_certificates(threshold: nil) ⇒ HealthQueue

Get the number of certificates that are waiting to be issued against [Letsencrypt](letsencrypt.org/) in the Appwrite internal queue server.



184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
# File 'lib/appwrite/services/health.rb', line 184

def get_queue_certificates(threshold: nil)
    api_path = '/health/queue/certificates'

    api_params = {
        threshold: threshold,
    }
    
    api_headers = {
    }

    @client.call(
        method: 'GET',
        path: api_path,
        headers: api_headers,
        params: api_params,
        response_type: Models::HealthQueue
    )
end

#get_queue_databases(name: nil, threshold: nil) ⇒ HealthQueue

Get the number of database changes that are waiting to be processed in the Appwrite internal queue server.



211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
# File 'lib/appwrite/services/health.rb', line 211

def get_queue_databases(name: nil, threshold: nil)
    api_path = '/health/queue/databases'

    api_params = {
        name: name,
        threshold: threshold,
    }
    
    api_headers = {
    }

    @client.call(
        method: 'GET',
        path: api_path,
        headers: api_headers,
        params: api_params,
        response_type: Models::HealthQueue
    )
end

#get_queue_deletes(threshold: nil) ⇒ HealthQueue

Get the number of background destructive changes that are waiting to be processed in the Appwrite internal queue server.



238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
# File 'lib/appwrite/services/health.rb', line 238

def get_queue_deletes(threshold: nil)
    api_path = '/health/queue/deletes'

    api_params = {
        threshold: threshold,
    }
    
    api_headers = {
    }

    @client.call(
        method: 'GET',
        path: api_path,
        headers: api_headers,
        params: api_params,
        response_type: Models::HealthQueue
    )
end

#get_queue_functions(threshold: nil) ⇒ HealthQueue

Get the number of function executions that are waiting to be processed in the Appwrite internal queue server.



296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
# File 'lib/appwrite/services/health.rb', line 296

def get_queue_functions(threshold: nil)
    api_path = '/health/queue/functions'

    api_params = {
        threshold: threshold,
    }
    
    api_headers = {
    }

    @client.call(
        method: 'GET',
        path: api_path,
        headers: api_headers,
        params: api_params,
        response_type: Models::HealthQueue
    )
end

#get_queue_logs(threshold: nil) ⇒ HealthQueue

Get the number of logs that are waiting to be processed in the Appwrite internal queue server.



322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
# File 'lib/appwrite/services/health.rb', line 322

def get_queue_logs(threshold: nil)
    api_path = '/health/queue/logs'

    api_params = {
        threshold: threshold,
    }
    
    api_headers = {
    }

    @client.call(
        method: 'GET',
        path: api_path,
        headers: api_headers,
        params: api_params,
        response_type: Models::HealthQueue
    )
end

#get_queue_mails(threshold: nil) ⇒ HealthQueue

Get the number of mails that are waiting to be processed in the Appwrite internal queue server.



348
349
350
351
352
353
354
355
356
357
358
359
360
361
362
363
364
365
# File 'lib/appwrite/services/health.rb', line 348

def get_queue_mails(threshold: nil)
    api_path = '/health/queue/mails'

    api_params = {
        threshold: threshold,
    }
    
    api_headers = {
    }

    @client.call(
        method: 'GET',
        path: api_path,
        headers: api_headers,
        params: api_params,
        response_type: Models::HealthQueue
    )
end

#get_queue_messaging(threshold: nil) ⇒ HealthQueue

Get the number of messages that are waiting to be processed in the Appwrite internal queue server.



374
375
376
377
378
379
380
381
382
383
384
385
386
387
388
389
390
391
# File 'lib/appwrite/services/health.rb', line 374

def get_queue_messaging(threshold: nil)
    api_path = '/health/queue/messaging'

    api_params = {
        threshold: threshold,
    }
    
    api_headers = {
    }

    @client.call(
        method: 'GET',
        path: api_path,
        headers: api_headers,
        params: api_params,
        response_type: Models::HealthQueue
    )
end

#get_queue_migrations(threshold: nil) ⇒ HealthQueue

Get the number of migrations that are waiting to be processed in the Appwrite internal queue server.



400
401
402
403
404
405
406
407
408
409
410
411
412
413
414
415
416
417
# File 'lib/appwrite/services/health.rb', line 400

def get_queue_migrations(threshold: nil)
    api_path = '/health/queue/migrations'

    api_params = {
        threshold: threshold,
    }
    
    api_headers = {
    }

    @client.call(
        method: 'GET',
        path: api_path,
        headers: api_headers,
        params: api_params,
        response_type: Models::HealthQueue
    )
end

#get_queue_stats_resources(threshold: nil) ⇒ HealthQueue

Get the number of metrics that are waiting to be processed in the Appwrite stats resources queue.



426
427
428
429
430
431
432
433
434
435
436
437
438
439
440
441
442
443
# File 'lib/appwrite/services/health.rb', line 426

def get_queue_stats_resources(threshold: nil)
    api_path = '/health/queue/stats-resources'

    api_params = {
        threshold: threshold,
    }
    
    api_headers = {
    }

    @client.call(
        method: 'GET',
        path: api_path,
        headers: api_headers,
        params: api_params,
        response_type: Models::HealthQueue
    )
end

#get_queue_usage(threshold: nil) ⇒ HealthQueue

Get the number of metrics that are waiting to be processed in the Appwrite internal queue server.



452
453
454
455
456
457
458
459
460
461
462
463
464
465
466
467
468
469
# File 'lib/appwrite/services/health.rb', line 452

def get_queue_usage(threshold: nil)
    api_path = '/health/queue/stats-usage'

    api_params = {
        threshold: threshold,
    }
    
    api_headers = {
    }

    @client.call(
        method: 'GET',
        path: api_path,
        headers: api_headers,
        params: api_params,
        response_type: Models::HealthQueue
    )
end

#get_queue_webhooks(threshold: nil) ⇒ HealthQueue

Get the number of webhooks that are waiting to be processed in the Appwrite internal queue server.



478
479
480
481
482
483
484
485
486
487
488
489
490
491
492
493
494
495
# File 'lib/appwrite/services/health.rb', line 478

def get_queue_webhooks(threshold: nil)
    api_path = '/health/queue/webhooks'

    api_params = {
        threshold: threshold,
    }
    
    api_headers = {
    }

    @client.call(
        method: 'GET',
        path: api_path,
        headers: api_headers,
        params: api_params,
        response_type: Models::HealthQueue
    )
end

#get_storageHealthStatus

Check the Appwrite storage device is up and connection is successful.



502
503
504
505
506
507
508
509
510
511
512
513
514
515
516
517
518
# File 'lib/appwrite/services/health.rb', line 502

def get_storage()
    api_path = '/health/storage'

    api_params = {
    }
    
    api_headers = {
    }

    @client.call(
        method: 'GET',
        path: api_path,
        headers: api_headers,
        params: api_params,
        response_type: Models::HealthStatus
    )
end

#get_storage_localHealthStatus

Check the Appwrite local storage device is up and connection is successful.



525
526
527
528
529
530
531
532
533
534
535
536
537
538
539
540
541
# File 'lib/appwrite/services/health.rb', line 525

def get_storage_local()
    api_path = '/health/storage/local'

    api_params = {
    }
    
    api_headers = {
    }

    @client.call(
        method: 'GET',
        path: api_path,
        headers: api_headers,
        params: api_params,
        response_type: Models::HealthStatus
    )
end

#get_timeHealthTime

Check the Appwrite server time is synced with Google remote NTP server. We use this technology to smoothly handle leap seconds with no disruptive events. The [Network Time Protocol](en.wikipedia.org/wiki/Network_Time_Protocol) (NTP) is used by hundreds of millions of computers and devices to synchronize their clocks over the Internet. If your computer sets its own clock, it likely uses NTP.



554
555
556
557
558
559
560
561
562
563
564
565
566
567
568
569
570
# File 'lib/appwrite/services/health.rb', line 554

def get_time()
    api_path = '/health/time'

    api_params = {
    }
    
    api_headers = {
    }

    @client.call(
        method: 'GET',
        path: api_path,
        headers: api_headers,
        params: api_params,
        response_type: Models::HealthTime
    )
end