Class: Appwrite::Organization
- Defined in:
- lib/appwrite/services/organization.rb
Instance Method Summary collapse
-
#create_key(key_id:, name:, scopes:, expire: nil) ⇒ Key
Create a new organization API key.
-
#create_membership(roles:, email: nil, user_id: nil, phone: nil, url: nil, name: nil) ⇒ Membership
Invite a new member to join the current organization.
-
#create_project(project_id:, name:, region: nil) ⇒ Project
Create a new project.
-
#delete ⇒ Object
Delete the current organization.
-
#delete_key(key_id:) ⇒ Object
Delete a key by its unique ID.
-
#delete_membership(membership_id:) ⇒ Object
Remove a member from the current organization.
-
#delete_project(project_id:) ⇒ Object
Delete a project by its unique ID.
-
#get ⇒ Organization
Get the current organization.
-
#get_key(key_id:) ⇒ Key
Get a key by its unique ID.
-
#get_membership(membership_id:) ⇒ Membership
Get a membership from the current organization by its unique ID.
-
#get_project(project_id:) ⇒ Project
Get a project.
-
#initialize(client) ⇒ Organization
constructor
A new instance of Organization.
-
#list_keys(queries: nil, total: nil) ⇒ KeyList
Get a list of all API keys from the current organization.
-
#list_memberships(queries: nil, search: nil, total: nil) ⇒ MembershipList
Get a list of all memberships from the current organization.
-
#list_projects(queries: nil, search: nil, total: nil) ⇒ ProjectList
Get a list of all projects.
-
#update(name:) ⇒ Organization
Update the current organization's name.
-
#update_key(key_id:, name:, scopes:, expire: nil) ⇒ Key
Update a key by its unique ID.
-
#update_membership(membership_id:, roles:) ⇒ Membership
Modify the roles of a member in the current organization.
-
#update_project(project_id:, name:) ⇒ Project
Update a project by its unique ID.
Constructor Details
#initialize(client) ⇒ Organization
Returns a new instance of Organization.
6 7 8 |
# File 'lib/appwrite/services/organization.rb', line 6 def initialize(client) @client = client end |
Instance Method Details
#create_key(key_id:, name:, scopes:, expire: nil) ⇒ Key
Create a new organization API key.
129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 |
# File 'lib/appwrite/services/organization.rb', line 129 def create_key(key_id:, name:, scopes:, expire: nil) api_path = '/organization/keys' if key_id.nil? raise Appwrite::Exception.new('Missing required parameter: "keyId"') end if name.nil? raise Appwrite::Exception.new('Missing required parameter: "name"') end if scopes.nil? raise Appwrite::Exception.new('Missing required parameter: "scopes"') end api_params = { keyId: key_id, name: name, scopes: scopes, expire: expire, } api_headers = { "X-Appwrite-Project": @client.get_config('project'), "content-type": 'application/json', "accept": 'application/json', } @client.call( method: 'POST', path: api_path, headers: api_headers, params: api_params, response_type: Models::Key ) end |
#create_membership(roles:, email: nil, user_id: nil, phone: nil, url: nil, name: nil) ⇒ Membership
Invite a new member to join the current organization. An email with a link to join the organization will be sent to the new member's email address. If member doesn't exist in the project it will be automatically created.
320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 350 |
# File 'lib/appwrite/services/organization.rb', line 320 def create_membership(roles:, email: nil, user_id: nil, phone: nil, url: nil, name: nil) api_path = '/organization/memberships' if roles.nil? raise Appwrite::Exception.new('Missing required parameter: "roles"') end api_params = { email: email, userId: user_id, phone: phone, roles: roles, url: url, name: name, } api_headers = { "X-Appwrite-Project": @client.get_config('project'), "content-type": 'application/json', "accept": 'application/json', } @client.call( method: 'POST', path: api_path, headers: api_headers, params: api_params, response_type: Models::Membership ) end |
#create_project(project_id:, name:, region: nil) ⇒ Project
Create a new project.
492 493 494 495 496 497 498 499 500 501 502 503 504 505 506 507 508 509 510 511 512 513 514 515 516 517 518 519 520 521 522 523 |
# File 'lib/appwrite/services/organization.rb', line 492 def create_project(project_id:, name:, region: nil) api_path = '/organization/projects' if project_id.nil? raise Appwrite::Exception.new('Missing required parameter: "projectId"') end if name.nil? raise Appwrite::Exception.new('Missing required parameter: "name"') end api_params = { projectId: project_id, name: name, region: region, } api_headers = { "X-Appwrite-Project": @client.get_config('project'), "content-type": 'application/json', "accept": 'application/json', } @client.call( method: 'POST', path: api_path, headers: api_headers, params: api_params, response_type: Models::Project ) end |
#delete ⇒ Object
Delete the current organization. All projects that belong to the organization are deleted as well.
72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 |
# File 'lib/appwrite/services/organization.rb', line 72 def delete() api_path = '/organization' api_params = { } api_headers = { "X-Appwrite-Project": @client.get_config('project'), "content-type": 'application/json', } @client.call( method: 'DELETE', path: api_path, headers: api_headers, params: api_params, ) end |
#delete_key(key_id:) ⇒ Object
Delete a key by its unique ID. Once deleted, the key can no longer be used to authenticate API calls.
252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 |
# File 'lib/appwrite/services/organization.rb', line 252 def delete_key(key_id:) api_path = '/organization/keys/{keyId}' .gsub('{keyId}', key_id) if key_id.nil? raise Appwrite::Exception.new('Missing required parameter: "keyId"') end api_params = { } api_headers = { "X-Appwrite-Project": @client.get_config('project'), "content-type": 'application/json', } @client.call( method: 'DELETE', path: api_path, headers: api_headers, params: api_params, ) end |
#delete_membership(membership_id:) ⇒ Object
Remove a member from the current organization. The member is removed whether they accepted the invitation or not; a pending invitation is revoked.
428 429 430 431 432 433 434 435 436 437 438 439 440 441 442 443 444 445 446 447 448 449 450 451 |
# File 'lib/appwrite/services/organization.rb', line 428 def delete_membership(membership_id:) api_path = '/organization/memberships/{membershipId}' .gsub('{membershipId}', membership_id) if membership_id.nil? raise Appwrite::Exception.new('Missing required parameter: "membershipId"') end api_params = { } api_headers = { "X-Appwrite-Project": @client.get_config('project'), "content-type": 'application/json', } @client.call( method: 'DELETE', path: api_path, headers: api_headers, params: api_params, ) end |
#delete_project(project_id:) ⇒ Object
Delete a project by its unique ID.
598 599 600 601 602 603 604 605 606 607 608 609 610 611 612 613 614 615 616 617 618 619 620 621 |
# File 'lib/appwrite/services/organization.rb', line 598 def delete_project(project_id:) api_path = '/organization/projects/{projectId}' .gsub('{projectId}', project_id) if project_id.nil? raise Appwrite::Exception.new('Missing required parameter: "projectId"') end api_params = { } api_headers = { "X-Appwrite-Project": @client.get_config('project'), "content-type": 'application/json', } @client.call( method: 'DELETE', path: api_path, headers: api_headers, params: api_params, ) end |
#get ⇒ Organization
Get the current organization.
14 15 16 17 18 19 20 21 22 23 24 25 26 27 28 29 30 31 32 33 |
# File 'lib/appwrite/services/organization.rb', line 14 def get() api_path = '/organization' api_params = { } api_headers = { "X-Appwrite-Project": @client.get_config('project'), "accept": 'application/json', } @client.call( method: 'GET', path: api_path, headers: api_headers, params: api_params, response_type: Models::Organization ) end |
#get_key(key_id:) ⇒ Key
Get a key by its unique ID. This endpoint returns details about a specific API key in your organization including its scopes.
173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 |
# File 'lib/appwrite/services/organization.rb', line 173 def get_key(key_id:) api_path = '/organization/keys/{keyId}' .gsub('{keyId}', key_id) if key_id.nil? raise Appwrite::Exception.new('Missing required parameter: "keyId"') end api_params = { } api_headers = { "X-Appwrite-Project": @client.get_config('project'), "accept": 'application/json', } @client.call( method: 'GET', path: api_path, headers: api_headers, params: api_params, response_type: Models::Key ) end |
#get_membership(membership_id:) ⇒ Membership
Get a membership from the current organization by its unique ID.
357 358 359 360 361 362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 381 |
# File 'lib/appwrite/services/organization.rb', line 357 def get_membership(membership_id:) api_path = '/organization/memberships/{membershipId}' .gsub('{membershipId}', membership_id) if membership_id.nil? raise Appwrite::Exception.new('Missing required parameter: "membershipId"') end api_params = { } api_headers = { "X-Appwrite-Project": @client.get_config('project'), "accept": 'application/json', } @client.call( method: 'GET', path: api_path, headers: api_headers, params: api_params, response_type: Models::Membership ) end |
#get_project(project_id:) ⇒ Project
Get a project.
530 531 532 533 534 535 536 537 538 539 540 541 542 543 544 545 546 547 548 549 550 551 552 553 |
# File 'lib/appwrite/services/organization.rb', line 530 def get_project(project_id:) api_path = '/organization/projects/{projectId}' .gsub('{projectId}', project_id) if project_id.nil? raise Appwrite::Exception.new('Missing required parameter: "projectId"') end api_params = { } api_headers = { "X-Appwrite-Project": @client.get_config('project'), } @client.call( method: 'GET', path: api_path, headers: api_headers, params: api_params, response_type: Models::Project ) end |
#list_keys(queries: nil, total: nil) ⇒ KeyList
Get a list of all API keys from the current organization.
98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 |
# File 'lib/appwrite/services/organization.rb', line 98 def list_keys(queries: nil, total: nil) api_path = '/organization/keys' api_params = { queries: queries, total: total, } api_headers = { "X-Appwrite-Project": @client.get_config('project'), "accept": 'application/json', } @client.call( method: 'GET', path: api_path, headers: api_headers, params: api_params, response_type: Models::KeyList ) end |
#list_memberships(queries: nil, search: nil, total: nil) ⇒ MembershipList
Get a list of all memberships from the current organization.
284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 |
# File 'lib/appwrite/services/organization.rb', line 284 def list_memberships(queries: nil, search: nil, total: nil) api_path = '/organization/memberships' api_params = { queries: queries, search: search, total: total, } api_headers = { "X-Appwrite-Project": @client.get_config('project'), "accept": 'application/json', } @client.call( method: 'GET', path: api_path, headers: api_headers, params: api_params, response_type: Models::MembershipList ) end |
#list_projects(queries: nil, search: nil, total: nil) ⇒ ProjectList
Get a list of all projects. You can use the query params to filter your results.
461 462 463 464 465 466 467 468 469 470 471 472 473 474 475 476 477 478 479 480 481 482 483 |
# File 'lib/appwrite/services/organization.rb', line 461 def list_projects(queries: nil, search: nil, total: nil) api_path = '/organization/projects' api_params = { queries: queries, search: search, total: total, } api_headers = { "X-Appwrite-Project": @client.get_config('project'), "accept": 'application/json', } @client.call( method: 'GET', path: api_path, headers: api_headers, params: api_params, response_type: Models::ProjectList ) end |
#update(name:) ⇒ Organization
Update the current organization's name.
40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 |
# File 'lib/appwrite/services/organization.rb', line 40 def update(name:) api_path = '/organization' if name.nil? raise Appwrite::Exception.new('Missing required parameter: "name"') end api_params = { name: name, } api_headers = { "X-Appwrite-Project": @client.get_config('project'), "content-type": 'application/json', "accept": 'application/json', } @client.call( method: 'PUT', path: api_path, headers: api_headers, params: api_params, response_type: Models::Organization ) end |
#update_key(key_id:, name:, scopes:, expire: nil) ⇒ Key
Update a key by its unique ID. Use this endpoint to update the name, scopes, or expiration time of an API key.
208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 |
# File 'lib/appwrite/services/organization.rb', line 208 def update_key(key_id:, name:, scopes:, expire: nil) api_path = '/organization/keys/{keyId}' .gsub('{keyId}', key_id) if key_id.nil? raise Appwrite::Exception.new('Missing required parameter: "keyId"') end if name.nil? raise Appwrite::Exception.new('Missing required parameter: "name"') end if scopes.nil? raise Appwrite::Exception.new('Missing required parameter: "scopes"') end api_params = { name: name, scopes: scopes, expire: expire, } api_headers = { "X-Appwrite-Project": @client.get_config('project'), "content-type": 'application/json', "accept": 'application/json', } @client.call( method: 'PUT', path: api_path, headers: api_headers, params: api_params, response_type: Models::Key ) end |
#update_membership(membership_id:, roles:) ⇒ Membership
Modify the roles of a member in the current organization.
389 390 391 392 393 394 395 396 397 398 399 400 401 402 403 404 405 406 407 408 409 410 411 412 413 414 415 416 417 418 419 |
# File 'lib/appwrite/services/organization.rb', line 389 def update_membership(membership_id:, roles:) api_path = '/organization/memberships/{membershipId}' .gsub('{membershipId}', membership_id) if membership_id.nil? raise Appwrite::Exception.new('Missing required parameter: "membershipId"') end if roles.nil? raise Appwrite::Exception.new('Missing required parameter: "roles"') end api_params = { roles: roles, } api_headers = { "X-Appwrite-Project": @client.get_config('project'), "content-type": 'application/json', "accept": 'application/json', } @client.call( method: 'PATCH', path: api_path, headers: api_headers, params: api_params, response_type: Models::Membership ) end |
#update_project(project_id:, name:) ⇒ Project
Update a project by its unique ID.
561 562 563 564 565 566 567 568 569 570 571 572 573 574 575 576 577 578 579 580 581 582 583 584 585 586 587 588 589 590 591 |
# File 'lib/appwrite/services/organization.rb', line 561 def update_project(project_id:, name:) api_path = '/organization/projects/{projectId}' .gsub('{projectId}', project_id) if project_id.nil? raise Appwrite::Exception.new('Missing required parameter: "projectId"') end if name.nil? raise Appwrite::Exception.new('Missing required parameter: "name"') end api_params = { name: name, } api_headers = { "X-Appwrite-Project": @client.get_config('project'), "content-type": 'application/json', "accept": 'application/json', } @client.call( method: 'PATCH', path: api_path, headers: api_headers, params: api_params, response_type: Models::Project ) end |