Class: Appwrite::Organization
- Defined in:
- lib/appwrite/services/organization.rb
Instance Method Summary collapse
-
#create_key(key_id:, name:, scopes:, expire: nil) ⇒ Key
Create a new organization API key.
-
#create_project(project_id:, name:, region: nil) ⇒ Project
Create a new project.
-
#delete_key(key_id:) ⇒ Object
Delete a key by its unique ID.
-
#delete_project(project_id:) ⇒ Object
Delete a project by its unique ID.
-
#get_key(key_id:) ⇒ Key
Get a key by its unique ID.
-
#get_project(project_id:) ⇒ Project
Get a project.
-
#initialize(client) ⇒ Organization
constructor
A new instance of Organization.
-
#list_keys(queries: nil, total: nil) ⇒ KeyList
Get a list of all API keys from the current organization.
-
#list_projects(queries: nil, search: nil, total: nil) ⇒ ProjectList
Get a list of all projects.
-
#update_key(key_id:, name:, scopes:, expire: nil) ⇒ Key
Update a key by its unique ID.
-
#update_project(project_id:, name:) ⇒ Project
Update a project by its unique ID.
Constructor Details
#initialize(client) ⇒ Organization
Returns a new instance of Organization.
6 7 8 |
# File 'lib/appwrite/services/organization.rb', line 6 def initialize(client) @client = client end |
Instance Method Details
#create_key(key_id:, name:, scopes:, expire: nil) ⇒ Key
Create a new organization API key.
46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 |
# File 'lib/appwrite/services/organization.rb', line 46 def create_key(key_id:, name:, scopes:, expire: nil) api_path = '/organization/keys' if key_id.nil? raise Appwrite::Exception.new('Missing required parameter: "keyId"') end if name.nil? raise Appwrite::Exception.new('Missing required parameter: "name"') end if scopes.nil? raise Appwrite::Exception.new('Missing required parameter: "scopes"') end api_params = { keyId: key_id, name: name, scopes: scopes, expire: expire, } api_headers = { "X-Appwrite-Project": @client.get_config('project'), "content-type": 'application/json', } @client.call( method: 'POST', path: api_path, headers: api_headers, params: api_params, response_type: Models::Key ) end |
#create_project(project_id:, name:, region: nil) ⇒ Project
Create a new project.
229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 |
# File 'lib/appwrite/services/organization.rb', line 229 def create_project(project_id:, name:, region: nil) api_path = '/organization/projects' if project_id.nil? raise Appwrite::Exception.new('Missing required parameter: "projectId"') end if name.nil? raise Appwrite::Exception.new('Missing required parameter: "name"') end api_params = { projectId: project_id, name: name, region: region, } api_headers = { "X-Appwrite-Project": @client.get_config('project'), "content-type": 'application/json', } @client.call( method: 'POST', path: api_path, headers: api_headers, params: api_params, response_type: Models::Project ) end |
#delete_key(key_id:) ⇒ Object
Delete a key by its unique ID. Once deleted, the key can no longer be used to authenticate API calls.
166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 |
# File 'lib/appwrite/services/organization.rb', line 166 def delete_key(key_id:) api_path = '/organization/keys/{keyId}' .gsub('{keyId}', key_id) if key_id.nil? raise Appwrite::Exception.new('Missing required parameter: "keyId"') end api_params = { } api_headers = { "X-Appwrite-Project": @client.get_config('project'), "content-type": 'application/json', } @client.call( method: 'DELETE', path: api_path, headers: api_headers, params: api_params, ) end |
#delete_project(project_id:) ⇒ Object
Delete a project by its unique ID.
333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 350 351 352 353 354 355 356 |
# File 'lib/appwrite/services/organization.rb', line 333 def delete_project(project_id:) api_path = '/organization/projects/{projectId}' .gsub('{projectId}', project_id) if project_id.nil? raise Appwrite::Exception.new('Missing required parameter: "projectId"') end api_params = { } api_headers = { "X-Appwrite-Project": @client.get_config('project'), "content-type": 'application/json', } @client.call( method: 'DELETE', path: api_path, headers: api_headers, params: api_params, ) end |
#get_key(key_id:) ⇒ Key
Get a key by its unique ID. This endpoint returns details about a specific API key in your organization including its scopes.
89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 |
# File 'lib/appwrite/services/organization.rb', line 89 def get_key(key_id:) api_path = '/organization/keys/{keyId}' .gsub('{keyId}', key_id) if key_id.nil? raise Appwrite::Exception.new('Missing required parameter: "keyId"') end api_params = { } api_headers = { "X-Appwrite-Project": @client.get_config('project'), } @client.call( method: 'GET', path: api_path, headers: api_headers, params: api_params, response_type: Models::Key ) end |
#get_project(project_id:) ⇒ Project
Get a project.
266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 |
# File 'lib/appwrite/services/organization.rb', line 266 def get_project(project_id:) api_path = '/organization/projects/{projectId}' .gsub('{projectId}', project_id) if project_id.nil? raise Appwrite::Exception.new('Missing required parameter: "projectId"') end api_params = { } api_headers = { "X-Appwrite-Project": @client.get_config('project'), } @client.call( method: 'GET', path: api_path, headers: api_headers, params: api_params, response_type: Models::Project ) end |
#list_keys(queries: nil, total: nil) ⇒ KeyList
Get a list of all API keys from the current organization.
16 17 18 19 20 21 22 23 24 25 26 27 28 29 30 31 32 33 34 35 36 |
# File 'lib/appwrite/services/organization.rb', line 16 def list_keys(queries: nil, total: nil) api_path = '/organization/keys' api_params = { queries: queries, total: total, } api_headers = { "X-Appwrite-Project": @client.get_config('project'), } @client.call( method: 'GET', path: api_path, headers: api_headers, params: api_params, response_type: Models::KeyList ) end |
#list_projects(queries: nil, search: nil, total: nil) ⇒ ProjectList
Get a list of all projects. You can use the query params to filter your results.
199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 |
# File 'lib/appwrite/services/organization.rb', line 199 def list_projects(queries: nil, search: nil, total: nil) api_path = '/organization/projects' api_params = { queries: queries, search: search, total: total, } api_headers = { "X-Appwrite-Project": @client.get_config('project'), } @client.call( method: 'GET', path: api_path, headers: api_headers, params: api_params, response_type: Models::ProjectList ) end |
#update_key(key_id:, name:, scopes:, expire: nil) ⇒ Key
Update a key by its unique ID. Use this endpoint to update the name, scopes, or expiration time of an API key.
123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 |
# File 'lib/appwrite/services/organization.rb', line 123 def update_key(key_id:, name:, scopes:, expire: nil) api_path = '/organization/keys/{keyId}' .gsub('{keyId}', key_id) if key_id.nil? raise Appwrite::Exception.new('Missing required parameter: "keyId"') end if name.nil? raise Appwrite::Exception.new('Missing required parameter: "name"') end if scopes.nil? raise Appwrite::Exception.new('Missing required parameter: "scopes"') end api_params = { name: name, scopes: scopes, expire: expire, } api_headers = { "X-Appwrite-Project": @client.get_config('project'), "content-type": 'application/json', } @client.call( method: 'PUT', path: api_path, headers: api_headers, params: api_params, response_type: Models::Key ) end |
#update_project(project_id:, name:) ⇒ Project
Update a project by its unique ID.
297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 |
# File 'lib/appwrite/services/organization.rb', line 297 def update_project(project_id:, name:) api_path = '/organization/projects/{projectId}' .gsub('{projectId}', project_id) if project_id.nil? raise Appwrite::Exception.new('Missing required parameter: "projectId"') end if name.nil? raise Appwrite::Exception.new('Missing required parameter: "name"') end api_params = { name: name, } api_headers = { "X-Appwrite-Project": @client.get_config('project'), "content-type": 'application/json', } @client.call( method: 'PATCH', path: api_path, headers: api_headers, params: api_params, response_type: Models::Project ) end |