Class: Appwrite::Sites
- Defined in:
- lib/appwrite/services/sites.rb
Instance Method Summary collapse
-
#create(site_id:, name:, framework:, build_runtime:, enabled: nil, logging: nil, timeout: nil, install_command: nil, build_command: nil, start_command: nil, output_directory: nil, adapter: nil, installation_id: nil, fallback_file: nil, provider_repository_id: nil, provider_branch: nil, provider_silent_mode: nil, provider_root_directory: nil, build_specification: nil, runtime_specification: nil, deployment_retention: nil) ⇒ Site
Create a new site.
-
#create_deployment(site_id:, code:, install_command: nil, build_command: nil, output_directory: nil, activate: nil, on_progress: nil) ⇒ Deployment
Create a new site code deployment.
-
#create_duplicate_deployment(site_id:, deployment_id:) ⇒ Deployment
Create a new build for an existing site deployment.
-
#create_template_deployment(site_id:, repository:, owner:, root_directory:, type:, reference:, activate: nil) ⇒ Deployment
Create a deployment based on a template.
-
#create_variable(site_id:, key:, value:, secret: nil) ⇒ Variable
Create a new site variable.
-
#create_vcs_deployment(site_id:, type:, reference:, activate: nil) ⇒ Deployment
Create a deployment when a site is connected to VCS.
-
#delete(site_id:) ⇒ Object
Delete a site by its unique ID.
-
#delete_deployment(site_id:, deployment_id:) ⇒ Object
Delete a site deployment by its unique ID.
-
#delete_log(site_id:, log_id:) ⇒ Object
Delete a site log by its unique ID.
-
#delete_variable(site_id:, variable_id:) ⇒ Object
Delete a variable by its unique ID.
-
#get(site_id:) ⇒ Site
Get a site by its unique ID.
-
#get_deployment(site_id:, deployment_id:) ⇒ Deployment
Get a site deployment by its unique ID.
-
#get_deployment_download(site_id:, deployment_id:, type: nil) ⇒ Object
Get a site deployment content by its unique ID.
-
#get_log(site_id:, log_id:) ⇒ Execution
Get a site request log by its unique ID.
-
#get_variable(site_id:, variable_id:) ⇒ Variable
Get a variable by its unique ID.
-
#initialize(client) ⇒ Sites
constructor
A new instance of Sites.
-
#list(queries: nil, search: nil, total: nil) ⇒ SiteList
Get a list of all the project’s sites.
-
#list_deployments(site_id:, queries: nil, search: nil, total: nil) ⇒ DeploymentList
Get a list of all the site’s code deployments.
-
#list_frameworks ⇒ FrameworkList
Get a list of all frameworks that are currently available on the server instance.
-
#list_logs(site_id:, queries: nil, total: nil) ⇒ ExecutionList
Get a list of all site logs.
-
#list_specifications ⇒ SpecificationList
List allowed site specifications for this instance.
-
#list_variables(site_id:) ⇒ VariableList
Get a list of all variables of a specific site.
-
#update(site_id:, name:, framework:, enabled: nil, logging: nil, timeout: nil, install_command: nil, build_command: nil, start_command: nil, output_directory: nil, build_runtime: nil, adapter: nil, fallback_file: nil, installation_id: nil, provider_repository_id: nil, provider_branch: nil, provider_silent_mode: nil, provider_root_directory: nil, build_specification: nil, runtime_specification: nil, deployment_retention: nil) ⇒ Site
Update site by its unique ID.
-
#update_deployment_status(site_id:, deployment_id:) ⇒ Deployment
Cancel an ongoing site deployment build.
-
#update_site_deployment(site_id:, deployment_id:) ⇒ Site
Update the site active deployment.
-
#update_variable(site_id:, variable_id:, key:, value: nil, secret: nil) ⇒ Variable
Update variable by its unique ID.
Constructor Details
#initialize(client) ⇒ Sites
Returns a new instance of Sites.
6 7 8 |
# File 'lib/appwrite/services/sites.rb', line 6 def initialize(client) @client = client end |
Instance Method Details
#create(site_id:, name:, framework:, build_runtime:, enabled: nil, logging: nil, timeout: nil, install_command: nil, build_command: nil, start_command: nil, output_directory: nil, adapter: nil, installation_id: nil, fallback_file: nil, provider_repository_id: nil, provider_branch: nil, provider_silent_mode: nil, provider_root_directory: nil, build_specification: nil, runtime_specification: nil, deployment_retention: nil) ⇒ Site
Create a new site.
65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 |
# File 'lib/appwrite/services/sites.rb', line 65 def create(site_id:, name:, framework:, build_runtime:, enabled: nil, logging: nil, timeout: nil, install_command: nil, build_command: nil, start_command: nil, output_directory: nil, adapter: nil, installation_id: nil, fallback_file: nil, provider_repository_id: nil, provider_branch: nil, provider_silent_mode: nil, provider_root_directory: nil, build_specification: nil, runtime_specification: nil, deployment_retention: nil) api_path = '/sites' if site_id.nil? raise Appwrite::Exception.new('Missing required parameter: "siteId"') end if name.nil? raise Appwrite::Exception.new('Missing required parameter: "name"') end if framework.nil? raise Appwrite::Exception.new('Missing required parameter: "framework"') end if build_runtime.nil? raise Appwrite::Exception.new('Missing required parameter: "buildRuntime"') end api_params = { siteId: site_id, name: name, framework: framework, enabled: enabled, logging: logging, timeout: timeout, installCommand: install_command, buildCommand: build_command, startCommand: start_command, outputDirectory: output_directory, buildRuntime: build_runtime, adapter: adapter, installationId: installation_id, fallbackFile: fallback_file, providerRepositoryId: provider_repository_id, providerBranch: provider_branch, providerSilentMode: provider_silent_mode, providerRootDirectory: provider_root_directory, buildSpecification: build_specification, runtimeSpecification: runtime_specification, deploymentRetention: deployment_retention, } api_headers = { "content-type": 'application/json', } @client.call( method: 'POST', path: api_path, headers: api_headers, params: api_params, response_type: Models::Site ) end |
#create_deployment(site_id:, code:, install_command: nil, build_command: nil, output_directory: nil, activate: nil, on_progress: nil) ⇒ Deployment
Create a new site code deployment. Use this endpoint to upload a new version of your site code. To activate your newly uploaded code, you’ll need to update the site’s deployment to use your new deployment ID.
390 391 392 393 394 395 396 397 398 399 400 401 402 403 404 405 406 407 408 409 410 411 412 413 414 415 416 417 418 419 420 421 422 423 424 425 426 427 |
# File 'lib/appwrite/services/sites.rb', line 390 def create_deployment(site_id:, code:, install_command: nil, build_command: nil, output_directory: nil, activate: nil, on_progress: nil) api_path = '/sites/{siteId}/deployments' .gsub('{siteId}', site_id) if site_id.nil? raise Appwrite::Exception.new('Missing required parameter: "siteId"') end if code.nil? raise Appwrite::Exception.new('Missing required parameter: "code"') end api_params = { installCommand: install_command, buildCommand: build_command, outputDirectory: output_directory, code: code, activate: activate, } api_headers = { "content-type": 'multipart/form-data', } id_param_name = nil param_name = 'code' @client.chunked_upload( path: api_path, headers: api_headers, params: api_params, param_name: param_name, id_param_name: id_param_name, on_progress: on_progress, response_type: Models::Deployment ) end |
#create_duplicate_deployment(site_id:, deployment_id:) ⇒ Deployment
Create a new build for an existing site deployment. This endpoint allows you to rebuild a deployment with the updated site configuration, including its commands and output directory if they have been modified. The build process will be queued and executed asynchronously. The original deployment’s code will be preserved and used for the new build.
439 440 441 442 443 444 445 446 447 448 449 450 451 452 453 454 455 456 457 458 459 460 461 462 463 464 465 466 467 |
# File 'lib/appwrite/services/sites.rb', line 439 def create_duplicate_deployment(site_id:, deployment_id:) api_path = '/sites/{siteId}/deployments/duplicate' .gsub('{siteId}', site_id) if site_id.nil? raise Appwrite::Exception.new('Missing required parameter: "siteId"') end if deployment_id.nil? raise Appwrite::Exception.new('Missing required parameter: "deploymentId"') end api_params = { deploymentId: deployment_id, } api_headers = { "content-type": 'application/json', } @client.call( method: 'POST', path: api_path, headers: api_headers, params: api_params, response_type: Models::Deployment ) end |
#create_template_deployment(site_id:, repository:, owner:, root_directory:, type:, reference:, activate: nil) ⇒ Deployment
Create a deployment based on a template.
Use this endpoint with combination of [listTemplates](appwrite.io/docs/products/sites/templates) to find the template details.
484 485 486 487 488 489 490 491 492 493 494 495 496 497 498 499 500 501 502 503 504 505 506 507 508 509 510 511 512 513 514 515 516 517 518 519 520 521 522 523 524 525 526 527 528 529 530 531 532 533 |
# File 'lib/appwrite/services/sites.rb', line 484 def create_template_deployment(site_id:, repository:, owner:, root_directory:, type:, reference:, activate: nil) api_path = '/sites/{siteId}/deployments/template' .gsub('{siteId}', site_id) if site_id.nil? raise Appwrite::Exception.new('Missing required parameter: "siteId"') end if repository.nil? raise Appwrite::Exception.new('Missing required parameter: "repository"') end if owner.nil? raise Appwrite::Exception.new('Missing required parameter: "owner"') end if root_directory.nil? raise Appwrite::Exception.new('Missing required parameter: "rootDirectory"') end if type.nil? raise Appwrite::Exception.new('Missing required parameter: "type"') end if reference.nil? raise Appwrite::Exception.new('Missing required parameter: "reference"') end api_params = { repository: repository, owner: owner, rootDirectory: root_directory, type: type, reference: reference, activate: activate, } api_headers = { "content-type": 'application/json', } @client.call( method: 'POST', path: api_path, headers: api_headers, params: api_params, response_type: Models::Deployment ) end |
#create_variable(site_id:, key:, value:, secret: nil) ⇒ Variable
Create a new site variable. These variables can be accessed during build and runtime (server-side rendering) as environment variables.
871 872 873 874 875 876 877 878 879 880 881 882 883 884 885 886 887 888 889 890 891 892 893 894 895 896 897 898 899 900 901 902 903 904 905 |
# File 'lib/appwrite/services/sites.rb', line 871 def create_variable(site_id:, key:, value:, secret: nil) api_path = '/sites/{siteId}/variables' .gsub('{siteId}', site_id) if site_id.nil? raise Appwrite::Exception.new('Missing required parameter: "siteId"') end if key.nil? raise Appwrite::Exception.new('Missing required parameter: "key"') end if value.nil? raise Appwrite::Exception.new('Missing required parameter: "value"') end api_params = { key: key, value: value, secret: secret, } api_headers = { "content-type": 'application/json', } @client.call( method: 'POST', path: api_path, headers: api_headers, params: api_params, response_type: Models::Variable ) end |
#create_vcs_deployment(site_id:, type:, reference:, activate: nil) ⇒ Deployment
Create a deployment when a site is connected to VCS.
This endpoint lets you create deployment from a branch, commit, or a tag.
545 546 547 548 549 550 551 552 553 554 555 556 557 558 559 560 561 562 563 564 565 566 567 568 569 570 571 572 573 574 575 576 577 578 579 |
# File 'lib/appwrite/services/sites.rb', line 545 def create_vcs_deployment(site_id:, type:, reference:, activate: nil) api_path = '/sites/{siteId}/deployments/vcs' .gsub('{siteId}', site_id) if site_id.nil? raise Appwrite::Exception.new('Missing required parameter: "siteId"') end if type.nil? raise Appwrite::Exception.new('Missing required parameter: "type"') end if reference.nil? raise Appwrite::Exception.new('Missing required parameter: "reference"') end api_params = { type: type, reference: reference, activate: activate, } api_headers = { "content-type": 'application/json', } @client.call( method: 'POST', path: api_path, headers: api_headers, params: api_params, response_type: Models::Deployment ) end |
#delete(site_id:) ⇒ Object
Delete a site by its unique ID.
281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 |
# File 'lib/appwrite/services/sites.rb', line 281 def delete(site_id:) api_path = '/sites/{siteId}' .gsub('{siteId}', site_id) if site_id.nil? raise Appwrite::Exception.new('Missing required parameter: "siteId"') end api_params = { } api_headers = { "content-type": 'application/json', } @client.call( method: 'DELETE', path: api_path, headers: api_headers, params: api_params, ) end |
#delete_deployment(site_id:, deployment_id:) ⇒ Object
Delete a site deployment by its unique ID.
622 623 624 625 626 627 628 629 630 631 632 633 634 635 636 637 638 639 640 641 642 643 644 645 646 647 648 649 |
# File 'lib/appwrite/services/sites.rb', line 622 def delete_deployment(site_id:, deployment_id:) api_path = '/sites/{siteId}/deployments/{deploymentId}' .gsub('{siteId}', site_id) .gsub('{deploymentId}', deployment_id) if site_id.nil? raise Appwrite::Exception.new('Missing required parameter: "siteId"') end if deployment_id.nil? raise Appwrite::Exception.new('Missing required parameter: "deploymentId"') end api_params = { } api_headers = { "content-type": 'application/json', } @client.call( method: 'DELETE', path: api_path, headers: api_headers, params: api_params, ) end |
#delete_log(site_id:, log_id:) ⇒ Object
Delete a site log by its unique ID.
804 805 806 807 808 809 810 811 812 813 814 815 816 817 818 819 820 821 822 823 824 825 826 827 828 829 830 831 |
# File 'lib/appwrite/services/sites.rb', line 804 def delete_log(site_id:, log_id:) api_path = '/sites/{siteId}/logs/{logId}' .gsub('{siteId}', site_id) .gsub('{logId}', log_id) if site_id.nil? raise Appwrite::Exception.new('Missing required parameter: "siteId"') end if log_id.nil? raise Appwrite::Exception.new('Missing required parameter: "logId"') end api_params = { } api_headers = { "content-type": 'application/json', } @client.call( method: 'DELETE', path: api_path, headers: api_headers, params: api_params, ) end |
#delete_variable(site_id:, variable_id:) ⇒ Object
Delete a variable by its unique ID.
994 995 996 997 998 999 1000 1001 1002 1003 1004 1005 1006 1007 1008 1009 1010 1011 1012 1013 1014 1015 1016 1017 1018 1019 1020 1021 |
# File 'lib/appwrite/services/sites.rb', line 994 def delete_variable(site_id:, variable_id:) api_path = '/sites/{siteId}/variables/{variableId}' .gsub('{siteId}', site_id) .gsub('{variableId}', variable_id) if site_id.nil? raise Appwrite::Exception.new('Missing required parameter: "siteId"') end if variable_id.nil? raise Appwrite::Exception.new('Missing required parameter: "variableId"') end api_params = { } api_headers = { "content-type": 'application/json', } @client.call( method: 'DELETE', path: api_path, headers: api_headers, params: api_params, ) end |
#get(site_id:) ⇒ Site
Get a site by its unique ID.
174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 |
# File 'lib/appwrite/services/sites.rb', line 174 def get(site_id:) api_path = '/sites/{siteId}' .gsub('{siteId}', site_id) if site_id.nil? raise Appwrite::Exception.new('Missing required parameter: "siteId"') end api_params = { } api_headers = { } @client.call( method: 'GET', path: api_path, headers: api_headers, params: api_params, response_type: Models::Site ) end |
#get_deployment(site_id:, deployment_id:) ⇒ Deployment
Get a site deployment by its unique ID.
587 588 589 590 591 592 593 594 595 596 597 598 599 600 601 602 603 604 605 606 607 608 609 610 611 612 613 614 |
# File 'lib/appwrite/services/sites.rb', line 587 def get_deployment(site_id:, deployment_id:) api_path = '/sites/{siteId}/deployments/{deploymentId}' .gsub('{siteId}', site_id) .gsub('{deploymentId}', deployment_id) if site_id.nil? raise Appwrite::Exception.new('Missing required parameter: "siteId"') end if deployment_id.nil? raise Appwrite::Exception.new('Missing required parameter: "deploymentId"') end api_params = { } api_headers = { } @client.call( method: 'GET', path: api_path, headers: api_headers, params: api_params, response_type: Models::Deployment ) end |
#get_deployment_download(site_id:, deployment_id:, type: nil) ⇒ Object
Get a site deployment content by its unique ID. The endpoint response return with a ‘Content-Disposition: attachment’ header that tells the browser to start downloading the file to user downloads directory.
660 661 662 663 664 665 666 667 668 669 670 671 672 673 674 675 676 677 678 679 680 681 682 683 684 685 686 687 |
# File 'lib/appwrite/services/sites.rb', line 660 def get_deployment_download(site_id:, deployment_id:, type: nil) api_path = '/sites/{siteId}/deployments/{deploymentId}/download' .gsub('{siteId}', site_id) .gsub('{deploymentId}', deployment_id) if site_id.nil? raise Appwrite::Exception.new('Missing required parameter: "siteId"') end if deployment_id.nil? raise Appwrite::Exception.new('Missing required parameter: "deploymentId"') end api_params = { type: type, } api_headers = { } @client.call( method: 'GET', path: api_path, headers: api_headers, params: api_params, ) end |
#get_log(site_id:, log_id:) ⇒ Execution
Get a site request log by its unique ID.
769 770 771 772 773 774 775 776 777 778 779 780 781 782 783 784 785 786 787 788 789 790 791 792 793 794 795 796 |
# File 'lib/appwrite/services/sites.rb', line 769 def get_log(site_id:, log_id:) api_path = '/sites/{siteId}/logs/{logId}' .gsub('{siteId}', site_id) .gsub('{logId}', log_id) if site_id.nil? raise Appwrite::Exception.new('Missing required parameter: "siteId"') end if log_id.nil? raise Appwrite::Exception.new('Missing required parameter: "logId"') end api_params = { } api_headers = { } @client.call( method: 'GET', path: api_path, headers: api_headers, params: api_params, response_type: Models::Execution ) end |
#get_variable(site_id:, variable_id:) ⇒ Variable
Get a variable by its unique ID.
913 914 915 916 917 918 919 920 921 922 923 924 925 926 927 928 929 930 931 932 933 934 935 936 937 938 939 940 |
# File 'lib/appwrite/services/sites.rb', line 913 def get_variable(site_id:, variable_id:) api_path = '/sites/{siteId}/variables/{variableId}' .gsub('{siteId}', site_id) .gsub('{variableId}', variable_id) if site_id.nil? raise Appwrite::Exception.new('Missing required parameter: "siteId"') end if variable_id.nil? raise Appwrite::Exception.new('Missing required parameter: "variableId"') end api_params = { } api_headers = { } @client.call( method: 'GET', path: api_path, headers: api_headers, params: api_params, response_type: Models::Variable ) end |
#list(queries: nil, search: nil, total: nil) ⇒ SiteList
Get a list of all the project’s sites. You can use the query params to filter your results.
18 19 20 21 22 23 24 25 26 27 28 29 30 31 32 33 34 35 36 37 38 |
# File 'lib/appwrite/services/sites.rb', line 18 def list(queries: nil, search: nil, total: nil) api_path = '/sites' api_params = { queries: queries, search: search, total: total, } api_headers = { } @client.call( method: 'GET', path: api_path, headers: api_headers, params: api_params, response_type: Models::SiteList ) end |
#list_deployments(site_id:, queries: nil, search: nil, total: nil) ⇒ DeploymentList
Get a list of all the site’s code deployments. You can use the query params to filter your results.
351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 |
# File 'lib/appwrite/services/sites.rb', line 351 def list_deployments(site_id:, queries: nil, search: nil, total: nil) api_path = '/sites/{siteId}/deployments' .gsub('{siteId}', site_id) if site_id.nil? raise Appwrite::Exception.new('Missing required parameter: "siteId"') end api_params = { queries: queries, search: search, total: total, } api_headers = { } @client.call( method: 'GET', path: api_path, headers: api_headers, params: api_params, response_type: Models::DeploymentList ) end |
#list_frameworks ⇒ FrameworkList
Get a list of all frameworks that are currently available on the server instance.
127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 |
# File 'lib/appwrite/services/sites.rb', line 127 def list_frameworks() api_path = '/sites/frameworks' api_params = { } api_headers = { } @client.call( method: 'GET', path: api_path, headers: api_headers, params: api_params, response_type: Models::FrameworkList ) end |
#list_logs(site_id:, queries: nil, total: nil) ⇒ ExecutionList
Get a list of all site logs. You can use the query params to filter your results.
737 738 739 740 741 742 743 744 745 746 747 748 749 750 751 752 753 754 755 756 757 758 759 760 761 |
# File 'lib/appwrite/services/sites.rb', line 737 def list_logs(site_id:, queries: nil, total: nil) api_path = '/sites/{siteId}/logs' .gsub('{siteId}', site_id) if site_id.nil? raise Appwrite::Exception.new('Missing required parameter: "siteId"') end api_params = { queries: queries, total: total, } api_headers = { } @client.call( method: 'GET', path: api_path, headers: api_headers, params: api_params, response_type: Models::ExecutionList ) end |
#list_specifications ⇒ SpecificationList
List allowed site specifications for this instance.
150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 |
# File 'lib/appwrite/services/sites.rb', line 150 def list_specifications() api_path = '/sites/specifications' api_params = { } api_headers = { } @client.call( method: 'GET', path: api_path, headers: api_headers, params: api_params, response_type: Models::SpecificationList ) end |
#list_variables(site_id:) ⇒ VariableList
Get a list of all variables of a specific site.
838 839 840 841 842 843 844 845 846 847 848 849 850 851 852 853 854 855 856 857 858 859 860 |
# File 'lib/appwrite/services/sites.rb', line 838 def list_variables(site_id:) api_path = '/sites/{siteId}/variables' .gsub('{siteId}', site_id) if site_id.nil? raise Appwrite::Exception.new('Missing required parameter: "siteId"') end api_params = { } api_headers = { } @client.call( method: 'GET', path: api_path, headers: api_headers, params: api_params, response_type: Models::VariableList ) end |
#update(site_id:, name:, framework:, enabled: nil, logging: nil, timeout: nil, install_command: nil, build_command: nil, start_command: nil, output_directory: nil, build_runtime: nil, adapter: nil, fallback_file: nil, installation_id: nil, provider_repository_id: nil, provider_branch: nil, provider_silent_mode: nil, provider_root_directory: nil, build_specification: nil, runtime_specification: nil, deployment_retention: nil) ⇒ Site
Update site by its unique ID.
223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 |
# File 'lib/appwrite/services/sites.rb', line 223 def update(site_id:, name:, framework:, enabled: nil, logging: nil, timeout: nil, install_command: nil, build_command: nil, start_command: nil, output_directory: nil, build_runtime: nil, adapter: nil, fallback_file: nil, installation_id: nil, provider_repository_id: nil, provider_branch: nil, provider_silent_mode: nil, provider_root_directory: nil, build_specification: nil, runtime_specification: nil, deployment_retention: nil) api_path = '/sites/{siteId}' .gsub('{siteId}', site_id) if site_id.nil? raise Appwrite::Exception.new('Missing required parameter: "siteId"') end if name.nil? raise Appwrite::Exception.new('Missing required parameter: "name"') end if framework.nil? raise Appwrite::Exception.new('Missing required parameter: "framework"') end api_params = { name: name, framework: framework, enabled: enabled, logging: logging, timeout: timeout, installCommand: install_command, buildCommand: build_command, startCommand: start_command, outputDirectory: output_directory, buildRuntime: build_runtime, adapter: adapter, fallbackFile: fallback_file, installationId: installation_id, providerRepositoryId: provider_repository_id, providerBranch: provider_branch, providerSilentMode: provider_silent_mode, providerRootDirectory: provider_root_directory, buildSpecification: build_specification, runtimeSpecification: runtime_specification, deploymentRetention: deployment_retention, } api_headers = { "content-type": 'application/json', } @client.call( method: 'PUT', path: api_path, headers: api_headers, params: api_params, response_type: Models::Site ) end |
#update_deployment_status(site_id:, deployment_id:) ⇒ Deployment
Cancel an ongoing site deployment build. If the build is already in progress, it will be stopped and marked as canceled. If the build hasn’t started yet, it will be marked as canceled without executing. You cannot cancel builds that have already completed (status ‘ready’) or failed. The response includes the final build status and details.
699 700 701 702 703 704 705 706 707 708 709 710 711 712 713 714 715 716 717 718 719 720 721 722 723 724 725 726 727 |
# File 'lib/appwrite/services/sites.rb', line 699 def update_deployment_status(site_id:, deployment_id:) api_path = '/sites/{siteId}/deployments/{deploymentId}/status' .gsub('{siteId}', site_id) .gsub('{deploymentId}', deployment_id) if site_id.nil? raise Appwrite::Exception.new('Missing required parameter: "siteId"') end if deployment_id.nil? raise Appwrite::Exception.new('Missing required parameter: "deploymentId"') end api_params = { } api_headers = { "content-type": 'application/json', } @client.call( method: 'PATCH', path: api_path, headers: api_headers, params: api_params, response_type: Models::Deployment ) end |
#update_site_deployment(site_id:, deployment_id:) ⇒ Site
Update the site active deployment. Use this endpoint to switch the code deployment that should be used when visitor opens your site.
312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 |
# File 'lib/appwrite/services/sites.rb', line 312 def update_site_deployment(site_id:, deployment_id:) api_path = '/sites/{siteId}/deployment' .gsub('{siteId}', site_id) if site_id.nil? raise Appwrite::Exception.new('Missing required parameter: "siteId"') end if deployment_id.nil? raise Appwrite::Exception.new('Missing required parameter: "deploymentId"') end api_params = { deploymentId: deployment_id, } api_headers = { "content-type": 'application/json', } @client.call( method: 'PATCH', path: api_path, headers: api_headers, params: api_params, response_type: Models::Site ) end |
#update_variable(site_id:, variable_id:, key:, value: nil, secret: nil) ⇒ Variable
Update variable by its unique ID.
951 952 953 954 955 956 957 958 959 960 961 962 963 964 965 966 967 968 969 970 971 972 973 974 975 976 977 978 979 980 981 982 983 984 985 986 |
# File 'lib/appwrite/services/sites.rb', line 951 def update_variable(site_id:, variable_id:, key:, value: nil, secret: nil) api_path = '/sites/{siteId}/variables/{variableId}' .gsub('{siteId}', site_id) .gsub('{variableId}', variable_id) if site_id.nil? raise Appwrite::Exception.new('Missing required parameter: "siteId"') end if variable_id.nil? raise Appwrite::Exception.new('Missing required parameter: "variableId"') end if key.nil? raise Appwrite::Exception.new('Missing required parameter: "key"') end api_params = { key: key, value: value, secret: secret, } api_headers = { "content-type": 'application/json', } @client.call( method: 'PUT', path: api_path, headers: api_headers, params: api_params, response_type: Models::Variable ) end |