Class: Appwrite::Storage
- Defined in:
- lib/appwrite/services/storage.rb
Instance Method Summary collapse
-
#create_bucket(bucket_id:, name:, permissions: nil, file_security: nil, enabled: nil, maximum_file_size: nil, allowed_file_extensions: nil, compression: nil, encryption: nil, antivirus: nil, transformations: nil) ⇒ Bucket
Create a new storage bucket.
-
#create_file(bucket_id:, file_id:, file:, permissions: nil, on_progress: nil) ⇒ File
Create a new file.
-
#delete_bucket(bucket_id:) ⇒ Object
Delete a storage bucket by its unique ID.
-
#delete_file(bucket_id:, file_id:) ⇒ Object
Delete a file by its unique ID.
-
#get_bucket(bucket_id:) ⇒ Bucket
Get a storage bucket by its unique ID.
-
#get_file(bucket_id:, file_id:) ⇒ File
Get a file by its unique ID.
-
#get_file_download(bucket_id:, file_id:, token: nil) ⇒ Object
Get a file content by its unique ID.
-
#get_file_preview(bucket_id:, file_id:, width: nil, height: nil, gravity: nil, quality: nil, border_width: nil, border_color: nil, border_radius: nil, opacity: nil, rotation: nil, background: nil, output: nil, token: nil) ⇒ Object
Get a file preview image.
-
#get_file_view(bucket_id:, file_id:, token: nil) ⇒ Object
Get a file content by its unique ID.
-
#initialize(client) ⇒ Storage
constructor
A new instance of Storage.
-
#list_buckets(queries: nil, search: nil, total: nil) ⇒ BucketList
Get a list of all the storage buckets.
-
#list_files(bucket_id:, queries: nil, search: nil, total: nil) ⇒ FileList
Get a list of all the user files.
-
#update_bucket(bucket_id:, name:, permissions: nil, file_security: nil, enabled: nil, maximum_file_size: nil, allowed_file_extensions: nil, compression: nil, encryption: nil, antivirus: nil, transformations: nil) ⇒ Bucket
Update a storage bucket by its unique ID.
-
#update_file(bucket_id:, file_id:, name: nil, permissions: nil) ⇒ File
Update a file by its unique ID.
Constructor Details
#initialize(client) ⇒ Storage
Returns a new instance of Storage.
6 7 8 |
# File 'lib/appwrite/services/storage.rb', line 6 def initialize(client) @client = client end |
Instance Method Details
#create_bucket(bucket_id:, name:, permissions: nil, file_security: nil, enabled: nil, maximum_file_size: nil, allowed_file_extensions: nil, compression: nil, encryption: nil, antivirus: nil, transformations: nil) ⇒ Bucket
Create a new storage bucket.
55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 |
# File 'lib/appwrite/services/storage.rb', line 55 def create_bucket(bucket_id:, name:, permissions: nil, file_security: nil, enabled: nil, maximum_file_size: nil, allowed_file_extensions: nil, compression: nil, encryption: nil, antivirus: nil, transformations: nil) api_path = '/storage/buckets' if bucket_id.nil? raise Appwrite::Exception.new('Missing required parameter: "bucketId"') end if name.nil? raise Appwrite::Exception.new('Missing required parameter: "name"') end api_params = { bucketId: bucket_id, name: name, permissions: , fileSecurity: file_security, enabled: enabled, maximumFileSize: maximum_file_size, allowedFileExtensions: allowed_file_extensions, compression: compression, encryption: encryption, antivirus: antivirus, transformations: transformations, } api_headers = { "content-type": 'application/json', } @client.call( method: 'POST', path: api_path, headers: api_headers, params: api_params, response_type: Models::Bucket ) end |
#create_file(bucket_id:, file_id:, file:, permissions: nil, on_progress: nil) ⇒ File
Create a new file. Before using this route, you should create a new bucket resource using either a [server integration](appwrite.io/docs/server/storage#storageCreateBucket) API or directly from your Appwrite console.
Larger files should be uploaded using multiple requests with the [content-range](developer.mozilla.org/en-US/docs/Web/HTTP/Headers/Content-Range) header to send a partial request with a maximum supported chunk of ‘5MB`. The `content-range` header values should always be in bytes.
When the first request is sent, the server will return the File object, and the subsequent part request must include the file’s id in ‘x-appwrite-id` header to allow the server to know that the partial upload is for the existing file and not for a new one.
If you’re creating a new file using one of the Appwrite SDKs, all the chunking logic will be managed by the SDK internally.
268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 |
# File 'lib/appwrite/services/storage.rb', line 268 def create_file(bucket_id:, file_id:, file:, permissions: nil, on_progress: nil) api_path = '/storage/buckets/{bucketId}/files' .gsub('{bucketId}', bucket_id) if bucket_id.nil? raise Appwrite::Exception.new('Missing required parameter: "bucketId"') end if file_id.nil? raise Appwrite::Exception.new('Missing required parameter: "fileId"') end if file.nil? raise Appwrite::Exception.new('Missing required parameter: "file"') end api_params = { fileId: file_id, file: file, permissions: , } api_headers = { "content-type": 'multipart/form-data', } id_param_name = "fileId" param_name = 'file' @client.chunked_upload( path: api_path, headers: api_headers, params: api_params, param_name: param_name, id_param_name: id_param_name, on_progress: on_progress, response_type: Models::File ) end |
#delete_bucket(bucket_id:) ⇒ Object
Delete a storage bucket by its unique ID.
183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 |
# File 'lib/appwrite/services/storage.rb', line 183 def delete_bucket(bucket_id:) api_path = '/storage/buckets/{bucketId}' .gsub('{bucketId}', bucket_id) if bucket_id.nil? raise Appwrite::Exception.new('Missing required parameter: "bucketId"') end api_params = { } api_headers = { "content-type": 'application/json', } @client.call( method: 'DELETE', path: api_path, headers: api_headers, params: api_params, ) end |
#delete_file(bucket_id:, file_id:) ⇒ Object
Delete a file by its unique ID. Only users with write permissions have access to delete this resource.
393 394 395 396 397 398 399 400 401 402 403 404 405 406 407 408 409 410 411 412 413 414 415 416 417 418 419 420 |
# File 'lib/appwrite/services/storage.rb', line 393 def delete_file(bucket_id:, file_id:) api_path = '/storage/buckets/{bucketId}/files/{fileId}' .gsub('{bucketId}', bucket_id) .gsub('{fileId}', file_id) if bucket_id.nil? raise Appwrite::Exception.new('Missing required parameter: "bucketId"') end if file_id.nil? raise Appwrite::Exception.new('Missing required parameter: "fileId"') end api_params = { } api_headers = { "content-type": 'application/json', } @client.call( method: 'DELETE', path: api_path, headers: api_headers, params: api_params, ) end |
#get_bucket(bucket_id:) ⇒ Bucket
Get a storage bucket by its unique ID. This endpoint response returns a JSON object with the storage bucket metadata.
100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 |
# File 'lib/appwrite/services/storage.rb', line 100 def get_bucket(bucket_id:) api_path = '/storage/buckets/{bucketId}' .gsub('{bucketId}', bucket_id) if bucket_id.nil? raise Appwrite::Exception.new('Missing required parameter: "bucketId"') end api_params = { } api_headers = { } @client.call( method: 'GET', path: api_path, headers: api_headers, params: api_params, response_type: Models::Bucket ) end |
#get_file(bucket_id:, file_id:) ⇒ File
Get a file by its unique ID. This endpoint response returns a JSON object with the file metadata.
316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 |
# File 'lib/appwrite/services/storage.rb', line 316 def get_file(bucket_id:, file_id:) api_path = '/storage/buckets/{bucketId}/files/{fileId}' .gsub('{bucketId}', bucket_id) .gsub('{fileId}', file_id) if bucket_id.nil? raise Appwrite::Exception.new('Missing required parameter: "bucketId"') end if file_id.nil? raise Appwrite::Exception.new('Missing required parameter: "fileId"') end api_params = { } api_headers = { } @client.call( method: 'GET', path: api_path, headers: api_headers, params: api_params, response_type: Models::File ) end |
#get_file_download(bucket_id:, file_id:, token: nil) ⇒ Object
Get a file content by its unique ID. The endpoint response return with a ‘Content-Disposition: attachment’ header that tells the browser to start downloading the file to user downloads directory.
431 432 433 434 435 436 437 438 439 440 441 442 443 444 445 446 447 448 449 450 451 452 453 454 455 456 457 458 |
# File 'lib/appwrite/services/storage.rb', line 431 def get_file_download(bucket_id:, file_id:, token: nil) api_path = '/storage/buckets/{bucketId}/files/{fileId}/download' .gsub('{bucketId}', bucket_id) .gsub('{fileId}', file_id) if bucket_id.nil? raise Appwrite::Exception.new('Missing required parameter: "bucketId"') end if file_id.nil? raise Appwrite::Exception.new('Missing required parameter: "fileId"') end api_params = { token: token, } api_headers = { } @client.call( method: 'GET', path: api_path, headers: api_headers, params: api_params, ) end |
#get_file_preview(bucket_id:, file_id:, width: nil, height: nil, gravity: nil, quality: nil, border_width: nil, border_color: nil, border_radius: nil, opacity: nil, rotation: nil, background: nil, output: nil, token: nil) ⇒ Object
Get a file preview image. Currently, this method supports preview for image files (jpg, png, and gif), other supported formats, like pdf, docs, slides, and spreadsheets, will return the file icon image. You can also pass query string arguments for cutting and resizing your preview image. Preview is supported only for image files smaller than 10MB.
482 483 484 485 486 487 488 489 490 491 492 493 494 495 496 497 498 499 500 501 502 503 504 505 506 507 508 509 510 511 512 513 514 515 516 517 518 519 520 |
# File 'lib/appwrite/services/storage.rb', line 482 def get_file_preview(bucket_id:, file_id:, width: nil, height: nil, gravity: nil, quality: nil, border_width: nil, border_color: nil, border_radius: nil, opacity: nil, rotation: nil, background: nil, output: nil, token: nil) api_path = '/storage/buckets/{bucketId}/files/{fileId}/preview' .gsub('{bucketId}', bucket_id) .gsub('{fileId}', file_id) if bucket_id.nil? raise Appwrite::Exception.new('Missing required parameter: "bucketId"') end if file_id.nil? raise Appwrite::Exception.new('Missing required parameter: "fileId"') end api_params = { width: width, height: height, gravity: gravity, quality: quality, borderWidth: border_width, borderColor: border_color, borderRadius: border_radius, opacity: opacity, rotation: rotation, background: background, output: output, token: token, } api_headers = { } @client.call( method: 'GET', path: api_path, headers: api_headers, params: api_params, ) end |
#get_file_view(bucket_id:, file_id:, token: nil) ⇒ Object
Get a file content by its unique ID. This endpoint is similar to the download method but returns with no ‘Content-Disposition: attachment’ header.
531 532 533 534 535 536 537 538 539 540 541 542 543 544 545 546 547 548 549 550 551 552 553 554 555 556 557 558 |
# File 'lib/appwrite/services/storage.rb', line 531 def get_file_view(bucket_id:, file_id:, token: nil) api_path = '/storage/buckets/{bucketId}/files/{fileId}/view' .gsub('{bucketId}', bucket_id) .gsub('{fileId}', file_id) if bucket_id.nil? raise Appwrite::Exception.new('Missing required parameter: "bucketId"') end if file_id.nil? raise Appwrite::Exception.new('Missing required parameter: "fileId"') end api_params = { token: token, } api_headers = { } @client.call( method: 'GET', path: api_path, headers: api_headers, params: api_params, ) end |
#list_buckets(queries: nil, search: nil, total: nil) ⇒ BucketList
Get a list of all the storage buckets. You can use the query params to filter your results.
18 19 20 21 22 23 24 25 26 27 28 29 30 31 32 33 34 35 36 37 38 |
# File 'lib/appwrite/services/storage.rb', line 18 def list_buckets(queries: nil, search: nil, total: nil) api_path = '/storage/buckets' api_params = { queries: queries, search: search, total: total, } api_headers = { } @client.call( method: 'GET', path: api_path, headers: api_headers, params: api_params, response_type: Models::BucketList ) end |
#list_files(bucket_id:, queries: nil, search: nil, total: nil) ⇒ FileList
Get a list of all the user files. You can use the query params to filter your results.
216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 |
# File 'lib/appwrite/services/storage.rb', line 216 def list_files(bucket_id:, queries: nil, search: nil, total: nil) api_path = '/storage/buckets/{bucketId}/files' .gsub('{bucketId}', bucket_id) if bucket_id.nil? raise Appwrite::Exception.new('Missing required parameter: "bucketId"') end api_params = { queries: queries, search: search, total: total, } api_headers = { } @client.call( method: 'GET', path: api_path, headers: api_headers, params: api_params, response_type: Models::FileList ) end |
#update_bucket(bucket_id:, name:, permissions: nil, file_security: nil, enabled: nil, maximum_file_size: nil, allowed_file_extensions: nil, compression: nil, encryption: nil, antivirus: nil, transformations: nil) ⇒ Bucket
Update a storage bucket by its unique ID.
139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 |
# File 'lib/appwrite/services/storage.rb', line 139 def update_bucket(bucket_id:, name:, permissions: nil, file_security: nil, enabled: nil, maximum_file_size: nil, allowed_file_extensions: nil, compression: nil, encryption: nil, antivirus: nil, transformations: nil) api_path = '/storage/buckets/{bucketId}' .gsub('{bucketId}', bucket_id) if bucket_id.nil? raise Appwrite::Exception.new('Missing required parameter: "bucketId"') end if name.nil? raise Appwrite::Exception.new('Missing required parameter: "name"') end api_params = { name: name, permissions: , fileSecurity: file_security, enabled: enabled, maximumFileSize: maximum_file_size, allowedFileExtensions: allowed_file_extensions, compression: compression, encryption: encryption, antivirus: antivirus, transformations: transformations, } api_headers = { "content-type": 'application/json', } @client.call( method: 'PUT', path: api_path, headers: api_headers, params: api_params, response_type: Models::Bucket ) end |
#update_file(bucket_id:, file_id:, name: nil, permissions: nil) ⇒ File
Update a file by its unique ID. Only users with write permissions have access to update this resource.
354 355 356 357 358 359 360 361 362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 381 382 383 384 |
# File 'lib/appwrite/services/storage.rb', line 354 def update_file(bucket_id:, file_id:, name: nil, permissions: nil) api_path = '/storage/buckets/{bucketId}/files/{fileId}' .gsub('{bucketId}', bucket_id) .gsub('{fileId}', file_id) if bucket_id.nil? raise Appwrite::Exception.new('Missing required parameter: "bucketId"') end if file_id.nil? raise Appwrite::Exception.new('Missing required parameter: "fileId"') end api_params = { name: name, permissions: , } api_headers = { "content-type": 'application/json', } @client.call( method: 'PUT', path: api_path, headers: api_headers, params: api_params, response_type: Models::File ) end |